@@ -9,13 +9,11 @@
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
       SUBROUTINE INTCTL1(CMO,NCMO)
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
-      IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
+      IMPLICIT None
 #include "caspt2.fh"
 #include "pt2_guga.fh"
-#include "intgrl.fh"
       INTEGER NCMO
       REAL*8 CMO(NCMO)
 
