@@ -28,22 +28,31 @@
 ************************************************************************
       use OneDat, only: sNoNuc, sNoOri
       use Constants, only: Zero, One
+      use stdalloc, only: mma_allocate, mma_deallocate
       Implicit Real*8 (A-H,O-Z)
 #include "Molcas.fh"
-#include "WrkSpc.fh"
+      Integer irc, nSym
       Integer nBas(nSym),nFro(nSym),nIsh(nSym),nAsh(nSym),nSsh(nSym),
      &        nDel(nSym)
-      Integer irc,nUniqAt,IFQCAN
-      Real*8  Thrs, EMP2
-      Logical DoMP2, DoEnv, all_Vir
       Character(Len=LENIN8) NAME(*)
+      Integer nUniqAt
+      Real*8  Thrs
+      Integer IFQCAN
+      Logical DoMP2, DoEnv, all_Vir
+      Real*8  EMP2
+      Integer NCMO
+      Real*8 CMO(nCMO)
+
       Character(Len=LENIN) blank, NamAct(mxAtom)
       character(len=8) :: Label
       Logical ortho
       Real*8  TrA(8), TrF(8), TrX(8)
       Integer ns_O(8), ns_V(8)
       Integer lnOrb(8), lnOcc(8), lnFro(8), lnDel(8), lnVir(8)
-      Real*8 CMO(*)
+      Integer, allocatable:: nBas_per_Atom(:), nBas_Start(:), D_A(:),
+     &                       D_Vir(:)
+      Real*8, allocatable:: SQ(:), SLT(:), CMOX(:), Q(:), Z(:)
+      Real*8, allocatable:: Saa(:), XMO(:), DMat(:), OrbE(:)
 *
 *
       irc=0
@@ -107,105 +116,101 @@ C     -----------------------------------------------------------
 
       l_nBas_per_Atom = nUniqAt
       l_nBas_Start    = nUniqAt
-      Call GetMem('nB_per_Atom','Allo','Inte',
-     &            ip_nBas_per_Atom,l_nBas_per_Atom)
-      Call GetMem('nB_Start','Allo','Inte',
-     &            ip_nBas_Start,l_nBas_Start)
+      Call mma_allocate(nBas_per_Atom,l_nBas_per_Atom,Label='nB/A')
+      Call mma_allocate(nBas_Start,l_nBas_Start,Label='nBStart')
 *
 *----------------------------------------------------------------------*
 *     Read the overlap matrix                                          *
 *----------------------------------------------------------------------*
-      CALL GetMem('SMAT','ALLO','REAL',ipSQ,nSQ)
-      CALL GetMem('SLT','ALLO','REAL',ipS,nTri)
+      CALL mma_allocate(SQ,nSQ,Label='SQ')
+      CALL mma_allocate(SLT,nTri,Label='SLT')
       isymlbl=1
       iopt=ibset(ibset(0,sNoOri),sNoNuc)
       Label='Mltpl  0'
       iComp=1
-      Call RdOne(irc,iopt,Label,iComp,Work(ipS),isymlbl)
+      Call RdOne(irc,iopt,Label,iComp,SLT,isymlbl)
       If(irc.ne.0) return
-      ltri=0
-      lsq=0
+      ltri=1
+      lsq=1
       Do iSym=1,nSym
-         Call Square(Work(ipS+ltri),Work(ipSQ+lsq),1,nBas(iSym),
+         Call Square(SLT(ltri),SQ(lsq),1,nBas(iSym),
      &                                               nBas(iSym))
          ltri=ltri+nBas(iSym)*(nBAs(iSym)+1)/2
          lsq=lsq+nBas(iSym)**2
       End Do
-      CALL GetMem('SLT','FREE','REAL',ipS,nTri)
+      CALL mma_deallocate(SLT)
 *
-      CALL GETMEM('LCMO','ALLO','REAL',LCMO,2*NCMO)
-      ipCMO=LCMO+NCMO
+      CALL mma_allocate(CMOX,2*NCMO,Label='CMOX')
+      ipCMO=1+NCMO
 * This is not the best solution, but I wanted to avoid having to rewrite
 * the indexing code below just to use the CMO array directly
-      call dcopy_(NCMO,CMO,1,WORK(LCMO),1)
-      call dcopy_(NCMO,WORK(LCMO),1,WORK(ipCMO),1)
+      call dcopy_(NCMO,CMO,1,CMOX,1)
+      call dcopy_(NCMO,CMOX,1,CMOX(ipCMO),1)
 
 *----------------------------------------------------------------------*
 *     Compute Mulliken atomic charges of each active orbital           *
 *             on each center to define the Active Site                 *
 *----------------------------------------------------------------------*
-      Call GetMem('Qai','Allo','Real',ipQ,nUniqAt*(mAsh+1))
-      ipQa=ipQ+nUniqAt*mAsh
-      Call Fzero(Work(ipQa),nUniqAt)
-      Call GetMem('Zm','Allo','Real',ipZ,nBmx*mAsh)
+      Call mma_allocate(Q,nUniqAt*(mAsh+1),Label='Q')
+      ipQa=1+nUniqAt*mAsh
+      Call Fzero(Q(ipQa),nUniqAt)
+      Call mma_allocate(Z,nBmx*mAsh,Label='Z')
       lBas=0
       iOff=0
       Do iSym=1,nSym
-         iSQ=ipSQ+iOff
-         ipAsh=LCMO+iOff+nBas(iSym)*(nFro(iSym)+nIsh(iSym))
+         iSQ=1+iOff
+         ipAsh=1+iOff+nBas(iSym)*(nFro(iSym)+nIsh(iSym))
          nBx=Max(1,nBas(iSym))
          Call DGEMM_('N','N',nBas(iSym),nAsh(iSym),nBas(iSym),
-     &                      One,Work(iSQ),nBx,
-     &                          Work(ipAsh),nBx,
-     &                      Zero,Work(ipZ),nBx)
+     &                      One,SQ(iSQ),nBx,
+     &                          CMOX(ipAsh),nBx,
+     &                      Zero,Z,nBx)
          jBas=lBas+1
          kBas=lBas+nBas(iSym)
-         Call BasFun_Atom_Sym(iWork(ip_nBas_per_Atom),
-     &                        iWork(ip_nBas_Start),
+         Call BasFun_Atom_Sym(nBas_per_Atom,nBas_Start,
      &                        Name,jBas,kBas,nUniqAt,.false.)
          Do ik=0,nAsh(iSym)-1
             nAk=nUniqAt*ik
             nBk=nBas(iSym)*ik
             jCMO=ipAsh+nBk-1
-            jZ=ipZ+nBk-1
+            jZ=nBk
             Do iAt=0,nUniqAt-1
-               iBat=iWork(ip_nBas_Start+iAt)
+               iBat=nBas_Start(1+iAt)
                jjCMO=jCMO+iBat
                jjZ=jZ+iBat
-               nBat=iWork(ip_nBas_per_Atom+iAt)
-               iQ=ipQ+nAk+iAt
-               Work(iQ)=ddot_(nBat,Work(jjCMO),1,Work(jjZ),1)
+               nBat=nBas_per_Atom(1+iAt)
+               iQ=1+nAk+iAt
+               Q(iQ)=ddot_(nBat,CMOX(jjCMO),1,Z(jjZ),1)
             End Do
          End Do
          Do iAt=0,nUniqAt-1
-            jQ=ipQ+iAt
+            jQ=1+iAt
             iQa=ipQa+iAt
-            Work(iQa) = Work(iQa)
-     &                + ddot_(nAsh(iSym),Work(jQ),nUniqAt,
-     &                                  Work(jQ),nUniqAt)
-            If (sqrt(Work(iQa)).ge.Thrs) Then
-               jBat=iWork(ip_nBas_Start+iAt)+lBas
+            Q(iQa) = Q(iQa)
+     &             + ddot_(nAsh(iSym),Q(jQ),nUniqAt,Q(jQ),nUniqAt)
+            If (sqrt(Q(iQa)).ge.Thrs) Then
+               jBat=nBas_Start(1+iAt)+lBas
                NamAct(iAt+1)=Name(jBat)(1:LENIN)
             EndIf
          End Do
          lBas=lBas+nBas(iSym)
          iOff=iOff+nBas(iSym)**2
       End Do
-      Call GetMem('Zm','Free','Real',ipZ,nBmx*mAsh)
-      Call GetMem('Qai','Free','Real',ipQ,nUniqAt*(mAsh+1))
+      Call mma_deallocate(Z)
+      Call mma_deallocate(Q)
 
 *     We have now completed the definition of the active site
 *----------------------------------------------------------------------*
-      Call GetMem('ID_A','Allo','Inte',iD,nUniqAt)
+      Call mma_allocate(D_A,nUniqAt,Label='D_A')
       nActa=0
       Do iAt=1,nUniqAt
          If (NamAct(iAt).ne.blank) Then
-            iWork(iD+nActa)=iAt
             nActa=nActa+1
+            D_A(nActa)=iAt
          EndIf
       End Do
       Do iAt=1,nActa
-         jAt=iWork(iD+iAt-1)
+         jAt=D_A(iAt)
          NamAct(iAt)=NamAct(jAt)
       End Do
       Do iAt=nActa+1,nUniqAt
@@ -226,18 +231,19 @@ C     -----------------------------------------------------------
          Write(6,'(A,18A4)') ' Selected atoms: *** None *** '
       EndIf
 
-      Call GetMem('ID_A','Free','Inte',iD,nUniqAt)
+      Call mma_deallocate(D_A)
 *----------------------------------------------------------------------*
 
-      Call GetMem('Eorb','Allo','Real',ipOrbE,4*nOrb)
-      Call Get_darray('RASSCF OrbE',Work(ipOrbE),nOrb)
+      Call mma_allocate(OrbE,4*nOrb,Label='OrbE')
+      ipOrbE=1
+      Call Get_darray('RASSCF OrbE',OrbE(ipOrbE),nOrb)
       Call Compute_Tr_Dab(nSym,nBas,nFro,nIsh,nAsh,nSsh,nDel,
-     &                    Work(ipCMO),Work(ipOrbE),TrX)
+     &                    CMOX(ipCMO),OrbE(ipOrbE),TrX)
 *
 *---  MP2 calculation on the whole system (incompatible with DoMP2)
       If (DoEnv) Then
          Call energy_AplusB(nSym,nBas,nFro,nIsh,nAsh,nSsh,nDel,
-     &                           Work(ipCMO),Work(ipOrbE),E2_ab)
+     &                           CMOX(ipCMO),OrbE(ipOrbE),E2_ab)
       EndIf
 *----------------------------------------------------------------------*
 *     Localize the inactive and virtual orbitals                       *
@@ -247,23 +253,23 @@ C     -----------------------------------------------------------
 *                                                                      *
 *----------------------------------------------------------------------*
       Thrd=1.d-06
-      Call GetMem('ID_vir','Allo','Inte',iD_vir,nBasT)
+      Call mma_allocate(D_vir,nBasT,Label='D_Vir')
       Call Cho_ov_Loc(irc,Thrd,nSym,nBas,nFro,nIsh,
-     &                    nAsh,nSsh,Work(ipCMO),Work(ipSQ),
-     &                    iWork(iD_vir))
+     &                    nAsh,nSsh,CMOX(ipCMO),SQ,
+     &                    D_vir)
 
       If(irc.ne.0) then
        write(6,*) 'Localization failed in LovCASPT2'
-       Call Abend
+       Call Abend()
       Endif
 
       ipEorb=ipOrbE+nOrb
       kEOcc=ipEorb+nOrb
       kEVir=kEOcc+nOrb
-      Call GetMem('XMO','Allo','Real',ipXmo,2*NCMO)
-      iCMO=ipXmo+NCMO
-      Call GetMem('Saa','Allo','Real',ipSaa,nOrb)
-      call dcopy_(nOrb,[One],0,Work(ipSaa),1)
+      Call mma_allocate(Xmo,2*NCMO,Label='XMO')
+      iCMO=1+NCMO
+      Call mma_allocate(Saa,nOrb,Label='Saa')
+      Saa(:)=One
 
 
 *     Inactive orbital selection                                       *
@@ -274,13 +280,13 @@ C     -----------------------------------------------------------
       mOff=0
       Do iSym=1,nSym
          jOff=iOff+nBas(iSym)*nFro(iSym)
-         call dcopy_(nBas(iSym)*nIsh(iSym),Work(ipCMO+jOff),1,
-     &                                    Work(ipXMO+kOff),1)
-         call dcopy_(nBas(iSym)*nIsh(iSym),Work(LCMO+jOff),1,
-     &                                    Work(iCMO+kOff),1)
+         call dcopy_(nBas(iSym)*nIsh(iSym),CMOX(ipCMO+jOff),1,
+     &                                    XMO(1+kOff),1)
+         call dcopy_(nBas(iSym)*nIsh(iSym),CMOX(1+jOff),1,
+     &                                    XMO(iCMO+kOff),1)
          jOff=lOff+nFro(iSym)
-         call dcopy_(nIsh(iSym),Work(ipOrbE+jOff),1,
-     &                         Work(ipEorb+mOff),1)
+         call dcopy_(nIsh(iSym),OrbE(ipOrbE+jOff),1,
+     &                         OrbE(ipEorb+mOff),1)
          iOff=iOff+nBas(iSym)**2
          kOff=kOff+nBas(iSym)*nIsh(iSym)
          lOff=lOff+nBas(iSym)
@@ -288,8 +294,8 @@ C     -----------------------------------------------------------
       End Do
       ortho=.true.
 *
-      Call get_Orb_select(irc,Work(iCMO),Work(ipXMO),Work(ipEorb),
-     &                        Work(ipSQ),Work(ipSaa),Name,NamAct,
+      Call get_Orb_select(irc,XMO(iCMO),XMO,OrbE(ipEorb),
+     &                        SQ,Saa,Name,NamAct,
      &                        nSym,nActa,nIsh,nBas,ortho,Thrs,ns_O)
       If(irc.ne.0) Return
       iOff=0
@@ -298,8 +304,8 @@ C     -----------------------------------------------------------
          lOff=iOff+nBas(iSym)*nFro(iSym)
          Do ik=nIsh(iSym),1,-1
             jOff=kOff+nBas(iSym)*(ik-1)
-            call dcopy_(nBas(iSym),Work(iCMO+jOff),1,
-     &                            Work(LCMO+lOff),1)
+            call dcopy_(nBas(iSym),XMO(iCMO+jOff),1,
+     &                            CMOX(1+lOff),1)
             lOff=lOff+nBas(iSym)
          End Do
          iOff=iOff+nBas(iSym)**2
@@ -310,7 +316,7 @@ C     -----------------------------------------------------------
       Do iSym=1,nSym
          Do ik=nIsh(iSym),ns_O(iSym)+1,-1
             ie=ipEorb+loff+ik-1
-            Work(kEOcc+iloc)=Work(ie)
+            OrbE(kEOcc+iloc)=OrbE(ie)
             iloc=iloc+1
          End Do
          loff=loff+nIsh(iSym)
@@ -321,7 +327,7 @@ C     -----------------------------------------------------------
          koff=joff+nFro(iSym)+nIsh(iSym)-ns_O(iSym)
          Do ik=0,ns_O(iSym)-1
             ie=ipEorb+loff+ik
-            Work(ipOrbE+koff+ik)=Work(ie)
+            OrbE(ipOrbE+koff+ik)=OrbE(ie)
          End Do
          loff=loff+nIsh(iSym)
          joff=joff+nBas(iSym)
@@ -342,32 +348,32 @@ C     -----------------------------------------------------------
       mOff=0
       Do iSym=1,nSym
          jOff=iOff+nBas(iSym)*(nFro(iSym)+nIsh(iSym)+nAsh(iSym))
-         call dcopy_(nBas(iSym)*nSsh(iSym),Work(ipCMO+jOff),1,
-     &                                    Work(ipXMO+kOff),1)
-         call dcopy_(nBas(iSym)*nSsh(iSym),Work(LCMO+jOff),1,
-     &                                    Work(iCMO+kOff),1)
+         call dcopy_(nBas(iSym)*nSsh(iSym),CMOX(ipCMO+jOff),1,
+     &                                    XMO(1+kOff),1)
+         call dcopy_(nBas(iSym)*nSsh(iSym),CMOX(1+jOff),1,
+     &                                    XMO(iCMO+kOff),1)
          jOff=lOff+nFro(iSym)+nIsh(iSym)+nAsh(iSym)
-         call dcopy_(nSsh(iSym),Work(ipOrbE+jOff),1,
-     &                         Work(ipEorb+mOff),1)
+         call dcopy_(nSsh(iSym),OrbE(ipOrbE+jOff),1,
+     &                         OrbE(ipEorb+mOff),1)
          iOff=iOff+nBas(iSym)**2
          kOff=kOff+nBas(iSym)*nSsh(iSym)
          lOff=lOff+nBas(iSym)
          mOff=mOff+nSsh(iSym)
       End Do
       ortho=.false.
-      Call get_Saa(nSym,nBas,nSsh,Work(ipSQ),Work(ipXMO),Work(ipSaa))
+      Call get_Saa(nSym,nBas,nSsh,SQ,XMO,Saa)
 *
-      Call get_Vir_select(irc,Work(iCMO),Work(ipXMO),Work(ipEorb),
-     &                        Work(ipSQ),Name,NamAct,iWork(iD_vir),
+      Call get_Vir_select(irc,XMO(iCMO),XMO,OrbE(ipEorb),
+     &                        SQ,Name,NamAct,D_vir,
      &                        nSym,nActa,nSsh,nBas,ortho,ns_V)
       If(irc.ne.0) Return
-      Call GetMem('ID_vir','Free','Inte',iD_vir,nBasT)
+      Call mma_deallocate(D_vir)
       iOff=0
       kOff=0
       Do iSym=1,nSym
          jOff=iOff+nBas(iSym)*(nFro(iSym)+nIsh(iSym)+nAsh(iSym))
-         call dcopy_(nBas(iSym)*nSsh(iSym),Work(iCMO+kOff),1,
-     &                                    Work(LCMO+jOff),1)
+         call dcopy_(nBas(iSym)*nSsh(iSym),XMO(iCMO+kOff),1,
+     &                                    CMOX(1+jOff),1)
          iOff=iOff+nBas(iSym)**2
          kOff=kOff+nBas(iSym)*nSsh(iSym)
       End Do
@@ -376,7 +382,7 @@ C     -----------------------------------------------------------
       Do iSym=1,nSym
          Do ik=ns_V(iSym)+1,nSsh(iSym)
             ie=ipEorb+loff+ik-1
-            Work(kEVir+iloc)=Work(ie)
+            OrbE(kEVir+iloc)=OrbE(ie)
             iloc=iloc+1
          End Do
          loff=loff+nSsh(iSym)
@@ -387,7 +393,7 @@ C     -----------------------------------------------------------
          koff=joff+nFro(iSym)+nIsh(iSym)+nAsh(iSym)
          Do ik=0,ns_V(iSym)-1
             ie=ipEorb+loff+ik
-            Work(ipOrbE+koff+ik)=Work(ie)
+            OrbE(ipOrbE+koff+ik)=OrbE(ie)
          End Do
          joff=joff+nBas(iSym)
          loff=loff+nSsh(iSym)
@@ -416,42 +422,43 @@ C     -----------------------------------------------------------
          End Do
          If (Min(iDo,jDo).eq.0) goto 1000
 *
-         Call GetMem('Dmat','Allo','Real',ip_X,nVV+nOA)
+         Call mma_allocate(Dmat,nVV+nOA,Label='DMat')
+         ip_X=1
          ip_Y=ip_X+nVV
-         Call FZero(Work(ip_X),nVV+nOA)
-         Call FZero(Work(iCMO),NCMO)
+         DMat(:)=0.0D0
+         Call FZero(XMO(iCMO),NCMO)
          iOff=0
          Do iSym=1,nSym
-            kfr=LCMO+iOff+nBas(iSym)*nFro(iSym)
+            kfr=1   +iOff+nBas(iSym)*nFro(iSym)
             kto=iCMO+iOff+nBas(iSym)*lnFro(iSym)
-            call dcopy_(nBas(iSym)*lnOcc(iSym),Work(kfr),1,Work(kto),1)
-            kfr=LCMO+iOff+nBas(iSym)*(nFro(iSym)+nIsh(iSym)+nAsh(iSym)
+            call dcopy_(nBas(iSym)*lnOcc(iSym),CMOX(kfr),1,XMO(kto),1)
+            kfr=1+iOff+nBas(iSym)*(nFro(iSym)+nIsh(iSym)+nAsh(iSym)
      &                                                     +ns_V(iSym))
             kto=kto+nBas(iSym)*lnOcc(iSym)
-            call dcopy_(nBas(iSym)*lnVir(iSym),Work(kfr),1,Work(kto),1)
+            call dcopy_(nBas(iSym)*lnVir(iSym),CMOX(kfr),1,XMO(kto),1)
             iOff=iOff+nBas(iSym)**2
          End Do
          Call Check_Amp(nSym,lnOcc,lnVir,iSkip)
          If (iSkip.gt.0) Then
             Call LovCASPT2_putInf(nSym,lnOrb,lnOcc,lnFro,lnDel,lnVir,
      &                            .true.)
-            Call ChoMP2_Drv(irc,Dumm,Work(iCMO),Work(kEOcc),Work(kEVir),
-     &                      Work(ip_X),Work(ip_Y))
+            Call ChoMP2_Drv(irc,Dumm,XMO(iCMO),OrbE(kEOcc),OrbE(kEVir),
+     &                      DMAT(ip_X),DMAT(ip_Y))
             Call LovCASPT2_putInf(nSym,lnOrb,lnOcc,lnFro,lnDel,lnVir,
      &                            .false.)
-            Call ChoMP2_Drv(irc,EMP2,Work(iCMO),Work(kEOcc),Work(kEVir),
-     &                      Work(ip_X),Work(ip_Y))
+            Call ChoMP2_Drv(irc,EMP2,XMO(iCMO),OrbE(kEOcc),OrbE(kEVir),
+     &                      DMAT(ip_X),DMAT(ip_Y))
             If(irc.ne.0) then
               write(6,*) 'Frozen region MP2 failed'
               Call Abend
             Endif
             iV=ip_X
             Do iSym=1,nSym
-             TrF(iSym)=ddot_(lnVir(iSym),Work(iV),1+lnVir(iSym),[One],0)
+             TrF(iSym)=ddot_(lnVir(iSym),DMAT(iV),1+lnVir(iSym),[One],0)
               iV=iV+lnVir(iSym)**2
             End Do
          EndIf
-         Call GetMem('Dmat','Free','Real',ip_X,nVV+nOA)
+         Call mma_deallocate(Dmat)
 1000     Write(6,*)
 
          If (nActa.eq.0) Then
@@ -462,8 +469,8 @@ C     -----------------------------------------------------------
 *                                                                      *
 *----------------------------------------------------------------------*
 
-      Call GetMem('Saa','Free','Real',ipSaa,nOrb)
-      Call GetMem('XMO','Free','Real',ipXmo,2*NCMO)
+      Call mma_deallocate(Saa)
+      Call mma_deallocate(XMO)
 *
 *     Update the nFro, nIsh, nSsh, nDel for the Active site CASPT2
       Do iSym=1,nSym
@@ -476,7 +483,7 @@ C     -----------------------------------------------------------
       End Do
 
       Call Compute_Tr_Dab(nSym,nBas,nFro,nIsh,nAsh,nSsh,nDel,
-     &                    Work(LCMO),Work(ipOrbE),TrA)
+     &                    CMOX,OrbE(ipOrbE),TrA)
 
       write(6,*)'------------------------------------------------------'
       write(6,*)' Symm.  Tr(D):  Active        Frozen        Full      '
@@ -500,13 +507,13 @@ C     -----------------------------------------------------------
 *
       If (DoEnv) Then
          Call energy_AplusB(nSym,nBas,nFro,nIsh,nAsh,nSsh,nDel,
-     &                           Work(LCMO),Work(ipOrbE),E2_Aonly)
+     &                           CMOX,OrbE(ipOrbE),E2_Aonly)
          EMP2 = E2_ab - E2_Aonly
 c         Write(6,'(A,F18.10)')' MP2 correction (environment): ',EMP2
 c         Write(6,*)
       EndIf
 
-      Call GetMem('Eorb','Free','Real',ipOrbE,4*nOrb)
+      Call mma_deallocate(OrbE)
 
 2000  Continue
       If (Min(iDo,jDo).eq.0) Then
@@ -520,31 +527,31 @@ c         Write(6,*)
       EndIf
 *
       IF (IFQCAN.NE.0) IFQCAN=0 ! MOs to be recanonicalized on exit
-      call dcopy_(NCMO,WORK(LCMO),1,CMO,1)
+      call dcopy_(NCMO,CMOX,1,CMO,1)
 
-      CALL GETMEM('LCMO','FREE','REAL',LCMO,2*NCMO)
-      CALL GetMem('SMAT','FREE','REAL',ipSQ,nSQ)
-      Call GetMem('nB_per_Atom','Free','Inte',
-     &            ip_nBas_per_Atom,l_nBas_per_Atom)
-      Call GetMem('nB_Start','Free','Inte',
-     &            ip_nBas_Start,l_nBas_Start)
+      Call mma_deallocate(CMOX)
+      Call mma_deallocate(SQ)
+      Call mma_deallocate(nBas_per_Atom)
+      Call mma_deallocate(nBas_Start)
       Return
       End
 ************************************************************************
 *                                                                      *
 ************************************************************************
       Subroutine get_Saa(nSym,nBas,nOrb,Smn,Xmo,Saa)
+      use stdalloc, only: mma_allocate, mma_deallocate
       Implicit Real*8 (a-h,o-z)
       Integer nSym, nBas(nSym), nOrb(nSym)
       Real*8  Smn(*), Xmo(*), Saa(*)
-#include "WrkSpc.fh"
+
+      Real*8, Allocatable:: Z(:)
 *
 *
       mOb=nBas(1)*nOrb(1)
       Do iSym=2,nSym
          mOb=Max(mOb,nBas(iSym)*nOrb(iSym))
       End Do
-      Call GetMem('Z','Allo','Real',ipZ,mOb)
+      Call mma_allocate(Z,mOb,Label='Z')
 
       iX=1
       kX=1
@@ -554,19 +561,19 @@ c         Write(6,*)
          Call DGEMM_('N','N',nBas(iSym),nOrb(iSym),nBas(iSym),
      &                      1.0d0,Smn(iX),nBx,
      &                            Xmo(kX),nBx,
-     &                      0.0d0,Work(ipZ),nBx)
+     &                      0.0d0,Z,nBx)
          Do j=0,nOrb(iSym)-1
             jK=nBas(iSym)*j
             lk=kX+jK
-            jZ=ipZ+jK
+            jZ=1+jK
             jX=lX+j
-            Saa(jX)=ddot_(nBas(iSym),Xmo(lk),1,Work(jZ),1)
+            Saa(jX)=ddot_(nBas(iSym),Xmo(lk),1,Z(jZ),1)
          End Do
          iX=iX+nBas(iSym)**2
          kX=kX+nBas(iSym)*nOrb(iSym)
          lX=lX+nOrb(iSym)
       End Do
-      Call GetMem('Z','Free','Real',ipZ,mOb)
+      Call mma_deallocate(Z)
 *
       Return
       End
@@ -582,7 +589,7 @@ C
      &                  DoFNO, EOSMP2, ForceBatch, l_Dii, MxQual_Def,
      &                  MxQualMP2, OED_Thr, set_cd_thr, shf, SOS_mp2,
      &                  Span_Def, SpanMP2, ThrMP2, Verbose
-#include "implicit.fh"
+      Implicit REAL*8 (A-H,O-Z)
       Integer lnOrb(8), lnOcc(8), lnFro(8), lnDel(8), lnVir(8)
       Logical isFNO
 C
@@ -620,19 +627,20 @@ C
          l_Dii=l_Dii+nOcc(iSym)
       End Do
 C
-      Return
-      End
+      End SubRoutine LovCASPT2_putInf
 
       Subroutine Energy_AplusB(nSym,nBas,nFro,nIsh,nAsh,nSsh,nDel,
      &                              CMO,OrbE,E2_ab)
 
+      use stdalloc, only: mma_allocate, mma_deallocate
       Implicit Real*8 (a-h,o-z)
       Integer nSym, nBas(nSym), nFro(nSym), nIsh(nSym)
       Integer nAsh(nSym), nSsh(nSym), nDel(nSym)
-      Real*8  CMO(*), OrbE(*)
-#include "WrkSpc.fh"
+      Real*8  CMO(*), OrbE(*), E2_ab
+
       Integer nAct(8), lnOrb(8), lnOcc(8), lnFro(8), lnDel(8), lnVir(8)
       Real*8 Dummy(1)
+      Real*8, Allocatable:: Eorb(:), CMOX(:)
 *
 *
       Call Izero(nAct,nSym)
@@ -659,8 +667,8 @@ C
          nOA=nOA+lnOcc(iSym)
       End Do
 *
-      Call GetMem('EOV','Allo','Real',ipEorb,2*nOrb)
-      kEOcc=ipEorb
+      Call mma_allocate(Eorb,2*nOrb,Label='Eorb')
+      kEOcc=1
       kEVir=kEOcc+nOrb
       ioff=0
       joff=0
@@ -668,32 +676,32 @@ C
       Do iSym=1,nSym
          ifr=1+ioff+nFro(iSym)
          ito=kEOcc+joff
-         call dcopy_(lnOcc(iSym),OrbE(ifr),1,Work(ito),1)
+         call dcopy_(lnOcc(iSym),OrbE(ifr),1,Eorb(ito),1)
          ifr=1+ioff+nFro(iSym)+nIsh(iSym)+nAsh(iSym)
          ito=kEVir+koff
-         call dcopy_(nSsh(iSym),OrbE(ifr),1,Work(ito),1)
+         call dcopy_(nSsh(iSym),OrbE(ifr),1,Eorb(ito),1)
          ioff=ioff+nBas(iSym)
          joff=joff+lnOcc(iSym)
          koff=koff+nSsh(iSym)
       End Do
 *
       Call LovCASPT2_putInf(nSym,lnOrb,lnOcc,lnFro,lnDel,lnVir,.false.)
-      Call GetMem('CMON','Allo','Real',iCMO,nBB)
-      Call FZero(Work(iCMO),nBB)
+      Call mma_allocate(CMOX,nBB,Label='CMOX')
+      CMOX(:)=0.0D0
       iOff=0
       Do iSym=1,nSym
          kfr=1+iOff+nBas(iSym)*nFro(iSym)
-         kto=iCMO+iOff+nBas(iSym)*lnFro(iSym)
-         call dcopy_(nBas(iSym)*lnOcc(iSym),CMO(kfr),1,Work(kto),1)
+         kto=1+iOff+nBas(iSym)*lnFro(iSym)
+         call dcopy_(nBas(iSym)*lnOcc(iSym),CMO(kfr),1,CMOX(kto),1)
          kfr=1+iOff+nBas(iSym)*(nFro(iSym)+nIsh(iSym)+nAsh(iSym))
          kto=kto+nBas(iSym)*lnOcc(iSym)
-         call dcopy_(nBas(iSym)*lnVir(iSym),CMO(kfr),1,Work(kto),1)
+         call dcopy_(nBas(iSym)*lnVir(iSym),CMO(kfr),1,CMOX(kto),1)
          iOff=iOff+nBas(iSym)**2
       End Do
 *
       Call Check_Amp(nSym,lnOcc,lnVir,iSkip)
       If (iSkip.gt.0) Then
-         Call ChoMP2_Drv(irc,E2_ab,Work(iCMO),Work(kEOcc),Work(kEVir),
+         Call ChoMP2_Drv(irc,E2_ab,CMOX,Eorb(kEOcc),Eorb(kEVir),
      &                   Dummy,Dummy)
          If(irc.ne.0) then
            write(6,*) 'MP2 calculation failed in energy_AplusB !'
@@ -706,9 +714,9 @@ C
          write(6,*)'Check your input and rerun the calculation! Bye!!'
          Call Abend
       Endif
-      Call GetMem('CMON','Free','Real',iCMO,nBB)
+      Call mma_deallocate(CMOX)
 *
-      Call GetMem('EOV ','Free','Real',ipEorb,2*nOrb)
+      Call mma_deallocate(Eorb)
 *
       Return
       End
