@@ -17,21 +17,20 @@
 * SWEDEN                                     *
 *--------------------------------------------*
       SUBROUTINE MKBMAT()
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug, verbose
       use stdalloc, only: mma_allocate, mma_deallocate
-      use caspt2_data, only: DREF, PREF
+      use caspt2_global, only: DREF, PREF
+      use caspt2_global, only: LUSOLV, LUSBT
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
 C Set up B matrices for cases 1..13.
 
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
 #include "pt2_guga.fh"
-#include "SysDef.fh"
       REAL*8 DUM(1)
       INTEGER*1, ALLOCATABLE :: idxG3(:,:)
+      REAL*8, ALLOCATABLE:: F1(:), F2(:), F3(:), FD(:), FP(:)
 
 
       IF(IPRGLB.GE.VERBOSE) THEN
@@ -41,20 +40,20 @@ C Set up B matrices for cases 1..13.
 
       IF(NASHT.EQ.0) GOTO 100
 
-      CALL GETMEM('DELTA1','ALLO','REAL',LF1,NG1)
+      CALL mma_allocate(F1,NG1,Label='F1')
       NFD=SIZE(PREF)
-      CALL GETMEM('FD','ALLO','REAL',LFD,NFD)
-      CALL PT2_GET(NG1,'DELTA1',WORK(LF1))
-      CALL MKDREF_RPT2(NASHT,WORK(LF1),WORK(LFD))
-      CALL GETMEM('DELTA1','FREE','REAL',LF1,NG1)
-      CALL GETMEM('DELTA2','ALLO','REAL',LF2,NG2)
-      CALL PT2_GET(NG2,'DELTA2',WORK(LF2))
+      CALL mma_allocate(FD,NFD,Label='FD')
+      CALL PT2_GET(NG1,'DELTA1',F1)
+      CALL MKDREF_RPT2(NASHT,F1,FD)
+      CALL mma_deallocate(F1)
+      CALL mma_allocate(F2,NG2,Label='F2')
+      CALL PT2_GET(NG2,'DELTA2',F2)
       NFP=SIZE(PREF)
-      CALL GETMEM('FP','ALLO','REAL',LFP,NFP)
-      CALL MKPREF_RPT2(NASHT,WORK(LF2),WORK(LFP))
-      CALL GETMEM('DELTA2','FREE','REAL',LF2,NG2)
-      CALL GETMEM('DELTA3','ALLO','REAL',LF3,NG3)
-      CALL PT2_GET(NG3,'DELTA3',WORK(LF3))
+      CALL mma_allocate(FP,NFP,Label='FP')
+      CALL MKPREF_RPT2(NASHT,F2,FP)
+      CALL mma_deallocate(F2)
+      CALL mma_allocate(F3,NG3,Label='F3')
+      CALL PT2_GET(NG3,'DELTA3',F3)
 
       IF(IPRGLB.GE.DEBUG) THEN
         WRITE(6,'("DEBUG> ",A)') 'CASE SYM B-MATRIX NORM'
@@ -65,21 +64,19 @@ C Set up B matrices for cases 1..13.
       iLUID=0
       CALL I1DAFILE(LUSOLV,2,idxG3,6*NG3,iLUID)
 
-      CALL MKBA(DREF,SIZE(DREF),PREF,SIZE(PREF),
-     &          WORK(LFD),WORK(LFP),NG3,WORK(LF3),idxG3)
-      CALL MKBC(DREF,SIZE(DREF),PREF,SIZE(PREF),
-     &          WORK(LFD),WORK(LFP),NG3,WORK(LF3),idxG3)
+      CALL MKBA(DREF,SIZE(DREF),PREF,SIZE(PREF),FD,FP,NG3,F3,idxG3)
+      CALL MKBC(DREF,SIZE(DREF),PREF,SIZE(PREF),FD,FP,NG3,F3,idxG3)
 
-      CALL GETMEM('DELTA3','FREE','REAL',LF3,NG3)
+      CALL mma_deallocate(F3)
       CALL mma_deallocate(idxG3)
 
-      CALL MKBB(DREF,SIZE(DREF),PREF,SIZE(PREF),WORK(LFD),WORK(LFP))
-      CALL MKBD(DREF,SIZE(DREF),PREF,SIZE(PREF),WORK(LFD),WORK(LFP))
-      CALL MKBE(DREF,SIZE(DREF),WORK(LFD))
-      CALL MKBF(DREF,SIZE(DREF),PREF,SIZE(PREF),WORK(LFP))
-      CALL MKBG(DREF,SIZE(DREF),WORK(LFD))
-      CALL GETMEM('FP','FREE','REAL',LFP,NFP)
-      CALL GETMEM('FD','FREE','REAL',LFD,NFD)
+      CALL MKBB(DREF,SIZE(DREF),PREF,SIZE(PREF),FD,FP)
+      CALL MKBD(DREF,SIZE(DREF),PREF,SIZE(PREF),FD,FP)
+      CALL MKBE(DREF,SIZE(DREF),FD)
+      CALL MKBF(DREF,SIZE(DREF),PREF,SIZE(PREF),FP)
+      CALL MKBG(DREF,SIZE(DREF),FD)
+      CALL mma_deallocate(FP)
+      CALL mma_deallocate(FD)
 
  100  CONTINUE
 
@@ -103,18 +100,16 @@ C looping, etc in the rest  of the routines.
 * Case A (ICASE=1)
 ********************************************************************************
       SUBROUTINE MKBA(DREF,NDREF,PREF,NPREF,FD,FP,NG3,F3,idxG3)
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
       USE SUPERINDEX
 #ifdef _MOLCAS_MPP_
       USE Para_Info, ONLY: Is_Real_Par
 #endif
+      use fake_GA, only: GA_Arrays
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
-#include "SysDef.fh"
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
@@ -171,14 +166,12 @@ C Similarly, Fvutxyz= Sum(w)(EPSA(w)<Evutxyzww>, etc.
      &                       NG3,F3,IDXG3)
           END IF
         ELSE
+#endif
           CALL MKBA_DP(DREF,NDREF,PREF,NPREF,FD,FP,
-     &                 ISYM,WORK(lg_BA),1,NAS,1,NAS,0)
-          CALL MKBA_F3(ISYM,WORK(LG_BA),NG3,F3,IDXG3)
+     &                 ISYM,GA_Arrays(lg_BA)%A(:),1,NAS,1,NAS,0)
+          CALL MKBA_F3(ISYM,GA_Arrays(lg_BA)%A(:),NG3,F3,IDXG3)
+#ifdef _MOLCAS_MPP_
         END IF
-#else
-        CALL MKBA_DP(DREF,NDREF,PREF,NPREF,FD,FP,
-     &               ISYM,WORK(lg_BA),1,NAS,1,NAS,0)
-        call MKBA_F3(ISYM,WORK(lg_BA),NG3,F3,idxG3)
 #endif
 
         CALL PSBMAT_WRITE('B',iCase,iSYM,lg_BA,NAS)
@@ -188,21 +181,18 @@ C Similarly, Fvutxyz= Sum(w)(EPSA(w)<Evutxyzww>, etc.
           WRITE(6,'("DEBUG> ",A4,1X,I3,1X,ES21.14)') 'A', ISYM, DBA
         END IF
 
-        CALL PSBMAT_FREEMEM('BA',lg_BA,NAS)
+        CALL PSBMAT_FREEMEM(lg_BA)
       END DO
 
-      END
+      END SUBROUTINE MKBA
 
       SUBROUTINE MKBA_DP (DREF,NDREF,PREF,NPREF,FD,FP,iSYM,
      &                    BA,iLo,iHi,jLo,jHi,LDA)
       USE SUPERINDEX
       use caspt2_global, only:ipea_shift
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
-#include "SysDef.fh"
       INTEGER NDREF, NPREF, iSYM, iLo, iHi, jLo, jHi, LDA
       DIMENSION DREF(NDREF),PREF(NPREF)
       DIMENSION FD(NDREF),FP(NPREF)
@@ -294,19 +284,16 @@ CGG End
           BA(ISADR)=VALUE
         END DO
       END DO
-      END
+      END SUBROUTINE MKBA_DP
 
       SUBROUTINE MKBA_F3(ISYM,BA,NG3,F3,idxG3)
       USE SUPERINDEX
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
-#include "SysDef.fh"
 
-      DIMENSION BA(*)
-      DIMENSION F3(NG3)
+      REAL*8 BA(*)
+      REAL*8 F3(NG3)
       INTEGER*1 idxG3(6,NG3)
 
 C-SVC20100831: determine indices in SA where a certain F3 value will end up
@@ -466,8 +453,7 @@ C  - F(xvzyut) -> BA(yvx,zut)
  500   CONTINUE
       END DO
 
-      RETURN
-      END
+      END SUBROUTINE MKBA_F3
 
 #ifdef _MOLCAS_MPP_
       SUBROUTINE MKBA_F3_MPP(ISYM,BA,iLo,iHi,jLo,jHi,LDA,
@@ -475,12 +461,9 @@ C  - F(xvzyut) -> BA(yvx,zut)
       USE MPI
       USE SUPERINDEX
       use stdalloc, only: mma_MaxDBLE
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
-#include "SysDef.fh"
 
 #include "global.fh"
 #include "mafdecls.fh"
@@ -929,7 +912,7 @@ c Avoid unused argument warnings
       END IF
       END FUNCTION
 
-      END
+      END SUBROUTINE MKBA_F3_MPP
 #endif
 
 ********************************************************************************
@@ -937,17 +920,15 @@ c Avoid unused argument warnings
 ********************************************************************************
       SUBROUTINE MKBC(DREF,NDREF,PREF,NPREF,FD,FP,NG3,F3,idxG3)
       USE SUPERINDEX
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
 #ifdef _MOLCAS_MPP_
       USE Para_Info, ONLY: Is_Real_Par
 #endif
+      use fake_GA, only: GA_Arrays
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
-#include "SysDef.fh"
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
@@ -1006,14 +987,13 @@ C Similarly, Fvutxyz= Sum(w)(EPSA(w)<Evutxyzww>, etc.
      &                       NG3,F3,IDXG3)
           END IF
         ELSE
+#endif
           CALL MKBC_DP(DREF,NDREF,PREF,NPREF,FD,FP,
-     &                 ISYM,WORK(lg_BC),1,NAS,1,NAS,0)
-          CALL MKBC_F3(ISYM,WORK(LG_BC),NG3,F3,IDXG3)
+     &                 ISYM,GA_Arrays(lg_BC)%A(:),1,NAS,1,NAS,0)
+          CALL MKBC_F3(ISYM,GA_Arrays(lg_BC)%A(:),NG3,F3,IDXG3)
+
+#ifdef _MOLCAS_MPP_
         END IF
-#else
-        CALL MKBC_DP(DREF,NDREF,PREF,NPREF,FD,FP,
-     &               ISYM,WORK(lg_BC),1,NAS,1,NAS,0)
-        call MKBC_F3(ISYM,WORK(lg_BC),NG3,F3,idxG3)
 #endif
 
         CALL PSBMAT_WRITE('B',iCase,iSYM,lg_BC,NAS)
@@ -1023,21 +1003,18 @@ C Similarly, Fvutxyz= Sum(w)(EPSA(w)<Evutxyzww>, etc.
           WRITE(6,'("DEBUG> ",A4,1X,I3,1X,ES21.14)') 'C', ISYM, DBC
         END IF
 
-        CALL PSBMAT_FREEMEM('BC',lg_BC,NAS)
+        CALL PSBMAT_FREEMEM(lg_BC)
       END DO
 
-      END
+      END SUBROUTINE MKBC
 
       SUBROUTINE MKBC_DP (DREF,NDREF,PREF,NPREF,FD,FP,iSYM,
      &                    BC,iLo,iHi,jLo,jHi,LDC)
       USE SUPERINDEX
       use caspt2_global, only:ipea_shift
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
-#include "SysDef.fh"
       INTEGER NDREF,NPREF, iSYM,iLo,iHi,jLo,jHi,LDC
       REAL*8 DREF(NDREF),PREF(NPREF)
       REAL*8 FD(NDREF),FP(NPREF)
@@ -1113,16 +1090,13 @@ CGG End
           BC(ISADR)=VALUE
         END DO
       END DO
-      END
+      END SUBROUTINE MKBC_DP
 
       SUBROUTINE MKBC_F3(ISYM,BC,NG3,F3,idxG3)
       USE SUPERINDEX
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
-#include "SysDef.fh"
 
       DIMENSION BC(*)
       DIMENSION F3(NG3)
@@ -1285,8 +1259,7 @@ C  - F(xvzyut) -> BC(zvx,yut)
  500   CONTINUE
       END DO
 
-      RETURN
-      END
+      END SUBROUTINE MKBC_F3
 
 #ifdef _MOLCAS_MPP_
       SUBROUTINE MKBC_F3_MPP(ISYM,BC,iLo,iHi,jLo,jHi,LDC,
@@ -1294,12 +1267,9 @@ C  - F(xvzyut) -> BC(zvx,yut)
       USE MPI
       USE SUPERINDEX
       use stdalloc, only: mma_MaxDBLE
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
-#include "SysDef.fh"
 
 #include "global.fh"
 #include "mafdecls.fh"
@@ -1748,24 +1718,26 @@ c Avoid unused argument warnings
       END IF
       END FUNCTION
 
-      END
+      END SUBROUTINE MKBC_F3_MPP
 #endif
 
       SUBROUTINE MKBB(DREF,NDREF,PREF,NPREF,FD,FP)
       USE SUPERINDEX
       use caspt2_global, only:ipea_shift
+      use caspt2_global, only: LUSBT
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
       IMPLICIT REAL*8 (A-H,O-Z)
 
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
 
-#include "SysDef.fh"
       INTEGER NDREF,NPREF
       REAL*8 DREF(NDREF),PREF(NPREF)
       REAL*8 FD(NDREF),FP(NPREF)
 
+      REAL*8, ALLOCATABLE:: BB(:), BBP(:), SP(:), SDP(:),
+     &                             BBM(:), SM(:), SDM(:)
+
 C Set up the matrices BBP(tu,xy) and BBM(tu,xy)
 C Formulae used:
 C    BB(tu,xy)= 2*( Fyuxt - (A-Et-Eu-Ex-Ey)*Gyuxt )
@@ -1787,7 +1759,7 @@ C Loop over superindex symmetry.
         NAS=NTU(ISYM)
         NBB=(NAS*(NAS+1))/2
         IF(NBB.GT.0) THEN
-          CALL GETMEM('BB','ALLO','REAL',LBB,NBB)
+          CALL mma_allocate(BB,NBB,Label='BB')
         END IF
         DO ITU=1,NAS
           ITUABS=ITU+NTUES(ISYM)
@@ -1849,43 +1821,43 @@ C Add  - 2*dxu ( (A-Et-Eu-Ey)*Dyt - Fyt)
               ATUY=EASUM-ET-EU-EY
               VALUE=VALUE-2.0D0*(ATUY*DREF(ID)-FD(ID))
             END IF
-            WORK(LBB-1+IBADR)=VALUE
+            BB(IBADR)=VALUE
           END DO
         END DO
         NASP=NTGEU(ISYM)
         NBBP=(NASP*(NASP+1))/2
         IF(NBBP.GT.0) THEN
-          CALL GETMEM('BBP','ALLO','REAL',LBBP,NBBP)
-CGG.Nov03  Load in LSDP the diagonal elements of SBP matrix:
+          CALL mma_allocate(BBP,NBBP,Label='BBP')
+CGG.Nov03  Load in SDP the diagonal elements of SBP matrix:
           NSP=(NASP*(NASP+1))/2
-          CALL GETMEM('SP','ALLO','REAL',LSP,NSP)
-          CALL GETMEM('SDP','ALLO','REAL',LSDP,NASP)
+          CALL mma_allocate(SP,NSP,Label='SP')
+          CALL mma_allocate(SDP,NASP,Label='SDP')
           IDSP=IDSMAT(ISYM,2)
-          CALL DDAFILE(LUSBT,2,WORK(LSP),NSP,IDSP)
+          CALL DDAFILE(LUSBT,2,SP,NSP,IDSP)
           IDIAG=0
           DO I=1,NASP
             IDIAG=IDIAG+I
-            WORK(LSDP-1+I)=WORK(LSP-1+IDIAG)
+            SDP(I)=SP(IDIAG)
           END DO
-          CALL GETMEM('SP','FREE','REAL',LSP,NSP)
+          CALL mma_deallocate(SP)
 CGG End
         END IF
         NASM=NTGTU(ISYM)
         NBBM=(NASM*(NASM+1))/2
         IF(NBBM.GT.0) THEN
-          CALL GETMEM('BBM','ALLO','REAL',LBBM,NBBM)
-CGG.Nov03  Load in LSDM the diagonal elements of SBM matrix:
+          CALL mma_allocate(BBM,NBBM,Label='BBM')
+CGG.Nov03  Load in SDM the diagonal elements of SBM matrix:
           NSM=(NASM*(NASM+1))/2
-          CALL GETMEM('SM','ALLO','REAL',LSM,NSM)
-          CALL GETMEM('SDM','ALLO','REAL',LSDM,NASM)
+          CALL mma_allocate(SM,NSM,Label='SM')
+          CALL mma_allocate(SDM,NASM,Label='SDM')
           IDSM=IDSMAT(ISYM,3)
-          CALL DDAFILE(LUSBT,2,WORK(LSM),NSM,IDSM)
+          CALL DDAFILE(LUSBT,2,SM,NSM,IDSM)
           IDIAG=0
           DO I=1,NASM
             IDIAG=IDIAG+I
-            WORK(LSDM-1+I)=WORK(LSM-1+IDIAG)
+            SDM(I)=SM(IDIAG)
           END DO
-          CALL GETMEM('SM','FREE','REAL',LSM,NSM)
+          CALL mma_deallocate(SM)
 CGG End
         END IF
         INSM=1
@@ -1905,21 +1877,21 @@ CGG End
             ELSE
               IBADR=(IXY*(IXY-1))/2+ITU
             END IF
-            BTUXY=WORK(LBB-1+IBADR)
+            BTUXY=BB(IBADR)
             IF(ITU.GE.IYX) THEN
               IBADR=(ITU*(ITU-1))/2+IYX
             ELSE
               IBADR=(IYX*(IYX-1))/2+ITU
             END IF
-            BTUYX=WORK(LBB-1+IBADR)
+            BTUYX=BB(IBADR)
             IBPADR=(ITGEU*(ITGEU-1))/2+IXGEY
-            WORK(LBBP-1+IBPADR)=BTUXY+BTUYX
+            BBP(IBPADR)=BTUXY+BTUYX
 CGG.Nov03
             IF (ITGEU.eq.IXGEY) THEN
               IDT=(ITABS*(ITABS+1))/2
               IDU=(IUABS*(IUABS+1))/2
-              WORK(LBBP-1+IBPADR)=WORK(LBBP-1+IBPADR)+ipea_shift*0.5d0*
-     &                          (DREF(IDT)+DREF(IDU))*WORK(LSDP-1+ITGEU)
+              BBP(IBPADR)=BBP(IBPADR)+ipea_shift*0.5d0*
+     &                          (DREF(IDT)+DREF(IDU))*SDP(ITGEU)
             ENDIF
 CGG End
             IF(ITABS.EQ.IUABS) GOTO 200
@@ -1927,64 +1899,61 @@ CGG End
             ITGTU=KTGTU(ITABS,IUABS)-NTGTUES(ISYM)
             IXGTY=KTGTU(IXABS,IYABS)-NTGTUES(ISYM)
             IBMADR=(ITGTU*(ITGTU-1))/2+IXGTY
-            WORK(LBBM-1+IBMADR)=BTUXY-BTUYX
+            BBM(IBMADR)=BTUXY-BTUYX
 CGG.Nov03
             IF (ITGEU.eq.IXGEY) THEN
               IDT=(ITABS*(ITABS+1))/2
               IDU=(IUABS*(IUABS+1))/2
-              WORK(LBBM-1+IBMADR)=WORK(LBBM-1+IBMADR)+ipea_shift*0.5d0*
-     &                           (DREF(IDT)+DREF(IDU))*WORK(LSDM-1+INSM)
+              BBM(IBMADR)=BBM(IBMADR)+ipea_shift*0.5d0*
+     &                           (DREF(IDT)+DREF(IDU))*SDM(INSM)
               INSM=INSM+1
             ENDIF
 CGG.End
  200        CONTINUE
           END DO
         END DO
-        IF(NBB.GT.0) THEN
-          CALL GETMEM('BB','FREE','REAL',LBB,NBB)
-        END IF
+        IF(NBB.GT.0) CALL mma_deallocate(BB)
 
 C Write to disk, and save size and address.
         IF(NBBP.GT.0.and.NINDEP(ISYM,2).GT.0) THEN
           IDISK=IDBMAT(ISYM,2)
-          CALL DDAFILE(LUSBT,1,WORK(LBBP),NBBP,IDISK)
-          CALL GETMEM('BBP','FREE','REAL',LBBP,NBBP)
-CGG.Nov03 DisAlloc LSDP
-          CALL GETMEM('SDP','FREE','REAL',LSDP,NASP)
+          CALL DDAFILE(LUSBT,1,BBP,NBBP,IDISK)
+          CALL mma_deallocate(BBP)
+CGG.Nov03 DisAlloc SDP
+          CALL mma_deallocate(SDP)
 CGG End
         END IF
         IF(NBBM.GT.0) THEN
           IF(NINDEP(ISYM,3).GT.0) THEN
             IDISK=IDBMAT(ISYM,3)
-            CALL DDAFILE(LUSBT,1,WORK(LBBM),NBBM,IDISK)
+            CALL DDAFILE(LUSBT,1,BBM,NBBM,IDISK)
           END IF
-          CALL GETMEM('BBM','FREE','REAL',LBBM,NBBM)
-CGG.Nov03 DisAlloc LSDM
-          CALL GETMEM('SDM','FREE','REAL',LSDM,NASM)
+          CALL mma_deallocate(BBM)
+CGG.Nov03 DisAlloc SDM
+          CALL mma_deallocate(SDM)
 CGG End
         END IF
  1000 CONTINUE
       END DO
 
-
-      RETURN
-      END
+      END SUBROUTINE MKBB
 
       SUBROUTINE MKBD(DREF,NDREF,PREF,NPREF,FD,FP)
       USE SUPERINDEX
       use caspt2_global, only:ipea_shift
+      use caspt2_global, only:LUSBT
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
       IMPLICIT REAL*8 (A-H,O-Z)
 
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
 
-#include "SysDef.fh"
       INTEGER NDREF,NPREF
       REAL*8 DREF(NDREF),PREF(NPREF)
       REAL*8 FD(NDREF),FP(NPREF)
 
+      REAL*8, ALLOCATABLE:: BD(:), S(:), SD(:)
+
 C Set up the matrix BD(tuP,xyQ),P and Q are 1 or 2,
 C Formulae used:
 C    BD(tu1,xy1)=
@@ -2002,20 +1971,20 @@ C Loop over superindex symmetry.
         NAS=NTU(ISYM)
         NBD=(2*NAS*(2*NAS+1))/2
         IF(NBD.GT.0) THEN
-          CALL GETMEM('BD','ALLO','REAL',LBD,NBD)
-CGG.Nov03  Load in LSD the diagonal elements of SD matrix:
+          CALL mma_allocate(BD,NBD,Label='BD')
+CGG.Nov03  Load in SD the diagonal elements of SD matrix:
           NS2=(2*NAS*(2*NAS+1))/2
           NAS2=2*NAS
-          CALL GETMEM('S','ALLO','REAL',LS,NS2)
-          CALL GETMEM('SD','ALLO','REAL',LSD,NAS2)
+          CALL mma_allocate(S,NS2,Label='S')
+          CALL mma_allocate(SD,NAS2,Label='SD')
           IDS=IDSMAT(ISYM,5)
-          CALL DDAFILE(LUSBT,2,WORK(LS),NS2,IDS)
+          CALL DDAFILE(LUSBT,2,S,NS2,IDS)
           IDIAG=0
           DO I=1,NAS2
             IDIAG=IDIAG+I
-            WORK(LSD-1+I)=WORK(LS-1+IDIAG)
+            SD(I)=S(IDIAG)
           END DO
-          CALL GETMEM('S','FREE','REAL',LS,NS2)
+          CALL mma_deallocate(S)
 CGG End
         END IF
         DO ITU=1,NAS
@@ -2056,18 +2025,18 @@ CGG End
               B11=B11+2.0D0*(FUY+(ET-EASUM)*DUY)
               B22=B22+2.0D0*(FUY+(EX-EASUM)*DUY)
             END IF
-            WORK(LBD-1+IB11)= B11
-            WORK(LBD-1+IB21)=-0.5D0*B11
-            WORK(LBD-1+IB12)=-0.5D0*B11
-            WORK(LBD-1+IB22)= B22
+            BD(IB11)= B11
+            BD(IB21)=-0.5D0*B11
+            BD(IB12)=-0.5D0*B11
+            BD(IB22)= B22
 CGG.Nov03
             IF (ITU.eq.IXY) THEN
               IDT=(ITABS*(ITABS+1))/2
               IDU=(IUABS*(IUABS+1))/2
-              WORK(LBD-1+IB11)=WORK(LBD-1+IB11)+ipea_shift*0.5d0*
-     &                       (2.0d0-DREF(IDU)+DREF(IDT))*WORK(LSD-1+ITU)
-              WORK(LBD-1+IB22)=WORK(LBD-1+IB22)+ipea_shift*0.5d0*
-     &                   (2.0d0-DREF(IDU)+DREF(IDT))*WORK(LSD-1+ITU+NAS)
+              BD(IB11)=BD(IB11)+ipea_shift*0.5d0*
+     &                       (2.0d0-DREF(IDU)+DREF(IDT))*SD(ITU)
+              BD(IB22)=BD(IB22)+ipea_shift*0.5d0*
+     &                   (2.0d0-DREF(IDU)+DREF(IDT))*SD(ITU+NAS)
             ENDIF
 CGG End
           END DO
@@ -2076,33 +2045,32 @@ CGG End
 C Write to disk
         IF(NBD.GT.0.and.NINDEP(ISYM,5).GT.0) THEN
           IDISK=IDBMAT(ISYM,5)
-C          CALL DAFILE(LUSBT,1,WORK(LBD),RtoI*NBD,IDISK)
-          CALL DDAFILE(LUSBT,1,WORK(LBD),NBD,IDISK)
-          CALL GETMEM('BD','FREE','REAL',LBD,NBD)
-CGG.Nov03 DisAlloc LSD
-          CALL GETMEM('SD','FREE','REAL',LSD,NAS2)
+          CALL DDAFILE(LUSBT,1,BD,NBD,IDISK)
+          CALL mma_deallocate(BD)
+CGG.Nov03 DisAlloc SD
+          CALL mma_deallocate(SD)
 CGG End
         END IF
  1000 CONTINUE
       END DO
 
 
-      RETURN
-      END
+      END SUBROUTINE MKBD
 
       SUBROUTINE MKBE(DREF,NDREF,FD)
       use caspt2_global, only:ipea_shift
+      use caspt2_global, only:LUSBT
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
       IMPLICIT REAL*8 (A-H,O-Z)
 
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
 
-#include "SysDef.fh"
       INTEGER NDREF
       REAL*8 DREF(NDREF),FD(NDREF)
 
+      Real*8, ALLOCATABLE:: BE(:), S(:), SD(:)
+
 C Set up the matrix BE(t,x)
 C Formula used:
 C    BE(t,x)=-Ftx + (EASUM-Ex-Et)*Dtx
@@ -2116,19 +2084,19 @@ C            + 2dtx Ex
         NAS=NASH(ISYM)
         NBE=(NAS*(NAS+1))/2
         IF(NBE.GT.0) THEN
-          CALL GETMEM('BE','ALLO','REAL',LBE,NBE)
-CGG.Nov03  Load in LSD the diagonal elements of SE matrix:
+          CALL mma_allocate(BE,NBE,LABEL='BE')
+CGG.Nov03  Load in SD the diagonal elements of SE matrix:
           NS=(NAS*(NAS+1))/2
-          CALL GETMEM('S','ALLO','REAL',LS,NS)
-          CALL GETMEM('SD','ALLO','REAL',LSD,NAS)
+          CALL mma_allocate(S,NS,Label='S')
+          CALL mma_allocate(SD,NAS,Label='SD')
           IDS=IDSMAT(ISYM,6)
-          CALL DDAFILE(LUSBT,2,WORK(LS),NS,IDS)
+          CALL DDAFILE(LUSBT,2,S,NS,IDS)
           IDIAG=0
           DO I=1,NAS
             IDIAG=IDIAG+I
-            WORK(LSD-1+I)=WORK(LS-1+IDIAG)
+            SD(I)=S(IDIAG)
           END DO
-          CALL GETMEM('S','FREE','REAL',LS,NS)
+          CALL mma_deallocate(S)
         ENDIF
 CGG End
         DO IT=1,NAS
@@ -2146,49 +2114,48 @@ CGG End
 CGG.Nov03
             IF (IT.eq.IX) THEN
               IDT=(ITABS*(ITABS+1))/2
-              VALUE=VALUE+ipea_shift*0.5d0*DREF(IDT)*WORK(LSD-1+IT)
+              VALUE=VALUE+ipea_shift*0.5d0*DREF(IDT)*SD(IT)
             ENDIF
 CGG End
-            WORK(LBE-1+IBE)=VALUE
+            BE(IBE)=VALUE
           END DO
         END DO
 
 C Write to disk
         IF(NBE.GT.0.and.NINDEP(ISYM,6).GT.0) THEN
           IDISK=IDBMAT(ISYM,6)
-C          CALL DAFILE(LUSBT,1,WORK(LBE),RtoI*NBE,IDISK)
-          CALL DDAFILE(LUSBT,1,WORK(LBE),NBE,IDISK)
+          CALL DDAFILE(LUSBT,1,BE,NBE,IDISK)
           IF(NINM.GT.0.and.NINDEP(ISYM,7).GT.0) THEN
             IDISK=IDBMAT(ISYM,7)
-C            CALL DAFILE(LUSBT,1,WORK(LBE),RtoI*NBE,IDISK)
-            CALL DDAFILE(LUSBT,1,WORK(LBE),NBE,IDISK)
+            CALL DDAFILE(LUSBT,1,BE,NBE,IDISK)
           END IF
-          CALL GETMEM('BE','FREE','REAL',LBE,NBE)
-CGG.Nov03 DisAlloc LSD
-          CALL GETMEM('SD','FREE','REAL',LSD,NAS)
+          CALL mma_deallocate(BE)
+CGG.Nov03 DisAlloc SD
+          CALL mma_deallocate(SD)
 CGG End
         END IF
  1000 CONTINUE
       END DO
 
-
-      RETURN
-      END
+      END SUBROUTINE MKBE
 
       SUBROUTINE MKBF(DREF,NDREF,PREF,NPREF,FP)
       USE SUPERINDEX
       use caspt2_global, only:ipea_shift
+      use caspt2_global, only:LUSBT
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
       IMPLICIT REAL*8 (A-H,O-Z)
 
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
 
-#include "SysDef.fh"
       INTEGER NDREF,NPREF
       REAL*8 PREF(NPREF),FP(NPREF),DREF(NDREF)
 
+      REAL*8, ALLOCATABLE:: BF(:), BFP(:), SDP(:),
+     &                      SP(:), BFM(:), SDM(:),
+     &                      SM(:)
+
 C Set up the matrices BFP(tu,xy) and BFM(tu,xy)
 C Formulae used:
 C    BF(tu,xy)= 2*(Ftxuy - EASUM*Gtxuy)
@@ -2203,7 +2170,7 @@ C Loop over superindex symmetry.
         NAS=NTU(ISYM)
         NBF=(NAS*(NAS+1))/2
         IF(NBF.GT.0) THEN
-          CALL GETMEM('BF','ALLO','REAL',LBF,NBF)
+          CALL mma_allocate(BF,NBF,LABEL='BF')
         END IF
         DO ITU=1,NAS
           ITUABS=ITU+NTUES(ISYM)
@@ -2219,43 +2186,43 @@ C Loop over superindex symmetry.
             IP1=MAX(ITX,IUY)
             IP2=MIN(ITX,IUY)
             IP=(IP1*(IP1-1))/2+IP2
-            WORK(LBF-1+IBADR)=4.0D0*(FP(IP)-EASUM*PREF(IP))
+            BF(IBADR)=4.0D0*(FP(IP)-EASUM*PREF(IP))
           END DO
         END DO
         NASP=NTGEU(ISYM)
         NBFP=(NASP*(NASP+1))/2
         IF(NBFP.GT.0) THEN
-          CALL GETMEM('BFP','ALLO','REAL',LBFP,NBFP)
-CGG.Nov03  Load in LSDP the diagonal elements of SFP matrix:
+          CALL mma_allocate(BFP,NBFP,Label='BFP')
+CGG.Nov03  Load in SDP the diagonal elements of SFP matrix:
           NSP=(NASP*(NASP+1))/2
-          CALL GETMEM('SP','ALLO','REAL',LSP,NSP)
-          CALL GETMEM('SDP','ALLO','REAL',LSDP,NASP)
+          CALL mma_allocate(SP,NSP,Label='SP')
+          CALL mma_allocate(SDP,NASP,Label='SDP')
           IDSP=IDSMAT(ISYM,8)
-          CALL DDAFILE(LUSBT,2,WORK(LSP),NSP,IDSP)
+          CALL DDAFILE(LUSBT,2,SP,NSP,IDSP)
           IDIAG=0
           DO I=1,NASP
             IDIAG=IDIAG+I
-            WORK(LSDP-1+I)=WORK(LSP-1+IDIAG)
+            SDP(I)=SP(IDIAG)
           END DO
-          CALL GETMEM('SP','FREE','REAL',LSP,NSP)
+          CALL mma_deallocate(SP)
 CGG End
         END IF
         NASM=NTGTU(ISYM)
         NBFM=(NASM*(NASM+1))/2
         IF(NBFM.GT.0) THEN
-          CALL GETMEM('BFM','ALLO','REAL',LBFM,NBFM)
-CGG.Nov03  Load in LSDM the diagonal elements of SFM matrix:
+          CALL mma_allocate(BFM,NBFM,Label='BFM')
+CGG.Nov03  Load in SDM the diagonal elements of SFM matrix:
           NSM=(NASM*(NASM+1))/2
-          CALL GETMEM('SM','ALLO','REAL',LSM,NSM)
-          CALL GETMEM('SDM','ALLO','REAL',LSDM,NASM)
+          CALL mma_allocate(SM,NSM,Label='SM')
+          CALL mma_allocate(SDM,NASM,Label='SDM')
           IDSM=IDSMAT(ISYM,9)
-          CALL DDAFILE(LUSBT,2,WORK(LSM),NSM,IDSM)
+          CALL DDAFILE(LUSBT,2,SM,NSM,IDSM)
           IDIAG=0
           DO I=1,NASM
             IDIAG=IDIAG+I
-            WORK(LSDM-1+I)=WORK(LSM-1+IDIAG)
+            SDM(I)=SM(IDIAG)
           END DO
-          CALL GETMEM('SM','FREE','REAL',LSM,NSM)
+          CALL mma_deallocate(SM)
 CGG End
         END IF
         INSM=1
@@ -2275,21 +2242,21 @@ CGG End
             ELSE
               IBADR=(IXY*(IXY-1))/2+ITU
             END IF
-            BTUXY=WORK(LBF-1+IBADR)
+            BTUXY=BF(IBADR)
             IF(ITU.GE.IYX) THEN
               IBADR=(ITU*(ITU-1))/2+IYX
             ELSE
               IBADR=(IYX*(IYX-1))/2+ITU
             END IF
-            BTUYX=WORK(LBF-1+IBADR)
+            BTUYX=BF(IBADR)
             IBPADR=(ITGEU*(ITGEU-1))/2+IXGEY
-            WORK(LBFP-1+IBPADR)=BTUXY+BTUYX
+            BFP(IBPADR)=BTUXY+BTUYX
 CGG.Nov03
             IF (ITGEU.eq.IXGEY) THEN
               IDT=(ITABS*(ITABS+1))/2
               IDU=(IUABS*(IUABS+1))/2
-              WORK(LBFP-1+IBPADR)=WORK(LBFP-1+IBPADR)+ipea_shift*0.5d0*
-     &                    (4.0d0-DREF(IDT)-DREF(IDU))*WORK(LSDP-1+ITGEU)
+              BFP(IBPADR)=BFP(IBPADR)+ipea_shift*0.5d0*
+     &                    (4.0d0-DREF(IDT)-DREF(IDU))*SDP(ITGEU)
             ENDIF
 CGG End
             IF(ITABS.EQ.IUABS) GOTO 200
@@ -2297,63 +2264,59 @@ CGG End
             ITGTU=KTGTU(ITABS,IUABS)-NTGTUES(ISYM)
             IXGTY=KTGTU(IXABS,IYABS)-NTGTUES(ISYM)
             IBMADR=(ITGTU*(ITGTU-1))/2+IXGTY
-            WORK(LBFM-1+IBMADR)=BTUXY-BTUYX
+            BFM(IBMADR)=BTUXY-BTUYX
 CGG.Nov03
             IF (ITGEU.eq.IXGEY) THEN
               IDT=(ITABS*(ITABS+1))/2
               IDU=(IUABS*(IUABS+1))/2
-              WORK(LBFM-1+IBMADR)=WORK(LBFM-1+IBMADR)+ipea_shift*0.5d0*
-     &                    (4.0d0-DREF(IDT)-DREF(IDU))*WORK(LSDM-1+INSM)
+              BFM(IBMADR)=BFM(IBMADR)+ipea_shift*0.5d0*
+     &                    (4.0d0-DREF(IDT)-DREF(IDU))*SDM(INSM)
               INSM=INSM+1
             ENDIF
 
  200        CONTINUE
           END DO
         END DO
-        IF(NBF.GT.0) THEN
-          CALL GETMEM('BF','FREE','REAL',LBF,NBF)
-        END IF
+        IF(NBF.GT.0) CALL mma_deallocate(BF)
 
 C Write to disk
         IF(NBFP.GT.0.and.NINDEP(ISYM,8).GT.0) THEN
           IDISK=IDBMAT(ISYM,8)
-C          CALL DAFILE(LUSBT,1,WORK(LBFP),RtoI*NBFP,IDISK)
-          CALL DDAFILE(LUSBT,1,WORK(LBFP),NBFP,IDISK)
-          CALL GETMEM('BFP','FREE','REAL',LBFP,NBFP)
-CGG.Nov03 DisAlloc LSDP
-          CALL GETMEM('SDP','FREE','REAL',LSDP,NASP)
+          CALL DDAFILE(LUSBT,1,BFP,NBFP,IDISK)
+          CALL mma_deallocate(BFP)
+CGG.Nov03 DisAlloc SDP
+          CALL mma_deallocate(SDP)
 CGG End
         END IF
         IF(NBFM.GT.0) THEN
          IF(NINDEP(ISYM,9).GT.0) THEN
           IDISK=IDBMAT(ISYM,9)
-          CALL DDAFILE(LUSBT,1,WORK(LBFM),NBFM,IDISK)
+          CALL DDAFILE(LUSBT,1,BFM,NBFM,IDISK)
          END IF
-         CALL GETMEM('BFM','FREE','REAL',LBFM,NBFM)
-CGG.Nov03 DisAlloc LSDM
-         CALL GETMEM('SDM','FREE','REAL',LSDM,NASM)
+         CALL mma_deallocate(BFM)
+CGG.Nov03 DisAlloc SDM
+         CALL mma_deallocate(SDM)
 CGG End
         END IF
  1000 CONTINUE
       END DO
 
-
-      RETURN
-      END
+      END SUBROUTINE MKBF
 
       SUBROUTINE MKBG(DREF,NDREF,FD)
       use caspt2_global, only:ipea_shift
+      use caspt2_global, only:LUSBT
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
       IMPLICIT REAL*8 (A-H,O-Z)
 
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "eqsolv.fh"
-#include "WrkSpc.fh"
 
-#include "SysDef.fh"
       INTEGER NDREF
       REAL*8 DREF(NDREF),FD(NDREF)
 
+      REAL*8, ALLOCATABLE:: BG(:), S(:), SD(:)
+
 C     Set up the matrix BG(t,x)
 C     Formula used:
 C     BG(t,x)= Ftx -EASUM*Dtx
@@ -2366,19 +2329,19 @@ C     BG(t,x)= Ftx -EASUM*Dtx
         NAS=NASH(ISYM)
         NBG=(NAS*(NAS+1))/2
         IF(NBG.GT.0) THEN
-          CALL GETMEM('BG','ALLO','REAL',LBG,NBG)
-CGG.Nov03  Load in LSD the diagonal elements of SG matrix:
+          CALL mma_Allocate(BG,NBG,LABEL='BG')
+CGG.Nov03  Load in SD the diagonal elements of SG matrix:
           NS=(NAS*(NAS+1))/2
-          CALL GETMEM('S','ALLO','REAL',LS,NS)
-          CALL GETMEM('SD','ALLO','REAL',LSD,NAS)
+          CALL mma_allocate(S,NS,Label='S')
+          CALL mma_allocate(SD,NAS,Label='SD')
           IDS=IDSMAT(ISYM,10)
-          CALL DDAFILE(LUSBT,2,WORK(LS),NS,IDS)
+          CALL DDAFILE(LUSBT,2,S,NS,IDS)
           IDIAG=0
           DO I=1,NAS
             IDIAG=IDIAG+I
-            WORK(LSD-1+I)=WORK(LS-1+IDIAG)
+            SD(I)=S(IDIAG)
           END DO
-          CALL GETMEM('S','FREE','REAL',LS,NS)
+          CALL mma_deallocate(S)
         ENDIF
 CGG End
         DO IT=1,NAS
@@ -2392,10 +2355,10 @@ CGG.Nov03
             IF (IT.eq.IX) THEN
               IDT=(ITABS*(ITABS+1))/2
               VALUE = VALUE +
-     &                ipea_shift*0.5d0*(2.0d0-DREF(IDT))*WORK(LSD-1+IT)
+     &                ipea_shift*0.5d0*(2.0d0-DREF(IDT))*SD(IT)
             ENDIF
-            WORK(LBG-1+IBG)=VALUE
-C           WORK(LBG-1+IBG)=FD(ID)-EASUM*DREF(ID)
+            BG(IBG)=VALUE
+C           BG(BG)=FD(ID)-EASUM*DREF(ID)
 CGG End
           END DO
         END DO
@@ -2404,20 +2367,18 @@ C Write to disk, and save size and address.
         IF(NBG.GT.0) THEN
          IF(NINDEP(ISYM,10).GT.0) THEN
           IDISK=IDBMAT(ISYM,10)
-          CALL DDAFILE(LUSBT,1,WORK(LBG),NBG,IDISK)
+          CALL DDAFILE(LUSBT,1,BG,NBG,IDISK)
          END IF
          IF(NINM.GT.0.and.NINDEP(ISYM,11).GT.0) THEN
            IDISK=IDBMAT(ISYM,11)
-           CALL DDAFILE(LUSBT,1,WORK(LBG),NBG,IDISK)
+           CALL DDAFILE(LUSBT,1,BG,NBG,IDISK)
          END IF
-CGG.Nov03 DisAlloc LSD
-         CALL GETMEM('SD','FREE','REAL',LSD,NAS)
+CGG.Nov03 DisAlloc SD
+         CALL mma_deallocate(SD)
 CGG End
-         CALL GETMEM('BG','FREE','REAL',LBG,NBG)
+         CALL mma_deallocate(BG)
         END IF
  1000 CONTINUE
       END DO
 
-
-      RETURN
-      END
+      END SUBROUTINE MKBG
