@@ -36,19 +36,14 @@ C
 
 #if defined (_ENABLE_BLOCK_DMRG_) || defined (_ENABLE_CHEMPS2_DMRG_)
       SUBROUTINE MKFG3DM(IFF,G1,F1,G2,F2,G3,F3,idxG3,NLEV)
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug, verbose
-#if defined (_MOLCAS_MPP_) && ! defined (_GA_)
-      USE Para_Info, ONLY: nProcs, Is_Real_Par, King
-#endif
       use gugx, only: CIS, SGS, L2ACT
-      use stdalloc, only: mma_MaxDBLE
+      use stdalloc, only: mma_MaxDBLE, mma_allocate, mma_deallocate
       IMPLICIT NONE
-#include "rasdim.fh"
 #include "caspt2.fh"
 #include "SysDef.fh"
 #include "pt2_guga.fh"
-#include "WrkSpc.fh"
 
       INTEGER, INTENT(IN) :: IFF, NLEV
       REAL*8, INTENT(OUT) :: G1(NLEV,NLEV),G2(NLEV,NLEV,NLEV,NLEV)
@@ -69,17 +64,16 @@ C
       INTEGER ISTU,ISVX,ISYZ
       INTEGER IT,IU,IV,IX,IY,IZ
       INTEGER ITLEV,IULEV,IVLEV,IXLEV,IYLEV,IZLEV
-      INTEGER LBUF1,LBUF2,LBUFD,LBUFT
-      INTEGER NBUF1,NBUF2,NBUFD,NBUFT
-      INTEGER LIBUF1,LIP1STA,LIP1END,LOFFSET,IOFFSET
+      INTEGER NBUF1
+      INTEGER IOFFSET
       INTEGER ISSG1,ISSG2,ISP1
-      INTEGER ITASK,ISUBTASK,ID,NTASKS,NSUBTASKS,
-     &        LTASK_LIST,MXTASK,MYTASK,MYBUFFER
+      INTEGER ITASK,ISUBTASK,ID,NTASKS,NSUBTASKS,MXTASK,MYTASK,MYBUFFER
       INTEGER NTRI1,NTRI2
       INTEGER MEMMAX, MEMMAX_SAFE
       INTEGER NLEV2
 #ifdef _ENABLE_BLOCK_DMRG_
-      INTEGER NLEV4,LG3TMP
+      INTEGER NLEV4
+      REAL*8, ALLOCATABLE:: G3Tmp(:)
 #endif
       INTEGER NCI
 
@@ -91,6 +85,9 @@ C
       INTEGER ICNJ(MXLEV**2)
       INTEGER IP1_BUF(MXLEV**2)
 
+      REAL*8, ALLOCATABLE:: BUF1(:,:), BUF2(:), BUFT(:), BUFD(:)
+      INTEGER, ALLOCATABLE:: TaskList(:,:)
+
 
       ! result buffer, maximum size is the largest possible ip1 range,
       ! which is set to nbuf1 later, i.e. a maximum of nlev2 <= mxlev**2
@@ -160,21 +157,14 @@ C Special pair index idx2ij allows true RAS cases to be handled:
 *
 *
       nbuf1=max(1,min(nlev2,(memmax_safe-3*mxci)/mxci)) ! -> 1 w/ DMRG?
-      nbuf2= 1
-      nbuft= 1
-      nbufd= 1
-      CALL GETMEM('BUF1','ALLO','REAL',LBUF1,NBUF1*MXCI)
-      CALL GETMEM('BUF2','ALLO','REAL',LBUF2,NBUF2*MXCI)
-      CALL GETMEM('BUFT','ALLO','REAL',LBUFT,NBUFT*MXCI)
-      CALL GETMEM('BUFD','ALLO','REAL',LBUFD,NBUFD*MXCI)
+      CALL mma_allocate(BUF1,MXCI,NBUF1,LABEL='BUF1')
+      CALL mma_allocate(BUF2,MXCI,LABEL='BUF2')
+      CALL mma_allocate(BUFT,MXCI,LABEL='BUFT')
+      CALL mma_allocate(BUFD,MXCI,LABEL='BUFD')
 
 C-SVC20100301: calculate maximum number of tasks possible
       MXTASK=(NTRI2-1)/NBUF1+1+(NTRI1-1)/NBUF1+1
-      CALL GETMEM ('TASKLIST','ALLO','INTE',lTask_List,4*mxTask)
-      lip1sta=lTask_List
-      lip1end=lTask_List+mxTask
-      libuf1=lTask_List+2*mxTask
-      lOffSet=lTask_List+3*mxTask
+      CALL mma_allocate (TaskList,mxTask,4,LABEL='TaskList')
 
       IF(iPrGlb.GE.VERBOSE) THEN
         WRITE(6,*)
@@ -192,7 +182,7 @@ C-SVC20100301: calculate maximum number of tasks possible
       DO issg1=1,nsym
        isp1=mul(issg1,stsym)
 *      nsgm1=CIS%ncsf(issg1)
-*      CALL H0DIAG_CASPT2(ISSG1,WORK(LBUFD),NOW1,IOW1,NMIDV)
+*      CALL H0DIAG_CASPT2(ISSG1,BUFD,NOW1,IOW1,NMIDV)
 
 C-SVC20100301: calculate number of larger tasks for this symmetry, this
 C-is basically the number of buffers we fill with sigma1 vectors.
@@ -205,12 +195,12 @@ C-is basically the number of buffers we fill with sigma1 vectors.
         IF (istu.EQ.isp1) THEN
           ibuf1=ibuf1+1
           ip1_buf(ibuf1)=ip1
-          IF (ibuf1.EQ.1) iwork(lip1sta+iTask-1)=ip1
+          IF (ibuf1.EQ.1) TaskList(iTask,1)=ip1
         ENDIF
         IF (ibuf1.EQ.nbuf1.OR.(ibuf1.GT.0.AND.
      &         (ip1.EQ.ntri2.OR.ip1.EQ.nlev2))) THEN
-            iwork(lip1end+iTask-1)=ip1_buf(ibuf1)
-            iwork(libuf1+iTask-1)=ibuf1
+            TaskList(iTask,2)=ip1_buf(ibuf1)
+            TaskList(iTask,3)=ibuf1
             iTask=iTask+1
             ibuf1=0
         ENDIF
@@ -220,9 +210,9 @@ C-is basically the number of buffers we fill with sigma1 vectors.
 C-SVC20100309: calculate number of inner loop iteration tasks.
       iOffSet=0
       DO iTask=1,nTasks
-        iWork(lOffSet+iTask-1)=iOffSet
-        ip1sta=iwork(lip1sta+iTask-1)
-        ip1end=iwork(lip1end+iTask-1)
+        TaskList(iTask,4)=iOffSet
+        ip1sta=TaskList(iTask,1)
+        ip1end=TaskList(iTask,2)
         ip3mx=ntri2
         if(ip1end.le.ntri2) ip3mx=ip1end
         if(ip1sta.gt.ntri2) ip3mx=ntri1
@@ -277,7 +267,7 @@ C-SVC20100302: BEGIN SEPARATE TASK EXECUTION
 
       myTask=nTasks
       DO iTask=1,nTasks
-        iBuf=iSubTask-iWork(lOffSet+iTask-1)
+        iBuf=iSubTask-TaskList(iTask,4)
         IF (iBuf.LE.0) THEN
           myTask=iTask-1
           goto 666
@@ -286,13 +276,13 @@ C-SVC20100302: BEGIN SEPARATE TASK EXECUTION
 666   continue
       iTask=myTask
 
-      iOffSet=iWork(lOffSet+iTask-1)
+      iOffSet=TaskList(iTask,4)
 
 C-SVC20100310: one task handles a range of ip1 values
 C-that are in the buffer and one ip3 value, for which
 C-a loop over ip2 values is then executed.
-      ip1sta=iWork(lip1sta+iTask-1)
-      ip1end=iWork(lip1end+iTask-1)
+      ip1sta=TaskList(iTask,1)
+      ip1end=TaskList(iTask,2)
       ip3=iSubTask-iOffSet
 
 C-SVC20100301: fill the buffer with sigma vectors if they
@@ -309,14 +299,13 @@ C-sigma vectors in the buffer.
          if(istu.eq.isp1) then
           ibuf1=ibuf1+1
           ip1_buf(ibuf1)=ip1i
-*         lto=lbuf1+mxci*(ibuf1-1)
-*         call dcopy_(nsgm1,0.0D0,0,work(lto),1)
-*         CALL SIGMA1(IULEV,ITLEV,1.0D00,STSYM,CI,WORK(LTO))
+*         call dcopy_(nsgm1,[0.0D0],0,BUF1(:,ibuf1),1)
+*         CALL SIGMA1(IULEV,ITLEV,1.0D00,STSYM,CI,BUF1(:,ibuf1))
          end if
         end do
         myBuffer=iTask
       ELSE
-        ibuf1=iWork(libuf1+iTask-1)
+        ibuf1=TaskList(iTask,3)
       ENDIF
 C-SVC20100301: necessary batch of sigma vectors is now in the buffer
 
@@ -330,12 +319,11 @@ C-SVC20100301: necessary batch of sigma vectors is now in the buffer
 *         iulev=idx2ij(2,idx)
 *         it=L2ACT(itlev)
 *         iu=L2ACT(iulev)
-*         lto=lbuf1+mxci*(ib-1)
-*         G1(it,iu)=DDOT_(nsgm1,ci,1,work(lto),1)
+*         G1(it,iu)=DDOT_(nsgm1,ci,1,BUF1(:,ib),1)
 *         IF(IFF.ne.0) then
 *           F1sum=0.0D0
 *           do i=1,nsgm1
-*             F1sum=F1sum+CI(i)*work(lto-1+i)*work(lbufd-1+i)
+*             F1sum=F1sum+CI(i)*BUF1(i,ib)*bufd(i)
 *           end do
 *           F1(it,iu)=F1sum-EPSA(iu)*G1(it,iu)
 *         end if
@@ -369,23 +357,20 @@ C G3(:,:,it,iu,iy,iz) loaded from disk, for each process...
 *     nsgm2=CIS%ncsf(issg2)
       iy=L2ACT(iylev)
       iz=L2ACT(izlev)
-*     lto=lbuf2
-*     call dcopy_(nsgm2,0.0D0,0,work(lto),1)
-*     CALL SIGMA1(IYLEV,IZLEV,1.0D00,STSYM,CI,WORK(LTO))
+*     call dcopy_(nsgm2,0.0D0,0,BUF2,1)
+*     CALL SIGMA1(IYLEV,IZLEV,1.0D00,STSYM,CI,BUF2)
 *     if(issg2.eq.issg1) then
 *       do ib=1,ibuf1
-*         idx=iwork(lip1buf-1+ib)
+*         idx=ip1_buf(ib)
 *         itlev=idx2ij(1,idx)
 *         iulev=idx2ij(2,idx)
 *         it=L2ACT(itlev)
 *         iu=L2ACT(iulev)
-*         G2(it,iu,iy,iz)=DDOT_(nsgm1,work(lto),1,
-*    &         work(lbuf1+mxci*(ib-1)),1)
+*         G2(it,iu,iy,iz)=DDOT_(nsgm1,BUF2,1,BUF1(:,ib),1)
 *         IF(IFF.ne.0) THEN
 *           F2sum=0.0D0
 *           do i=1,nlev
-*             F2sum=F2sum+work(lto-1+i)*work(lbufd-1+)*
-*    &             work(lbuf1-1+i+mxci*(ib-1))
+*             F2sum=F2sum+BUF2(i)*bufd(i)*BUF1(i,ib)
 *           end do
 *           F2(it,iu,iy,iz)=F2sum
 *         END IF
@@ -399,10 +384,8 @@ C G3(:,:,it,iu,iy,iz) loaded from disk, for each process...
         iv=L2ACT(ivlev)
         ix=L2ACT(ixlev)
         if(isvx.ne.mul(issg1,issg2)) goto 99
-*       lfrom=lbuf2
-*       lto=lbuft
-*       call dcopy_(nsgm1,0.0D0,0,work(lto),1)
-*       CALL SIGMA1(IVLEV,IXLEV,1.0D00,ISSG2,WORK(LFROM),WORK(LTO))
+*       call dcopy_(nsgm1,[0.0D0],0,BUFT,1)
+*       CALL SIGMA1(IVLEV,IXLEV,1.0D00,ISSG2,BUF2,BUFT)
 *-----------
 * Max and min values of index p1:
         ip1mx=ntri2
@@ -428,9 +411,8 @@ C G3(:,:,it,iu,iy,iz) loaded from disk, for each process...
 
 *-----------
 * Contract the Sgm1 wave functions with the Tau wave function.
-*       l1=lbuf1+mxci*(ibmn-1)
-*       call DGEMV_('T',nsgm1,nb,1.0D0,work(l1),mxci,
-*    &       work(lbuft),1,0.0D0,bufr,1)
+*       call DGEMV_('T',nsgm1,nb,1.0D0,BUF1(:,ibmn),mxci,
+*    &       buft,1,0.0D0,bufr,1)
 * and distribute this result into G3:
 *       call DCOPY_(nb,bufr,1,G3(iG3OFF+1),1)
 * and copy the active indices into idxG3:
@@ -451,12 +433,12 @@ C G3(:,:,it,iu,iy,iz) loaded from disk, for each process...
 *       IF(IFF.ne.0) THEN
 * Elementwise multiplication of Tau with H0 diagonal - EPSA(IV):
 *         do icsf=1,nsgm1
-*           work(lbuft-1+icsf)=
-*    &           (work(lbufd-1+icsf)-epsa(iv))*work(lbuft-1+icsf)
+*           buft(icsf)=
+*    &           (bufd(icsf)-epsa(iv))*buft(icsf)
 *         end do
 * so Tau is now = Sum(eps(w)*E_vxww) Psi. Contract and distribute:
-*         call DGEMV_('T',nsgm1,nb,1.0D0,work(l1),mxci,
-*    &         work(lbuft),1,0.0D0,bufr,1)
+*         call DGEMV_('T',nsgm1,nb,1.0D0,BUF1(:ibmn),mxci,
+*    &         buft,1,0.0D0,bufr,1)
 *         call dcopy_(nb,bufr,1,F3(iG3OFF+1),1)
 *       END IF
         iG3OFF=iG3OFF+nb
@@ -475,9 +457,6 @@ CSVC: The master node now continues to only handle task scheduling,
 C     needed to achieve better load balancing. So it exits from the task
 C     list.  It has to do it here since each process gets at least one
 C     task.
-#if defined (_MOLCAS_MPP_) && ! defined (_GA_)
-      IF (IS_REAL_PAR().AND.KING().AND.(NPROCS.GT.1)) GOTO 501
-#endif
 
 C-SVC20100301: end of the task
       GOTO 500
@@ -504,12 +483,12 @@ C-position 12345678901234567890
 C-SVC20100831: set correct number of elements in new G3
       NG3=iG3OFF
 
-      CALL GETMEM ('TASKLIST','FREE','INTE',lTask_List,4*mxTask)
+      CALL mma_deallocate(TASKLIST)
       ! free CI buffers
-      CALL GETMEM('BUF1','FREE','REAL',LBUF1,NBUF1*MXCI)
-      CALL GETMEM('BUF2','FREE','REAL',LBUF2,NBUF2*MXCI)
-      CALL GETMEM('BUFT','FREE','REAL',LBUFT,NBUFT*MXCI)
-      CALL GETMEM('BUFD','FREE','REAL',LBUFD,NBUFD*MXCI)
+      CALL mma_deallocate(BUF1)
+      CALL mma_deallocate(BUF2)
+      CALL mma_deallocate(BUFT)
+      CALL mma_deallocate(BUFD)
 
 C-SVC20100302: Synchronized add into the densitry matrices
 C  only for the G1 and G2 replicate arrays
@@ -523,16 +502,16 @@ C  only for the G1 and G2 replicate arrays
       NLEV4=NLEV2**2
 C
 C allocate work space to store 3RDM
-      Call GETMEM('G3TMP','ALLO','REAL',LG3TMP,NLEV4)
+      Call mma_allocate(G3TMP,NLEV4,Label='G3Tmp')
 C
 C TODO: Here, several options to compute F3.
 C Currently implemented only cu4, but cu34 and F3 from DMRG-sweep
 C will be possible. They should be implemented at this section.
 C
 C MKFG3CU4 is located under block_dmrg_util/
-      Call MKFG3CU4(IFF,G1,F1,G2,F2,G3,F3,idxG3,Work(LG3TMP))
+      Call MKFG3CU4(IFF,G1,F1,G2,F2,G3,F3,idxG3,G3TMP)
 C
-      Call GETMEM('G3TMP','FREE','REAL',LG3TMP,NLEV4)
+      Call mma_deallocate(G3TMP)
 #endif
 
 #ifdef _ENABLE_CHEMPS2_DMRG_
