@@ -11,14 +11,15 @@
 * Copyright (C) 2021, Yoshio Nishimoto                                 *
 ************************************************************************
       SUBROUTINE OLagNS2(iSym,DPT2C,T2AO)
+C
+      use stdalloc, only: mma_allocate, mma_deallocate
+      use definitions, only: wp
 C
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "caspt2_grad.fh"
 C
       DIMENSION DPT2C(*),T2AO(*)
+      real(kind=wp),allocatable :: Int1(:),Int2(:),Scr1(:),Amp1(:)
 C
       !! orbital Lagrangian from the T-amplitude
       !! See the loop structure in rhs_mp2.f
@@ -32,11 +33,10 @@ C     write(6,*) "nmaxorb = ", nmaxorb
 C
       lInt = nMaxOrb*nMaxOrb
 C
-      Call GetMem('Int1','Allo','Real',ipInt1,lInt) !! for (ia|jb)
-      Call GetMem('Int2','Allo','Real',ipInt2,lInt) !! for (ib|ja)
-      Call GetMem('Scr1','Allo','Real',ipScr1,lInt) !! work space
-
-      Call GetMem('Amp1','Allo','Real',ipAmp1,lInt) !! for amplitude
+      call mma_allocate(Int1,lInt,Label='Int1') !! for (ia|jb)
+      call mma_allocate(Int2,lInt,Label='Int2') !! for (ib|ja)
+      call mma_allocate(Scr1,lInt,Label='Scr1') !! work space
+      call mma_allocate(Amp1,lInt,Label='Amp1') !! for amplitude
 C
 
       !! (ia|jb)
@@ -56,25 +56,19 @@ C
               Do iCase = 1, 13
 C               if (icase.ne.12.and.icase.ne.13) cycle
                 Call OLagNs_Hel2(iCase,iSym,iSymA,iSymB,iSymI,iSymJ,
-     *                           nMaxOrb,Work(ipInt1),Work(ipInt2),
-     *                           Work(ipAmp1),Work(ipScr1),
-     *                           DPT2C,T2AO)
+     *                           nMaxOrb,Int1,Int2,Amp1,Scr1,DPT2C,T2AO)
               End Do
             End Do
           End Do
         End Do
       End Do
-C     write(6,*) "olag before VVVO"
-C     call sqprt(work(ipolag),12)
 C
-      Call DScal_(nBasSq,1.0D+00/DBLE(MAX(1,NACTEL)),DPT2C,1)
+      Call DScal_(NBSQT,1.0D+00/DBLE(MAX(1,NACTEL)),DPT2C,1)
 C
-C
-      Call GetMem('Int1','Free','Real',ipInt1,lInt)
-      Call GetMem('Int2','Free','Real',ipInt2,lInt)
-      Call GetMem('Scr1','Free','Real',ipScr1,lInt)
-
-      Call GetMem('Amp1','Free','Real',ipAmp1,lInt)
+      call mma_deallocate(Int1)
+      call mma_deallocate(Int2)
+      call mma_deallocate(Scr1)
+      call mma_deallocate(Amp1)
 C
       END SUBROUTINE OLagNS2
 C
@@ -84,16 +78,18 @@ C
      *                       ERI1,ERI2,Amp1,Scr,DPT2C,T2AO)
       USE SUPERINDEX
       USE iSD_data
+      use caspt2_global, only: OLag
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+      use definitions, only: wp
+      use fake_GA, only: GA_Arrays
 C
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-#include "caspt2_grad.fh"
       DIMENSION ERI1(*),ERI2(*),Amp1(nMaxOrb,nMaxOrb),
      *          Scr(nMaxOrb,nMaxOrb)
       DIMENSION DPT2C(*),T2AO(*)
+      real(kind=wp),allocatable :: WRK1(:),WRK2(:)
 C
       INTEGER   nAshA,nAshB,nSshA,nSshB
       LOGICAL   PM
@@ -149,17 +145,17 @@ C
 C
       !! Some setup
       !! Read T-amplitude, hopefully in contravariant form
-      nINP = 0
-      nINM = 0
-      nIN  = 0
+C     nINP = 0
+C     nINM = 0
+C     nIN  = 0
       If (PM) Then
-        nINP = nINDEP(iSym,iCase)
+C       nINP = nINDEP(iSym,iCase)
         nASP = nASup(iSym,iCase)
         nISP = nISup(iSym,iCase)
         ! If (nINP.ne.0) Then
         !   nVec = nINP*nISP
         ! End If
-        nINM = nINDEP(iSym,iCase+1)
+C       nINM = nINDEP(iSym,iCase+1)
         nASM = nASup(iSym,iCase+1)
         nISM = nISup(iSym,iCase+1)
         ! If (nINM.ne.0) Then
@@ -174,7 +170,7 @@ C
           CALL RHS_READ_C(ipTCM,iCase+1,iSym,iVecC2)
         End If
       Else
-        nIN = nINDEP(iSym,iCase)
+C       nIN = nINDEP(iSym,iCase)
         nAS = nASup(iSym,iCase)
         nIS = nISup(iSym,iCase)
         ! If (nIN.ne.0) Then
@@ -185,27 +181,6 @@ C
           CALL RHS_READ_C(ipTC,iCase,iSym,iVecC2)
         End If
       End If
-C
-      If (iCase.ne.12.and.iCase.ne.13) Then
-        If (PM) Then
-          If (nASP*nISP.ne.0) Then
-            CALL GETMEM('LSTP','ALLO','REAL',LSTP,nASP*nINP)
-            idST = idSTMAT(iSym,iCase)
-            CALL dDaFile(LUSBT,2,Work(LSTP),nASP*nINP,idST)
-          End If
-          If (nASM*nISM.ne.0) Then
-            CALL GETMEM('LSTM','ALLO','REAL',LSTM,nASM*nINM)
-            idST = idSTMAT(iSym,iCase+1)
-            CALL dDaFile(LUSBT,2,Work(LSTM),nASM*nINM,idST)
-          End If
-        Else
-          If (nAS*nIN.ne.0) Then
-            CALL GETMEM('LST','ALLO','REAL',LST,nAS*nIN)
-            idST = idSTMAT(iSym,iCase)
-            CALL dDaFile(LUSBT,2,Work(LST),nAS*nIN,idST)
-          End If
-        End If
-      End If
 C
 C     If (PM) Then
 C       If (nINP*nISP.eq.0.and.nINM*nISM.eq.0) GO TO 1
@@ -213,8 +188,8 @@ C     Else
 C       If (nIN*nIS) GO TO 1
 C     End If
 C
-      Call GetMem('WRK1','Allo','Real',ipWRK1,nBasT*nBasT)
-      Call GetMem('WRK2','Allo','Real',ipWRK2,nBasT*nBasT)
+      call mma_allocate(WRK1,nBasT*nBasT,Label='WRK1')
+      call mma_allocate(WRK2,nBasT*nBasT,Label='WRK2')
 C
       nFroI = nFro(iSymI)
       nFroJ = nFro(iSymJ)
@@ -268,26 +243,15 @@ C
         Call OLagNS_H(Amp1)
       End If
 C
-      Call GetMem('WRK1','Free','Real',ipWRK1,nBasT*nBasT)
-      Call GetMem('WRK2','Free','Real',ipWRK2,nBasT*nBasT)
+      call mma_deallocate(WRK1)
+      call mma_deallocate(WRK2)
 C
 C   1 CONTINUE
       If (PM) Then
-        If (nASP*nISP.ne.0) Call RHS_FREE(nASP,nISP,ipTCP)
-        If (nASM*nISM.ne.0) Call RHS_FREE(nASM,nISM,ipTCM)
+        If (nASP*nISP.ne.0) Call RHS_FREE(ipTCP)
+        If (nASM*nISM.ne.0) Call RHS_FREE(ipTCM)
       Else
-        If (nAS*nIS.ne.0) Call RHS_FREE(nAS,nIS,ipTC)
-      End If
-C
-      If (iCase.ne.12.and.iCase.ne.13) Then
-        If (PM) Then
-          If (nASP*nISP.ne.0)
-     *      CALL GETMEM('LSTP','FREE','REAL',LSTP,nASP*nINP)
-          If (nASM*nISM.ne.0)
-     *      CALL GETMEM('LSTM','FREE','REAL',LSTM,nASM*nINM)
-        Else
-          If (nAS*nIN.ne.0) CALL GETMEM('LST','FREE','REAL',LST,nAS*nIN)
-        End If
+        If (nAS*nIS.ne.0) Call RHS_FREE(ipTC)
       End If
 C
       Return
@@ -348,7 +312,7 @@ C             End Do
 C             ValA = ValA*2.0D+00
               iIS = iJabs
               iAS = IW1
-              ValA = Work(ipTC+iAS-1+nAS*(iIS-1))*2.0D+00
+              ValA = GA_Arrays(ipTC)%A(iAS+nAS*(iIS-1))*2.0D+00
 C
               If (iUabs.eq.iVabs) Then
                 !! For FIMO derivative
@@ -369,10 +333,9 @@ C
           !! Prepare for implicit (VV|VO) integrals
           !! T_{ij}^{ab} -> T_{ij}^{mu nu} back-transformation
           !! 1) T_{ij}^{ab} -> T_{ij}^{mu nu}
-          Call OLagNS_post2(nAshA,nAshB,nCorA,nCorB,
-     *                      AmpL1,Work(ipWRK2))
+          Call OLagNS_post2(nAshA,nAshB,nCorA,nCorB,AmpL1,WRK2)
           !! Reorder T_{ij}^{rho sigma} to T2AO(j,sigma,i,rho)
-          Call OLagNS_post3(iIabs,iJabs,T2AO,Work(ipWRK2))
+          Call OLagNS_post3(iIabs,iJabs,T2AO,WRK2)
         End Do
       End Do
 C
@@ -441,7 +404,7 @@ C    *        + Work(ipTP+iVP-1)*Work(LSTP+iVaP-1+nASP*(iICB-1))
 C             End Do
               iIS = iViP
               iAS = iVaP
-              ValBP = Work(ipTCP+iAS-1+nASP*(iIS-1))
+              ValBP = GA_Arrays(ipTCP)%A(iAS+nASP*(iIS-1))
               If (iAabs.ne.iBabs.and.iIabs.ne.iJabs) Then
                 If (iIabs.ne.iJabs) Then
 C                 Do iICB = 1, nINM
@@ -451,7 +414,7 @@ C    *          + Work(ipTM+iVM-1)*Work(LSTM+iVaM-1+nASM*(iICB-1))
 C                 End Do
                   iIS = iViM
                   iAS = iVaM
-                  ValBM = Work(ipTCM+iAS-1+nASM*(iIS-1))
+                  ValBM = GA_Arrays(ipTCM)%A(iAS+nASM*(iIS-1))
                 End If
                 !! permutated
                 If (iAabs.lt.iBabs) ValBM = -ValBM
@@ -471,10 +434,9 @@ C
           !! Prepare for implicit (VV|VO) integrals
           !! T_{ij}^{ab} -> T_{ij}^{mu nu} back-transformation
           !! 1) T_{ij}^{ab} -> T_{ij}^{mu nu}
-          Call OLagNS_post2(nAshA,nAshB,nCorA,nCorB,
-     *                      AmpL1,Work(ipWRK2))
+          Call OLagNS_post2(nAshA,nAshB,nCorA,nCorB,AmpL1,WRK2)
           !! Reorder T_{ij}^{rho sigma} to T2AO(j,sigma,i,rho)
-          Call OLagNS_post3(iIabs,iJabs,T2AO,Work(ipWRK2))
+          Call OLagNS_post3(iIabs,iJabs,T2AO,WRK2)
         End Do
       End Do
 C
@@ -548,10 +510,10 @@ C             ValC2 = ValC2*2.0D+00
 C
               iIS = iAabs
               iAS = kTUV(iTabs,iUabs,iVabs) - nTUVes(iSym)
-              ValC1 = Work(ipTC+iAS-1+nAS*(iIS-1))*2.0D+00
+              ValC1 = GA_Arrays(ipTC)%A(iAS+nAS*(iIS-1))*2.0D+00
               If (iIabs.ne.iJabs) Then
                 iAS = kTUV(iVabs,iUabs,iTabs) - nTUVes(iSym)
-                ValC2 = Work(ipTC+iAS-1+nAS*(iIS-1))*2.0D+00
+                ValC2 = GA_Arrays(ipTC)%A(iAS+nAS*(iIS-1))*2.0D+00
               End If
 C
               iTabs = iBabs
@@ -568,7 +530,7 @@ C    *          + Work(ipT+iV-1)*Work(LST+IW1-1+nAS*(iICB-1))
 C               End Do
 C               ONEADD = ONEADD*2.0D+00
                 iAS = kTUV(iTabs,iUabs,iVabs) - nTUVes(iSym)
-                ONEADD = Work(ipTC+iAS-1+nAS*(iIS-1))*2.0D+00
+                ONEADD = GA_Arrays(ipTC)%A(iAS+nAS*(iIS-1))*2.0D+00
                 DPT2C(iAtot+nOrbA*(iBtot-1))
      *            = DPT2C(iAtot+nOrbA*(iBtot-1)) + ONEADD
 C
@@ -587,7 +549,8 @@ C               ONEADD = 2.0D+00*ONEADD/DBLE(MAX(1,NACTEL))
                 ONEADD = 0.0D+00
                 Do iXabs = 1, nAshI !?
                   iAS = kTUV(iTabs,iXabs,iXabs) - nTUVes(iSym)
-                  ONEADD = ONEADD + Work(ipTC+iAS-1+nAS*(iIS-1))
+                  ONEADD = ONEADD
+     &                   + GA_Arrays(ipTC)%A(iAS+nAS*(iIS-1))
                 End Do
                 ONEADD = 2.0D+00*ONEADD/DBLE(MAX(1,NACTEL))
                 AmpL1(iAtot-nCorA,iBtot-nCorA)
@@ -610,9 +573,9 @@ C
           !! T_{ij}^{ab} -> T_{ij}^{mu nu} back-transformation
           !! 1) T_{ij}^{ab} -> T_{ij}^{mu nu}
           Call OLagNS_post2(nAshA+nSshA,nAshB+nSshB,nCorA,nCorB,
-     *                      AmpL1,Work(ipWRK2))
+     *                      AmpL1,WRK2)
           !! Reorder T_{ij}^{rho sigma} to T2AO(j,sigma,i,rho)
-          Call OLagNS_post3(iIabs,iJabs,T2AO,Work(ipWRK2))
+          Call OLagNS_post3(iIabs,iJabs,T2AO,WRK2)
         End Do
       End Do
 C
@@ -678,9 +641,9 @@ C             ValD1 = ValD1*2.0D+00
 C             ValD2 = ValD2*2.0D+00
               iIS = iJabs + nIshA*(iAabs-1)+iOFF1(iSymA)
               iAS = kTU(iB,iI)-nTUes(iSymA)
-              ValD1 = Work(ipTC+iAS-1+nAS*(iIS-1))*2.0D+00
+              ValD1 = GA_Arrays(ipTC)%A(iAS+nAS*(iIS-1))*2.0D+00
               iAS = iAS + nTU(iSymA)
-              ValD2 = Work(ipTC+iAS-1+nAS*(iIS-1))*2.0D+00
+              ValD2 = GA_Arrays(ipTC)%A(iAS+nAS*(iIS-1))*2.0D+00
 C
               !! Fock contributions from the inactive density
               If (iItot.eq.iBtot) Then
@@ -703,9 +666,9 @@ C
           !! T_{ij}^{ab} -> T_{ij}^{mu nu} back-transformation
           !! 1) T_{ij}^{ab} -> T_{ij}^{mu nu}
           Call OLagNS_post2(nAshA+nSshA,nAshB+nSshB,nCorA,nCorB,
-     *                      AmpL1,Work(ipWRK2))
+     *                      AmpL1,WRK2)
           !! Reorder T_{ij}^{rho sigma} to T2AO(j,sigma,i,rho)
-          Call OLagNS_post3(iIabs,iJabs,T2AO,Work(ipWRK2))
+          Call OLagNS_post3(iIabs,iJabs,T2AO,WRK2)
         End Do
       End Do
 C
@@ -756,13 +719,14 @@ C
 C
               iASP  = iBabs
               iISP  = iAabs + nSshA*(IgeJ-1)+iOFF1(iSymA)
-              ValEP = Work(ipTCP+iASP-1+nASP*(iISP-1))
+              ValEP = GA_Arrays(ipTCP)%A(iASP+nASP*(iISP-1))
               ValEM = 0.0D+00
               If (iIabs.gt.iJabs) Then
                 ValEP = ValEP * SQ2
                 iASM  = iBabs
                 iISM  = iAabs + nSshA*(IgtJ-1)+iOFF1(iSymA)
-                ValEM = Work(ipTCM+iASM-1+nASM*(iISM-1))*SQ2*SQ3
+                ValEM = GA_Arrays(ipTCM)%A(iASM+nASM*(iISM-1))
+     &                *SQ2*SQ3
               Else
               End If
 C
@@ -781,9 +745,9 @@ C
           !! T_{ij}^{ab} -> T_{ij}^{mu nu} back-transformation
           !! 1) T_{ij}^{ab} -> T_{ij}^{mu nu}
           Call OLagNS_post2(nAshA+nSshA,nAshB+nSshB,nCorA,nCorB,
-     *                      AmpL1,Work(ipWRK2))
+     *                      AmpL1,WRK2)
           !! Reorder T_{ij}^{rho sigma} to T2AO(j,sigma,i,rho)
-          Call OLagNS_post3(iIabs,iJabs,T2AO,Work(ipWRK2))
+          Call OLagNS_post3(iIabs,iJabs,T2AO,WRK2)
         End Do
       End Do
 C
@@ -835,14 +799,14 @@ C
 C
               iASP  = kTgeU(iTabs,iUabs)-nTgeUes(iSym)
               iISP  = kAgeB(iAabs,iBabs)-nAgeBes(iSym)
-              ValFP = Work(ipTCP+iASP-1+nASP*(iISP-1))
+              ValFP = GA_Arrays(ipTCP)%A(iASP+nASP*(iISP-1))
               If (iIabs.eq.iJabs) ValFP = ValFP*0.5D+00
               ValFM = 0.0D+00
               If (iAabs.ne.iBabs) Then
                 If (iTabs.ne.iUabs) Then
                   iASM  = kTgtU(iTabs,iUabs)-nTgtUes(iSym)
                   iISM  = kAgtB(iAabs,iBabs)-nAgtBes(iSym)
-                  ValFM = Work(ipTCM+iASM-1+nASM*(iISM-1))
+                  ValFM = GA_Arrays(ipTCM)%A(iASM+nASM*(iISM-1))
                 End If
               Else
                 ValFP = ValFP * SQI2
@@ -863,9 +827,9 @@ C
           !! Prepare for implicit (VV|VO) integrals
           !! T_{ij}^{ab} -> T_{ij}^{mu nu} back-transformation
           !! 1) T_{ij}^{ab} -> T_{ij}^{mu nu}
-          Call OLagNS_post2(nSshA,nSshB,nOccA,nOccB,AmpL1,Work(ipWRK2))
+          Call OLagNS_post2(nSshA,nSshB,nOccA,nOccB,AmpL1,WRK2)
           !! Reorder T_{ij}^{rho sigma} to T2AO(j,sigma,i,rho)
-          Call OLagNS_post3(iIabs,iJabs,T2AO,Work(ipWRK2))
+          Call OLagNS_post3(iIabs,iJabs,T2AO,WRK2)
         End Do
       End Do
 C
@@ -917,13 +881,13 @@ C
 C
               iAgeB = kAgeB(iAabs,iBabs)-nAgeBes(iSym) !! iSymAB
               iVjP  = iJ + nIsh(iSymJ)*(iAgeB-1)+IOFF1(iSymJ)
-              ValGP = Work(ipTCP+iI-1+nASP*(iVjP-1))
+              ValGP = GA_Arrays(ipTCP)%A(iI+nASP*(iVjP-1))
               ValGM = 0.0D+00
               If (iAabs.ne.iBabs) Then
                 ValGP = ValGP * SQ2
                 iAgtB = kAgtB(iAabs,iBabs) - nAgtBes(iSym) !! iSymAB
                 iVjM  = iJ + nIsh(iSymJ)*(iAgtB-1)+IOFF2(iSymJ)
-                ValGM = Work(ipTCM+iI-1+nASM*(iVjM-1))*SQ2*SQ3
+                ValGM = GA_Arrays(ipTCM)%A(iI+nASM*(iVjM-1))*SQ2*SQ3
               End If
 C
               AmpL1(iA,iB) = AmpL1(iA,iB) + ValGP + ValGM
@@ -939,18 +903,18 @@ C
 C         Call DGEMM_('N','T',nOrbA,nSshA,nSshB,
 C    *                1.0D+00,ERI1(1+nOrbA*nOccB),nOrbA,
 C    *                        AmpL1,nSshA,
-C    *                1.0D+00,Work(ipOLAG+nOrbA*nOccB),nOrbA)
+C    *                1.0D+00,OLAG(nOrbA*nOccB+1),nOrbA)
 C         Call DGEMM_('T','N',nOrbA,nSshA,nSshB,
 C    *                1.0D+00,ERI1(nOccA+1),nOrbA,
 C    *                        AmpL1,nSshA,
-C    *                1.0D+00,Work(ipOLAG+nOrbA*nOccB),nOrbA)
+C    *                1.0D+00,OLAG(nOrbA*nOccB+1),nOrbA)
 C
           !! Prepare for implicit (VV|VO) integrals
           !! T_{ij}^{ab} -> T_{ij}^{mu nu} back-transformation
           !! 1) T_{ij}^{ab} -> T_{ij}^{mu nu} for all ij
-          Call OLagNS_post2(nSshA,nSshB,nOccA,nOccB,AmpL1,Work(ipWRK2))
+          Call OLagNS_post2(nSshA,nSshB,nOccA,nOccB,AmpL1,WRK2)
           !! Reorder T_{ij}^{rho sigma} to T2AO(j,sigma,i,rho)
-          Call OLagNS_post3(iIabs,iJabs,T2AO,Work(ipWRK2))
+          Call OLagNS_post3(iIabs,iJabs,T2AO,WRK2)
         End Do
       End Do
 C
@@ -1004,14 +968,14 @@ C
               iVaHP = kAgeB(iAabs,iBabs) - nAgeBes(iSym)
               iVHP  = iVaHP + iViHP !! nAgeB(iSym)*(iViP-1)
 C
-              ValHP = Work(ipTCP+iVHP-1)
+              ValHP = GA_Arrays(ipTCP)%A(iVHP)
               ValHM = 0.0D+00
               If (iIabs.ne.iJabs) Then
                 If (iAabs.ne.iBabs) Then
                   ValHP = ValHP * 2.0D+00
                   iVaHM = kAgtB(iAabs,iBabs) - nAgtBes(iSym)
                   iVHM  = iVaHM + iViHM !! nAgtB(iSym)*(iViM-1)
-                  ValHM = Work(ipTCM+iVHM-1) * 2.0D+00*SQ3
+                  ValHM = GA_Arrays(ipTCM)%A(iVHM) * 2.0D+00*SQ3
                 Else
                   ValHP = ValHP * SQ2
                 End If
@@ -1033,26 +997,26 @@ C
 C         Call DGEMM_('N','T',nOrbA,nSshA,nSshB,
 C    *                1.0D+00,ERI1(1+nOrbA*nOccB),nOrbA,
 C    *                        AmpL1,nSshA,
-C    *                1.0D+00,Work(ipOLAG+nOrbA*nOccB),nOrbA)
+C    *                1.0D+00,OLAG(nOrbA*nOccB+1),nOrbA)
 C         Call DGEMM_('T','N',nOrbA,nSshA,nSshB,
 C    *                1.0D+00,ERI1(nOccA+1),nOrbA,
 C    *                        AmpL1,nSshA,
-C    *                1.0D+00,Work(ipOLAG+nOrbA*nOccB),nOrbA)
+C    *                1.0D+00,OLAG(nOrbA*nOccB+1),nOrbA)
 C
           !! Prepare for implicit (VV|VO) integrals
           !! T_{ij}^{ab} -> T_{ij}^{mu nu} back-transformation
           !! 1) T_{ij}^{ab} -> T_{ij}^{mu nu} for all ij
-          Call OLagNS_post2(nSshA,nSshB,nOccA,nOccB,AmpL1,Work(ipWRK2))
+          Call OLagNS_post2(nSshA,nSshB,nOccA,nOccB,AmpL1,WRK2)
 C         Call DGEMM_('N','N',nBasT,nSshA,nSshB,
 C    *                1.0D+00,CMOPT2(1+nBasT*nOccB),nBasT,
 C    *                        AmpL1,nSshA,
-C    *                0.0D+00,Work(ipWRK1),nBasT)
+C    *                0.0D+00,WRK1,nBasT)
 C         Call DGEMM_('N','T',nBasT,nBasT,nSshB,
-C    *                1.0D+00,Work(ipWRK1),nBasT,
+C    *                1.0D+00,WRK1,nBasT,
 C    *                        CMOPT2(1+nBasT*nOccA),nBasT,
-C    *                0.0D+00,Work(ipWRK2),nBasT)
+C    *                0.0D+00,WRK2,nBasT)
           !! Reorder T_{ij}^{rho sigma} to T2AO(j,sigma,i,rho)
-          Call OLagNS_post3(iIabs,iJabs,T2AO,Work(ipWRK2))
+          Call OLagNS_post3(iIabs,iJabs,T2AO,WRK2)
 C         Do iBas = 1, nBasT
 C           Do jBas = 1, nBasT
 C             loc1 = iJ-1 + (jBas-1)*nOccA2
@@ -1061,8 +1025,8 @@ C             loc2 = iI-1 + (jBas-1)*nOccA2
 C    *             + (iJ-1)*nOccA2*nBasT + (iBas-1)*nOccA2*nBasT*nOccA2
 C             loc3 = iBas-1 + (jBas-1)*nBasT
 C             loc4 = jBas-1 + (iBas-1)*nBasT
-C             T2AO(1+loc1) = T2AO(1+loc1) + Work(ipWRK2+loc3)
-C             T2AO(1+loc2) = T2AO(1+loc2) + Work(ipWRK2+loc4)
+C             T2AO(1+loc1) = T2AO(1+loc1) + WRK2(1+loc3)
+C             T2AO(1+loc2) = T2AO(1+loc2) + WRK2(1+loc4)
 C           End Do
 C         End Do
         End Do
@@ -1106,11 +1070,11 @@ C
       Call DGEMM_('N','T',nOrbA,nDimA,nDimB,
      *            1.0D+00,ERI(1+nOrbA*nSkpB),nOrbA,
      *                    AmpMO,nDimA,
-     *            1.0D+00,Work(ipOLAG+nOrbA*nSkpB),nOrbA)
+     *            1.0D+00,OLAG(nOrbA*nSkpB+1),nOrbA)
       Call DGEMM_('T','N',nOrbA,nDimA,nDimB,
      *            1.0D+00,ERI(nSkpA+1),nOrbA,
      *                    AmpMO,nDimA,
-     *            1.0D+00,Work(ipOLAG+nOrbA*nSkpB),nOrbA)
+     *            1.0D+00,OLAG(nOrbA*nSkpB+1),nOrbA)
 C
       End Subroutine OLagNS_post1
 C
@@ -1118,7 +1082,7 @@ C-----------------------------------------------------------------------
 C
       Subroutine OLagNS_post2(nDimA,nDimB,nSkpA,nSkpB,AmpMO,AmpAO)
 C
-      use caspt2_data, only: CMOPT2
+      use caspt2_global, only: CMOPT2
       Implicit Real*8 (A-H,O-Z)
 C
       Dimension AmpMO(nDimA,nDimB),AmpAO(nBasA,nBasB)
@@ -1126,9 +1090,9 @@ C
        Call DGEMM_('N','N',nBasA,nDimB,nDimA,
      *             1.0D+00,CMOPT2(1+nBasA*nSkpA),nBasA,
      *                     AmpMO,nDimA,
-     *             0.0D+00,Work(ipWRK1),nBasA)
+     *             0.0D+00,WRK1,nBasA)
        Call DGEMM_('N','T',nBasA,nBasB,nDimB,
-     *             1.0D+00,Work(ipWRK1),nBasA,
+     *             1.0D+00,WRK1,nBasA,
      *                     CMOPT2(1+nBasB*nSkpB),nBasA,
      *             0.0D+00,AmpAO,nBasA)
 C
@@ -1158,8 +1122,8 @@ C         loc2 = iI-1 + (jBas-1)*nOccA2
 C    *         + (iJ-1)*nOccA2*nBasT + (iBas-1)*nOccA2*nBasT*nOccA2
 C         loc3 = iBas-1 + (jBas-1)*nBasT
 C         loc4 = jBas-1 + (iBas-1)*nBasT
-C         T2AO(1+loc1) = T2AO(1+loc1) + Work(ipWRK2+loc3)
-C         T2AO(1+loc2) = T2AO(1+loc2) + Work(ipWRK2+loc4)
+C         T2AO(1+loc1) = T2AO(1+loc1) + WRK2(1+loc3)
+C         T2AO(1+loc2) = T2AO(1+loc2) + WRK2(1+loc4)
 C       End Do
 C     End Do
 C
@@ -1174,7 +1138,6 @@ C
 C
       Implicit Real*8 (A-H,O-Z)
 C
-#include "rasdim.fh"
 #include "caspt2.fh"
 C
       Dimension CMO(*),DPT2(*),DPT2AO(*),WRK(*)
