@@ -22,16 +22,14 @@
 
 *||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||*
       SUBROUTINE RHSOD_NOSYM(IVEC)
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: verbose
 #ifdef _MOLCAS_MPP_
       USE Para_Info, ONLY: Is_Real_Par
 #endif
+      use EQSOLV
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
 
 
       IF (IPRGLB.GE.VERBOSE) THEN
@@ -86,20 +84,23 @@
       SUBROUTINE RHSOD_A_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
-      use caspt2_data, only: FIMO
+      use caspt2_global, only: FIMO
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+#ifndef _MOLCAS_MPP_
+      use fake_GA, only: GA_Arrays
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-      DIMENSION IOBRA(8,8), IOKET(8,8)
+      INTEGER IVEC
+
+      INTEGER IOBRA(8,8), IOKET(8,8)
+      REAL*8, ALLOCATABLE:: BRA(:), KET(:)
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
-#else
-#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -117,11 +118,11 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       CALL CHOVEC_SIZE(1,NBRA,IOBRA)
       CALL CHOVEC_SIZE(2,NKET,IOKET)
 
-      CALL GETMEM('BRABUF','ALLO','REAL',LBRA,NBRA)
-      CALL GETMEM('KETBUF','ALLO','REAL',LKET,NKET)
+      CALL mma_allocate(BRA,NBRA,LABEL='BRA')
+      CALL mma_allocate(KET,NKET,LABEL='KET')
 
-      CALL CHOVEC_READ(1,LBRA)
-      CALL CHOVEC_READ(2,LKET)
+      CALL CHOVEC_READ(1,BRA,NBRA)
+      CALL CHOVEC_READ(2,KET,NKET)
 
       ICASE=1
 ************************************************************************
@@ -159,9 +160,9 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             NV=NVTOT_CHOSYM(MUL(ISYT,ISYJ)) ! JSYM=ISYT*ISYI=ISYU*ISYV
             ITJ=IT-1+NASH(ISYT)*(IJ-1)
             IVX=IV-1+NASH(ISYV)*(IX-1)
-            IOFFTJ=LBRA+IOBRA(ISYT,ISYJ)+NV*ITJ
-            IOFFVX=LKET+IOKET(ISYV,ISYX)+NV*IVX
-            TJVX=DDOT_(NV,WORK(IOFFTJ),1,WORK(IOFFVX),1)
+            IOFFTJ=1+IOBRA(ISYT,ISYJ)+NV*ITJ
+            IOFFVX=1+IOKET(ISYV,ISYX)+NV*IVX
+            TJVX=DDOT_(NV,BRA(IOFFTJ),1,KET(IOFFVX),1)
 ! A(tvx,j) = (tjvx) + FIMO(t,j)*delta(v,x)/NACTEL
             IF (ISYT.EQ.ISYJ.AND.IVABS.EQ.IXABS) THEN
               ITTOT=IT+NISH(ISYT)
@@ -172,14 +173,18 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             END IF
 ! write element A(tvx,j)
             IDX=ITVX+NAS*(IJ-IISTA)
+#ifdef _MOLCAS_MPP_
             DBL_MB(MW+IDX-1)=ATVXJ
+#else
+            GA_Arrays(lg_W)%A(IDX)=ATVXJ
+#endif
           END DO
         END DO
 ************************************************************************
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  1      CONTINUE
 
         NFIMOES=NFIMOES+(NORB(ISYM)*(NORB(ISYM)+1))/2
@@ -187,8 +192,8 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       END DO
 ************************************************************************
 
-      CALL GETMEM('BRABUF','FREE','REAL',LBRA,NBRA)
-      CALL GETMEM('KETBUF','FREE','REAL',LKET,NKET)
+      CALL mma_deallocate(BRA)
+      CALL mma_deallocate(KET)
 
       RETURN
       END
@@ -197,20 +202,23 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_C_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
-      use caspt2_data, only: FIMO
+      use caspt2_global, only: FIMO
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+#ifndef _MOLCAS_MPP_
+      use fake_GA, only: GA_Arrays
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-      DIMENSION IOBRA(8,8), IOKET(8,8)
+      INTEGER IVEC
+
+      INTEGER IOBRA(8,8), IOKET(8,8)
+      REAL*8, ALLOCATABLE:: BRA(:), KET(:)
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
-#else
-#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -228,11 +236,11 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       CALL CHOVEC_SIZE(3,NBRA,IOBRA)
       CALL CHOVEC_SIZE(2,NKET,IOKET)
 
-      CALL GETMEM('BRABUF','ALLO','REAL',LBRA,NBRA)
-      CALL GETMEM('KETBUF','ALLO','REAL',LKET,NKET)
+      CALL mma_allocate(BRA,NBRA,LABEL='BRA')
+      CALL mma_allocate(KET,NKET,LABEL='KET')
 
-      CALL CHOVEC_READ(3,LBRA)
-      CALL CHOVEC_READ(2,LKET)
+      CALL CHOVEC_READ(3,BRA,NBRA)
+      CALL CHOVEC_READ(2,KET,NKET)
 
       ICASE=4
 ************************************************************************
@@ -270,14 +278,18 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             NV=NVTOT_CHOSYM(MUL(ISYA,ISYT)) ! JSYM=ISYT*ISYI=ISYU*ISYV
             IAT=IA-1+NSSH(ISYA)*(IT-1)
             IVX=IV-1+NASH(ISYV)*(IX-1)
-            IOFFAT=LBRA+IOBRA(ISYA,ISYT)+NV*IAT
-            IOFFVX=LKET+IOKET(ISYV,ISYX)+NV*IVX
-            ATVX=DDOT_(NV,WORK(IOFFAT),1,WORK(IOFFVX),1)
+            IOFFAT=1+IOBRA(ISYA,ISYT)+NV*IAT
+            IOFFVX=1+IOKET(ISYV,ISYX)+NV*IVX
+            ATVX=DDOT_(NV,BRA(IOFFAT),1,KET(IOFFVX),1)
 
 ! W(tvx,a) = (at,vx) + (FIMO(a,t)-Sum_u(au,ut))*delta(v,x)/NACTEL
 ! write element W(tvx,j), only the (at,vx) part
             IDX=ITVX+NAS*(IA-IISTA)
+#ifdef _MOLCAS_MPP_
             DBL_MB(MW+IDX-1)=ATVX
+#else
+            GA_Arrays(lg_W)%A(IDX)=ATVX
+#endif
           END DO
 ! now, add in the part with corrections to the integrals
           IATOT=IA+NISH(ISYM)+NASH(ISYM)
@@ -289,13 +301,22 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             DO IUABS=1,NASHT
               IUUT=KTUV(IUABS,IUABS,ITABS)-NTUVES(ISYM)
               IDX=IUUT+NAS*(IA-IISTA)
+#ifdef _MOLCAS_MPP_
               SUMU=SUMU+DBL_MB(MW+IDX-1)
+#else
+              SUMU=SUMU+GA_Arrays(lg_w)%A(IDX)
+#endif
             END DO
             ADDONE=(FAT-SUMU)/DBLE(MAX(1,NACTEL))
             DO IVABS=1,NASHT
               ITVV=KTUV(ITABS,IVABS,IVABS)-NTUVES(ISYM)
               IDX=ITVV+NAS*(IA-IISTA)
+#ifdef _MOLCAS_MPP_
               DBL_MB(MW+IDX-1)=DBL_MB(MW+IDX-1)+ADDONE
+#else
+              GA_Arrays(lg_w)%A(IDX)=GA_Arrays(lg_w)%A(IDX)
+     &                                  +ADDONE
+#endif
             END DO
           END DO
         END DO
@@ -303,7 +324,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  4      CONTINUE
 
         NFIMOES=NFIMOES+(NORB(ISYM)*(NORB(ISYM)+1))/2
@@ -311,8 +332,8 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       END DO
 ************************************************************************
 
-      CALL GETMEM('BRABUF','FREE','REAL',LBRA,NBRA)
-      CALL GETMEM('KETBUF','FREE','REAL',LKET,NKET)
+      CALL mma_deallocate(BRA)
+      CALL mma_deallocate(KET)
 
       RETURN
       END
@@ -321,20 +342,23 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_B_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+#ifndef _MOLCAS_MPP_
+      use fake_GA, only: GA_Arrays
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-      DIMENSION IOSYM(8,8)
+      INTEGER IVEC
+
+      INTEGER IOSYM(8,8)
+      REAL*8, ALLOCATABLE:: CHOBUF(:)
 *      Logical Incore
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
-#else
-#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -355,9 +379,9 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
       CALL CHOVEC_SIZE(1,NCHOBUF,IOSYM)
 
-      CALL GETMEM('CHOBUF','ALLO','REAL',LCHOBUF,NCHOBUF)
+      CALL mma_allocate(CHOBUF,NCHOBUF,LABEL='CHOBUF')
 
-      CALL CHOVEC_READ(1,LCHOBUF)
+      CALL CHOVEC_READ(1,CHOBUF,NCHOBUF)
 
       iCASE=2
 ************************************************************************
@@ -398,16 +422,16 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             NV=NVTOT_CHOSYM(MUL(ISYT,ISYJ)) ! JSYM=ISYA*ISYJ=ISYC*ISYL
             ITJ=IT-1+NASH(ISYT)*(IJ-1)
             IVL=IV-1+NASH(ISYV)*(IL-1)
-            IOFFTJ=LCHOBUF+IOSYM(ISYT,ISYJ)+NV*ITJ
-            IOFFVL=LCHOBUF+IOSYM(ISYV,ISYL)+NV*IVL
-            TJVL=DDOT_(NV,WORK(IOFFTJ),1,WORK(IOFFVL),1)
+            IOFFTJ=1+IOSYM(ISYT,ISYJ)+NV*ITJ
+            IOFFVL=1+IOSYM(ISYV,ISYL)+NV*IVL
+            TJVL=DDOT_(NV,CHOBUF(IOFFTJ),1,CHOBUF(IOFFVL),1)
 
             NV=NVTOT_CHOSYM(MUL(ISYT,ISYL))
             ITL=IT-1+NASH(ISYT)*(IL-1)
             IVJ=IV-1+NASH(ISYV)*(IJ-1)
-            IOFFTL=LCHOBUF+IOSYM(ISYT,ISYL)+NV*ITL
-            IOFFVJ=LCHOBUF+IOSYM(ISYV,ISYJ)+NV*IVJ
-            TLVJ=DDOT_(NV,WORK(IOFFTL),1,WORK(IOFFVJ),1)
+            IOFFTL=1+IOSYM(ISYT,ISYL)+NV*ITL
+            IOFFVJ=1+IOSYM(ISYV,ISYJ)+NV*IVJ
+            TLVJ=DDOT_(NV,CHOBUF(IOFFTL),1,CHOBUF(IOFFVJ),1)
 
 ! BP(tv,jl)=((tj,vl)+(tl,vj))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(j,l))
             SCL=0.5D0
@@ -416,14 +440,18 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             BPTVJL=SCL*(TJVL+TLVJ)
 ! write element HP(ac,jl)
             IDX=ITGEU+NAS*(IJGEL-IISTA)
+#ifdef _MOLCAS_MPP_
             DBL_MB(MW+IDX-1)=BPTVJL
+#else
+            GA_Arrays(lg_w)%A(IDX)=BPTVJL
+#endif
           END DO
         END DO
 ************************************************************************
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  2      CONTINUE
       END DO
 ************************************************************************
@@ -469,16 +497,16 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             NV=NVTOT_CHOSYM(MUL(ISYT,ISYJ)) ! JSYM=ISYA*ISYJ=ISYC*ISYL
             ITJ=IT-1+NASH(ISYT)*(IJ-1)
             IVL=IV-1+NASH(ISYV)*(IL-1)
-            IOFFTJ=LCHOBUF+IOSYM(ISYT,ISYJ)+NV*ITJ
-            IOFFVL=LCHOBUF+IOSYM(ISYV,ISYL)+NV*IVL
-            TJVL=DDOT_(NV,WORK(IOFFTJ),1,WORK(IOFFVL),1)
+            IOFFTJ=1+IOSYM(ISYT,ISYJ)+NV*ITJ
+            IOFFVL=1+IOSYM(ISYV,ISYL)+NV*IVL
+            TJVL=DDOT_(NV,CHOBUF(IOFFTJ),1,CHOBUF(IOFFVL),1)
 
             NV=NVTOT_CHOSYM(MUL(ISYT,ISYL))
             ITL=IT-1+NASH(ISYT)*(IL-1)
             IVJ=IV-1+NASH(ISYV)*(IJ-1)
-            IOFFTL=LCHOBUF+IOSYM(ISYT,ISYL)+NV*ITL
-            IOFFVJ=LCHOBUF+IOSYM(ISYV,ISYJ)+NV*IVJ
-            TLVJ=DDOT_(NV,WORK(IOFFTL),1,WORK(IOFFVJ),1)
+            IOFFTL=1+IOSYM(ISYT,ISYL)+NV*ITL
+            IOFFVJ=1+IOSYM(ISYV,ISYJ)+NV*IVJ
+            TLVJ=DDOT_(NV,CHOBUF(IOFFTL),1,CHOBUF(IOFFVJ),1)
 
 ! BM(tv,jl)=((tj,vl)-(tl,vj))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(j,l))
             SCL=0.5D0
@@ -487,19 +515,23 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             BMTVJL=SCL*(TJVL-TLVJ)
 ! write element BM(tv,jl)
             IDX=ITGTU+NAS*(IJGTL-IISTA)
+#ifdef _MOLCAS_MPP_
             DBL_MB(MW+IDX-1)=BMTVJL
+#else
+            GA_Arrays(lg_w)%A(IDX)=BMTVJL
+#endif
           END DO
         END DO
 ************************************************************************
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  3      CONTINUE
       END DO
 ************************************************************************
 
-      CALL GETMEM('CHOBUF','FREE','REAL',LCHOBUF,NCHOBUF)
+      CALL mma_deallocate(CHOBUF)
 
       RETURN
       END
@@ -508,20 +540,23 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_F_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+#ifndef _MOLCAS_MPP_
+      use fake_GA, only: GA_Arrays
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-      DIMENSION IOSYM(8,8)
+      INTEGER IVEC
+
+      INTEGER IOSYM(8,8)
+      REAL*8, ALLOCATABLE:: CHOBUF(:)
 *      Logical Incore
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
-#else
-#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -541,9 +576,9 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
       CALL CHOVEC_SIZE(3,NCHOBUF,IOSYM)
 
-      CALL GETMEM('CHOBUF','ALLO','REAL',LCHOBUF,NCHOBUF)
+      CALL mma_allocate(CHOBUF,NCHOBUF,Label='CHOBUF')
 
-      CALL CHOVEC_READ(3,LCHOBUF)
+      CALL CHOVEC_READ(3,CHOBUF,NCHOBUF)
 
       iCASE=8
 ************************************************************************
@@ -584,16 +619,16 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             NV=NVTOT_CHOSYM(MUL(ISYA,ISYT)) ! JSYM=ISYA*ISYA=ISYC*ISYC
             IAT=IA-1+NSSH(ISYA)*(IT-1)
             ICV=IC-1+NSSH(ISYC)*(IV-1)
-            IOFFAT=LCHOBUF+IOSYM(ISYA,ISYT)+NV*IAT
-            IOFFCV=LCHOBUF+IOSYM(ISYC,ISYV)+NV*ICV
-            ATCV=DDOT_(NV,WORK(IOFFAT),1,WORK(IOFFCV),1)
+            IOFFAT=1+IOSYM(ISYA,ISYT)+NV*IAT
+            IOFFCV=1+IOSYM(ISYC,ISYV)+NV*ICV
+            ATCV=DDOT_(NV,CHOBUF(IOFFAT),1,CHOBUF(IOFFCV),1)
 
             NV=NVTOT_CHOSYM(MUL(ISYA,ISYV)) ! JSYM=ISYA*ISYA=ISYC*ISYC
             IAV=IA-1+NSSH(ISYA)*(IV-1)
             ICT=IC-1+NSSH(ISYC)*(IT-1)
-            IOFFAV=LCHOBUF+IOSYM(ISYA,ISYV)+NV*IAV
-            IOFFCT=LCHOBUF+IOSYM(ISYC,ISYT)+NV*ICT
-            AVCT=DDOT_(NV,WORK(IOFFAV),1,WORK(IOFFCT),1)
+            IOFFAV=1+IOSYM(ISYA,ISYV)+NV*IAV
+            IOFFCT=1+IOSYM(ISYC,ISYT)+NV*ICT
+            AVCT=DDOT_(NV,CHOBUF(IOFFAV),1,CHOBUF(IOFFCT),1)
 
 ! FP(tv,ac)=((at,cv)+(av,ct))*(1-Kron(t,v)/2)/(2*SQRT(1+Kron(a,c))
             SCL=0.5D0
@@ -602,14 +637,18 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             FPTVAC=SCL*(ATCV+AVCT)
 ! write element FP(tv,ac)
             IDX=ITGEU+NAS*(IAGEB-IISTA)
+#ifdef _MOLCAS_MPP_
             DBL_MB(MW+IDX-1)=FPTVAC
+#else
+            GA_Arrays(lg_W)%A(IDX)=FPTVAC
+#endif
           END DO
         END DO
 ************************************************************************
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  8      CONTINUE
       END DO
 ************************************************************************
@@ -655,16 +694,16 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             NV=NVTOT_CHOSYM(MUL(ISYA,ISYT)) ! JSYM=ISYA*ISYA=ISYC*ISYC
             IAT=IA-1+NSSH(ISYA)*(IT-1)
             ICV=IC-1+NSSH(ISYC)*(IV-1)
-            IOFFAT=LCHOBUF+IOSYM(ISYA,ISYT)+NV*IAT
-            IOFFCV=LCHOBUF+IOSYM(ISYC,ISYV)+NV*ICV
-            ATCV=DDOT_(NV,WORK(IOFFAT),1,WORK(IOFFCV),1)
+            IOFFAT=1+IOSYM(ISYA,ISYT)+NV*IAT
+            IOFFCV=1+IOSYM(ISYC,ISYV)+NV*ICV
+            ATCV=DDOT_(NV,CHOBUF(IOFFAT),1,CHOBUF(IOFFCV),1)
 
             NV=NVTOT_CHOSYM(MUL(ISYA,ISYV)) ! JSYM=ISYA*ISYA=ISYC*ISYC
             IAV=IA-1+NSSH(ISYA)*(IV-1)
             ICT=IC-1+NSSH(ISYC)*(IT-1)
-            IOFFAV=LCHOBUF+IOSYM(ISYA,ISYV)+NV*IAV
-            IOFFCT=LCHOBUF+IOSYM(ISYC,ISYT)+NV*ICT
-            AVCT=DDOT_(NV,WORK(IOFFAV),1,WORK(IOFFCT),1)
+            IOFFAV=1+IOSYM(ISYA,ISYV)+NV*IAV
+            IOFFCT=1+IOSYM(ISYC,ISYT)+NV*ICT
+            AVCT=DDOT_(NV,CHOBUF(IOFFAV),1,CHOBUF(IOFFCT),1)
 
 ! FM(tv,ac)= -((at,cv)-(av,ct))/(2*SQRT(1+Kron(a,c))
             SCL=0.5D0
@@ -673,19 +712,23 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             FMTVAC=SCL*(AVCT-ATCV)
 ! write element FM(tv,ac)
             IDX=ITGTU+NAS*(IAGTB-IISTA)
+#ifdef _MOLCAS_MPP_
             DBL_MB(MW+IDX-1)=FMTVAC
+#else
+            GA_Arrays(lg_w)%A(IDX)=FMTVAC
+#endif
           END DO
         END DO
 ************************************************************************
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  9      CONTINUE
       END DO
 ************************************************************************
 
-      CALL GETMEM('CHOBUF','FREE','REAL',LCHOBUF,NCHOBUF)
+      CALL mma_deallocate(CHOBUF)
 
       RETURN
       END
@@ -694,20 +737,23 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_H_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+#ifndef _MOLCAS_MPP_
+      use fake_GA, only: GA_Arrays
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-      DIMENSION IOSYM(8,8)
+      INTEGER IVEC
+
+      INTEGER IOSYM(8,8)
+      REAL*8, ALLOCATABLE:: CHOBUF(:)
 *      Logical Incore
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
-#else
-#define DBL_MB Work
 #endif
       INTEGER, PARAMETER :: NOSYM = 1
       REAL*8, ALLOCATABLE :: AIBJ(:,:)
@@ -734,9 +780,9 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 ************************************************************************
       CALL CHOVEC_SIZE(4,NCHOBUF,IOSYM)
 
-      CALL GETMEM('CHOBUF','ALLO','REAL',LCHOBUF,NCHOBUF)
+      CALL mma_allocate(CHOBUF,NCHOBUF,Label='CHOBUF')
 
-      CALL CHOVEC_READ(4,LCHOBUF)
+      CALL CHOVEC_READ(4,CHOBUF,NCHOBUF)
 
       iCASE=12
 
@@ -753,11 +799,11 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       DO IJGEL=IISTA,IIEND
         IJ=MIGEJ(1,IJGEL)
         IL=MIGEJ(2,IJGEL)
-        LIJOFF=LCHOBUF+NBLOCK*(IJ-1)
-        LILOFF=LCHOBUF+NBLOCK*(IL-1)
+        LIJOFF=1+NBLOCK*(IJ-1)
+        LILOFF=1+NBLOCK*(IL-1)
         ! precompute integral blocks
         CALL DGEMM_('T','N',NSSHT,NSSHT,NV,
-     &              1.0D0,WORK(LIJOFF),NV,WORK(LILOFF),NV,
+     &              1.0D0,CHOBUF(LIJOFF),NV,CHOBUF(LILOFF),NV,
      &              0.0D0,AIBJ,NSSHT)
         DO IAGEB=IASTA,IAEND ! these are always all elements
           IA=MAGEB(1,IAGEB)
@@ -771,13 +817,17 @@ CSVC: read in all the cholesky vectors (need all symmetries)
           HPACJL=SCL*(AJCL+ALCJ)
 ! write element HP(ac,jl)
           IDX=IAGEB+NAS*(IJGEL-IISTA)
+#ifdef _MOLCAS_MPP_
           DBL_MB(MW+IDX-1)=HPACJL
+#else
+          GA_Arrays(lg_w)%A(IDX)=HPACJL
+#endif
         END DO
       END DO
 ************************************************************************
       CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
       CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,NOSYM,iVEC)
-      CALL RHS_FREE (NAS,NIS,lg_W)
+      CALL RHS_FREE (lg_W)
 ************************************************************************
  12   CONTINUE
 
@@ -796,11 +846,11 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       DO IJGTL=IISTA,IIEND
         IJ=MIGTJ(1,IJGTL)
         IL=MIGTJ(2,IJGTL)
-        LIJOFF=LCHOBUF+NBLOCK*(IJ-1)
-        LILOFF=LCHOBUF+NBLOCK*(IL-1)
+        LIJOFF=1+NBLOCK*(IJ-1)
+        LILOFF=1+NBLOCK*(IL-1)
         ! precompute integral blocks
         CALL DGEMM_('T','N',NSSHT,NSSHT,NV,
-     &              1.0D0,WORK(LIJOFF),NV,WORK(LILOFF),NV,
+     &              1.0D0,CHOBUF(LIJOFF),NV,CHOBUF(LILOFF),NV,
      &              0.0D0,AIBJ,NSSHT)
         DO IAGTB=IASTA,IAEND ! these are always all elements
           IA=MAGTB(1,IAGTB)
@@ -812,18 +862,22 @@ CSVC: read in all the cholesky vectors (need all symmetries)
           HMACJL=SCL*(AJCL-ALCJ)
 ! write element HM(ac,jl)
           IDX=IAGTB+NAS*(IJGTL-IISTA)
+#ifdef _MOLCAS_MPP_
           DBL_MB(MW+IDX-1)=HMACJL
+#else
+          GA_Arrays(lg_W)%A(IDX)=HMACJL
+#endif
         END DO
       END DO
 ************************************************************************
 
       CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
       CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,NOSYM,iVEC)
-      CALL RHS_FREE (NAS,NIS,lg_W)
+      CALL RHS_FREE (lg_W)
  13   CONTINUE
 ************************************************************************
 
-      CALL GETMEM('CHOBUF','FREE','REAL',LCHOBUF,NCHOBUF)
+      CALL mma_deallocate(CHOBUF)
 
       DEALLOCATE(AIBJ)
 
@@ -834,22 +888,26 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_D_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
-      use caspt2_data, only: FIMO
+      use caspt2_global, only: FIMO
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+#ifndef _MOLCAS_MPP_
+      use fake_GA, only: GA_Arrays
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-      DIMENSION IOBRA1(8,8), IOKET1(8,8), IOBRA2(8,8), IOKET2(8,8)
+      INTEGER IVEC
+
+      INTEGER IOBRA1(8,8), IOKET1(8,8), IOBRA2(8,8), IOKET2(8,8)
+      REAL*8, ALLOCATABLE:: BRABUF1(:), KETBUF1(:),
+     &                      BRABUF2(:), KETBUF2(:)
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
-#else
-#define DBL_MB Work
 #endif
-      DIMENSION NFIMOES(8)
+      INTEGER NFIMOES(8)
 
       IF (iPrGlb.GE.DEBUG) THEN
         WRITE(6,*) 'RHS on demand: case D'
@@ -867,20 +925,20 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       CALL CHOVEC_SIZE(4,NBRABUF1,IOBRA1)
       CALL CHOVEC_SIZE(2,NKETBUF1,IOKET1)
 
-      CALL GETMEM('BRABUF1','ALLO','REAL',LBRABUF1,NBRABUF1)
-      CALL GETMEM('KETBUF1','ALLO','REAL',LKETBUF1,NKETBUF1)
+      CALL mma_allocate(BRABUF1,NBRABUF1,LABEL='BRABUF1')
+      CALL mma_allocate(KETBUF1,NKETBUF1,LABEL='KETBUF1')
 
-      CALL CHOVEC_READ(4,LBRABUF1)
-      CALL CHOVEC_READ(2,LKETBUF1)
+      CALL CHOVEC_READ(4,BRABUF1,NBRABUF1)
+      CALL CHOVEC_READ(2,KETBUF1,NKETBUF1)
 
       CALL CHOVEC_SIZE(3,NBRABUF2,IOBRA2)
       CALL CHOVEC_SIZE(1,NKETBUF2,IOKET2)
 
-      CALL GETMEM('BRABUF2','ALLO','REAL',LBRABUF2,NBRABUF2)
-      CALL GETMEM('KETBUF2','ALLO','REAL',LKETBUF2,NKETBUF2)
+      CALL mma_allocate(BRABUF2,NBRABUF2,LABEL='BRABUF2')
+      CALL mma_allocate(KETBUF2,NKETBUF2,LABEL='KETBUF2')
 
-      CALL CHOVEC_READ(3,LBRABUF2)
-      CALL CHOVEC_READ(1,LKETBUF2)
+      CALL CHOVEC_READ(3,BRABUF2,NBRABUF2)
+      CALL CHOVEC_READ(1,KETBUF2,NKETBUF2)
 
       iCASE=5
 ************************************************************************
@@ -935,14 +993,18 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             NV=NVTOT_CHOSYM(MUL(ISYA,ISYJ))
             IOAJ=IA-1+NSSH(ISYA)*(IJ-1)
             IOTV=IT-1+NASH(ISYT)*(IV-1)
-            IOFFAJ=LBRABUF1+IOBRA1(ISYA,ISYJ)+NV*IOAJ
-            IOFFTV=LKETBUF1+IOKET1(ISYT,ISYV)+NV*IOTV
-            AJTV=DDOT_(NV,WORK(IOFFAJ),1,WORK(IOFFTV),1)
+            IOFFAJ=1+IOBRA1(ISYA,ISYJ)+NV*IOAJ
+            IOFFTV=1+IOKET1(ISYT,ISYV)+NV*IOTV
+            AJTV=DDOT_(NV,BRABUF1(IOFFAJ),1,KETBUF1(IOFFTV),1)
 
 ! D1(tv,aj)=(aj,tv) + FIMO(a,j)*Kron(t,v)/NACTEL
 ! integrals only
             IDX=ITV+NAS*(IAJ-IISTA)
+#ifdef _MOLCAS_MPP_
             DBL_MB(MW+IDX-1)=AJTV
+#else
+            GA_Arrays(lg_w)%A(IDX)=AJTV
+#endif
           END DO
 ! now, dress with FIMO(a,j), only if T==V, so ISYT==ISYV, so if ISYM==1
           IF (ISYM.EQ.1) THEN
@@ -952,7 +1014,12 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             DO IUABS=1,NASHT
               IUU=KTU(IUABS,IUABS)
               IDX=IUU+NAS*(IAJ-IISTA)
+#ifdef _MOLCAS_MPP_
               DBL_MB(MW+IDX-1)=DBL_MB(MW+IDX-1)+ONEADD
+#else
+              GA_Arrays(lg_w)%A(IDX)=GA_Arrays(lg_w)%A(IDX)
+     &                                  +ONEADD
+#endif
             END DO
           END IF
           DO ITV=IASTA2,IAEND2 ! these are always all elements
@@ -966,30 +1033,34 @@ CSVC: read in all the cholesky vectors (need all symmetries)
             NV=NVTOT_CHOSYM(MUL(ISYA,ISYV))
             IOAV=IA-1+NSSH(ISYA)*(IV-1)
             IOTJ=IT-1+NASH(ISYT)*(IJ-1)
-            IOFFAV=LBRABUF2+IOBRA2(ISYA,ISYV)+NV*IOAV
-            IOFFTJ=LKETBUF2+IOKET2(ISYT,ISYJ)+NV*IOTJ
-            AVTJ=DDOT_(NV,WORK(IOFFAV),1,WORK(IOFFTJ),1)
+            IOFFAV=1+IOBRA2(ISYA,ISYV)+NV*IOAV
+            IOFFTJ=1+IOKET2(ISYT,ISYJ)+NV*IOTJ
+            AVTJ=DDOT_(NV,BRABUF2(IOFFAV),1,KETBUF2(IOFFTJ),1)
 
 ! D2(tv,aj)=(av,tj) + FIMO(a,j)*Kron(t,v)/NACTEL
             IDX=ITV+NAS*(IAJ-IISTA)
+#ifdef _MOLCAS_MPP_
             DBL_MB(MW+IDX-1)=AVTJ
+#else
+            GA_Arrays(lg_W)%A(IDX)=AVTJ
+#endif
           END DO
         END DO
 ************************************************************************
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  8      CONTINUE
 
       END DO
 ************************************************************************
 
-      CALL GETMEM('BRABUF1','FREE','REAL',LBRABUF1,NBRABUF1)
-      CALL GETMEM('KETBUF1','FREE','REAL',LKETBUF1,NKETBUF1)
+      CALL mma_deallocate(BRABUF1)
+      CALL mma_deallocate(KETBUF1)
 
-      CALL GETMEM('BRABUF2','FREE','REAL',LBRABUF2,NBRABUF2)
-      CALL GETMEM('KETBUF2','FREE','REAL',LKETBUF2,NKETBUF2)
+      CALL mma_deallocate(BRABUF2)
+      CALL mma_deallocate(KETBUF2)
 
 ************************************************************************
 
@@ -1000,20 +1071,23 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_E_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+#ifndef _MOLCAS_MPP_
+      use fake_GA, only: GA_Arrays
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-      DIMENSION IOBRA(8,8), IOKET(8,8)
+      INTEGER IVEC
+
+      INTEGER IOBRA(8,8), IOKET(8,8)
+      REAL*8, ALLOCATABLE:: BRABUF(:), KETBUF(:)
 *      Logical Incore
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
-#else
-#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -1043,11 +1117,11 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       CALL CHOVEC_SIZE(4,NBRABUF,IOBRA)
       CALL CHOVEC_SIZE(1,NKETBUF,IOKET)
 
-      CALL GETMEM('BRABUF','ALLO','REAL',LBRABUF,NBRABUF)
-      CALL GETMEM('KETBUF','ALLO','REAL',LKETBUF,NKETBUF)
+      CALL mma_allocate(BRABUF,NBRABUF,LABEL='BRABUF')
+      CALL mma_allocate(KETBUF,NKETBUF,LABEL='KETBUF')
 
-      CALL CHOVEC_READ(4,LBRABUF)
-      CALL CHOVEC_READ(1,LKETBUF)
+      CALL CHOVEC_READ(4,BRABUF,NBRABUF)
+      CALL CHOVEC_READ(1,KETBUF,NKETBUF)
 
       iCASE=6
 ************************************************************************
@@ -1095,16 +1169,16 @@ CSVC: read in all the cholesky vectors (need all symmetries)
               NV=NVTOT_CHOSYM(MUL(ISYA,ISYJ))
               IAJ=IA-1+NSSH(ISYA)*(IJ-1)
               IVL=IV-1+NASH(ISYV)*(IL-1)
-              IOFFAJ=LBRABUF+IOBRA(ISYA,ISYJ)+NV*IAJ
-              IOFFVL=LKETBUF+IOKET(ISYV,ISYL)+NV*IVL
-              AJVL=DDOT_(NV,WORK(IOFFAJ),1,WORK(IOFFVL),1)
+              IOFFAJ=1+IOBRA(ISYA,ISYJ)+NV*IAJ
+              IOFFVL=1+IOKET(ISYV,ISYL)+NV*IVL
+              AJVL=DDOT_(NV,BRABUF(IOFFAJ),1,KETBUF(IOFFVL),1)
 
               NV=NVTOT_CHOSYM(MUL(ISYA,ISYL))
               IAL=IA-1+NSSH(ISYA)*(IL-1)
               IVJ=IV-1+NASH(ISYV)*(IJ-1)
-              IOFFAL=LBRABUF+IOBRA(ISYA,ISYL)+NV*IAL
-              IOFFVJ=LKETBUF+IOKET(ISYV,ISYJ)+NV*IVJ
-              ALVJ=DDOT_(NV,WORK(IOFFAL),1,WORK(IOFFVJ),1)
+              IOFFAL=1+IOBRA(ISYA,ISYL)+NV*IAL
+              IOFFVJ=1+IOKET(ISYV,ISYJ)+NV*IVJ
+              ALVJ=DDOT_(NV,BRABUF(IOFFAL),1,KETBUF(IOFFVJ),1)
 
 ! EP(v,ajl)=((aj,vl)+(al,vj))/SQRT(2+2*Kron(j,l))
               IF (ILABS.EQ.IJABS) THEN
@@ -1115,7 +1189,11 @@ CSVC: read in all the cholesky vectors (need all symmetries)
               EP=SCL*(AJVL+ALVJ)
 ! write element EP
               IDX=IV+NAS*(IAJGEL+IOFF-IISTA)
+#ifdef _MOLCAS_MPP_
               DBL_MB(MW+IDX-1)=EP
+#else
+              GA_Arrays(lg_w)%A(IDX)=EP
+#endif
             END DO
           END DO
 
@@ -1125,7 +1203,7 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  6      CONTINUE
       END DO
 ************************************************************************
@@ -1178,22 +1256,26 @@ CSVC: read in all the cholesky vectors (need all symmetries)
               NV=NVTOT_CHOSYM(MUL(ISYA,ISYJ))
               IAJ=IA-1+NSSH(ISYA)*(IJ-1)
               IVL=IV-1+NASH(ISYV)*(IL-1)
-              IOFFAJ=LBRABUF+IOBRA(ISYA,ISYJ)+NV*IAJ
-              IOFFVL=LKETBUF+IOKET(ISYV,ISYL)+NV*IVL
-              AJVL=DDOT_(NV,WORK(IOFFAJ),1,WORK(IOFFVL),1)
+              IOFFAJ=1+IOBRA(ISYA,ISYJ)+NV*IAJ
+              IOFFVL=1+IOKET(ISYV,ISYL)+NV*IVL
+              AJVL=DDOT_(NV,BRABUF(IOFFAJ),1,KETBUF(IOFFVL),1)
 
               NV=NVTOT_CHOSYM(MUL(ISYA,ISYL))
               IAL=IA-1+NSSH(ISYA)*(IL-1)
               IVJ=IV-1+NASH(ISYV)*(IJ-1)
-              IOFFAL=LBRABUF+IOBRA(ISYA,ISYL)+NV*IAL
-              IOFFVJ=LKETBUF+IOKET(ISYV,ISYJ)+NV*IVJ
-              ALVJ=DDOT_(NV,WORK(IOFFAL),1,WORK(IOFFVJ),1)
+              IOFFAL=1+IOBRA(ISYA,ISYL)+NV*IAL
+              IOFFVJ=1+IOKET(ISYV,ISYJ)+NV*IVJ
+              ALVJ=DDOT_(NV,BRABUF(IOFFAL),1,KETBUF(IOFFVJ),1)
 
 ! EM(v,ajl)=((aj,vl)-(al,vj))*SQRT(3/2)
               EM=SQRTA*(AJVL-ALVJ)
 ! write element EM
               IDX=IV+NAS*(IAJGTL+IOFF-IISTA)
+#ifdef _MOLCAS_MPP_
               DBL_MB(MW+IDX-1)=EM
+#else
+              GA_Arrays(lg_w)%A(IDX)=EM
+#endif
             END DO
           END DO
 
@@ -1203,13 +1285,13 @@ CSVC: read in all the cholesky vectors (need all symmetries)
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  7      CONTINUE
       END DO
 ************************************************************************
 
-      CALL GETMEM('BRABUF','FREE','REAL',LBRABUF,NBRABUF)
-      CALL GETMEM('KETBUF','FREE','REAL',LKETBUF,NKETBUF)
+      CALL mma_deallocate(BRABUF)
+      CALL mma_deallocate(KETBUF)
 
       RETURN
       END
@@ -1218,20 +1300,23 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       SUBROUTINE RHSOD_G_NOSYM(IVEC)
       USE SUPERINDEX
       USE CHOVEC_IO
-      use caspt2_output, only:iPrGlb
+      use caspt2_global, only:iPrGlb
       use PrintLevel, only: debug
+      use EQSOLV
+      use stdalloc, only: mma_allocate, mma_deallocate
+#ifndef _MOLCAS_MPP_
+      use fake_GA, only: GA_Arrays
+#endif
       IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
 #include "caspt2.fh"
-#include "WrkSpc.fh"
-#include "eqsolv.fh"
-      DIMENSION IOBRA(8,8), IOKET(8,8)
+      INTEGER IVEC
+
+      INTEGER IOBRA(8,8), IOKET(8,8)
+      REAL*8, ALLOCATABLE:: BRABUF(:), KETBUF(:)
 *      Logical Incore
 #ifdef _MOLCAS_MPP_
 #include "global.fh"
 #include "mafdecls.fh"
-#else
-#define DBL_MB Work
 #endif
 
       IF (iPrGlb.GE.DEBUG) THEN
@@ -1261,11 +1346,11 @@ CSVC: read in all the cholesky vectors (need all symmetries)
       CALL CHOVEC_SIZE(3,NBRABUF,IOBRA)
       CALL CHOVEC_SIZE(4,NKETBUF,IOKET)
 
-      CALL GETMEM('BRABUF','ALLO','REAL',LBRABUF,NBRABUF)
-      CALL GETMEM('KETBUF','ALLO','REAL',LKETBUF,NKETBUF)
+      CALL mma_allocate(BRABUF,NBRABUF,LABEL='BRABUF')
+      CALL mma_allocate(KETBUF,NKETBUF,LABEL='KETBUF')
 
-      CALL CHOVEC_READ(3,LBRABUF)
-      CALL CHOVEC_READ(4,LKETBUF)
+      CALL CHOVEC_READ(3,BRABUF,NBRABUF)
+      CALL CHOVEC_READ(4,KETBUF,NKETBUF)
 
       iCASE=10
 ************************************************************************
@@ -1313,16 +1398,16 @@ CSVC: read in all the cholesky vectors (need all symmetries)
               NV=NVTOT_CHOSYM(MUL(ISYA,ISYV))
               IAV=IA-1+NSSH(ISYA)*(IV-1)
               ICJ=IC-1+NSSH(ISYC)*(IJ-1)
-              IOFFAV=LBRABUF+IOBRA(ISYA,ISYV)+NV*IAV
-              IOFFCJ=LKETBUF+IOKET(ISYC,ISYJ)+NV*ICJ
-              AVCJ=DDOT_(NV,WORK(IOFFAV),1,WORK(IOFFCJ),1)
+              IOFFAV=1+IOBRA(ISYA,ISYV)+NV*IAV
+              IOFFCJ=1+IOKET(ISYC,ISYJ)+NV*ICJ
+              AVCJ=DDOT_(NV,BRABUF(IOFFAV),1,KETBUF(IOFFCJ),1)
 
               NV=NVTOT_CHOSYM(MUL(ISYC,ISYV))
               ICV=IC-1+NSSH(ISYC)*(IV-1)
               IAJ=IA-1+NSSH(ISYA)*(IJ-1)
-              IOFFCV=LBRABUF+IOBRA(ISYC,ISYV)+NV*ICV
-              IOFFAJ=LKETBUF+IOKET(ISYA,ISYJ)+NV*IAJ
-              CVAJ=DDOT_(NV,WORK(IOFFCV),1,WORK(IOFFAJ),1)
+              IOFFCV=1+IOBRA(ISYC,ISYV)+NV*ICV
+              IOFFAJ=1+IOKET(ISYA,ISYJ)+NV*IAJ
+              CVAJ=DDOT_(NV,BRABUF(IOFFCV),1,KETBUF(IOFFAJ),1)
 
 C GP(v,jac)=((av,cj)+(cv,aj))/SQRT(2+2*Kron(a,b))
               IF (IAABS.EQ.ICABS) THEN
@@ -1333,7 +1418,11 @@ C GP(v,jac)=((av,cj)+(cv,aj))/SQRT(2+2*Kron(a,b))
               GP=SCL*(AVCJ+CVAJ)
 ! write element EP
               IDX=IV+NAS*(IJAGEC+IOFF-IISTA)
+#ifdef _MOLCAS_MPP_
               DBL_MB(MW+IDX-1)=GP
+#else
+              GA_Arrays(lg_w)%A(IDX)=GP
+#endif
             END DO
           END DO
 
@@ -1343,7 +1432,7 @@ C GP(v,jac)=((av,cj)+(cv,aj))/SQRT(2+2*Kron(a,b))
 
         CALL RHS_RELEASE_UPDATE (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  10     CONTINUE
       END DO
 ************************************************************************
@@ -1396,22 +1485,26 @@ C GP(v,jac)=((av,cj)+(cv,aj))/SQRT(2+2*Kron(a,b))
               NV=NVTOT_CHOSYM(MUL(ISYA,ISYV))
               IAV=IA-1+NSSH(ISYA)*(IV-1)
               ICJ=IC-1+NSSH(ISYC)*(IJ-1)
-              IOFFAV=LBRABUF+IOBRA(ISYA,ISYV)+NV*IAV
-              IOFFCJ=LKETBUF+IOKET(ISYC,ISYJ)+NV*ICJ
-              AVCJ=DDOT_(NV,WORK(IOFFAV),1,WORK(IOFFCJ),1)
+              IOFFAV=1+IOBRA(ISYA,ISYV)+NV*IAV
+              IOFFCJ=1+IOKET(ISYC,ISYJ)+NV*ICJ
+              AVCJ=DDOT_(NV,BRABUF(IOFFAV),1,KETBUF(IOFFCJ),1)
 
               NV=NVTOT_CHOSYM(MUL(ISYC,ISYV))
               ICV=IC-1+NSSH(ISYC)*(IV-1)
               IAJ=IA-1+NSSH(ISYA)*(IJ-1)
-              IOFFCV=LBRABUF+IOBRA(ISYC,ISYV)+NV*ICV
-              IOFFAJ=LKETBUF+IOKET(ISYA,ISYJ)+NV*IAJ
-              CVAJ=DDOT_(NV,WORK(IOFFCV),1,WORK(IOFFAJ),1)
+              IOFFCV=1+IOBRA(ISYC,ISYV)+NV*ICV
+              IOFFAJ=1+IOKET(ISYA,ISYJ)+NV*IAJ
+              CVAJ=DDOT_(NV,BRABUF(IOFFCV),1,KETBUF(IOFFAJ),1)
 
 C GM(v,jac)=((av,cj)-(cv,aj))*SQRT(3/2)
               GM=SQRTA*(AVCJ-CVAJ)
 ! write element GM
               IDX=IV+NAS*(IJAGTC+IOFF-IISTA)
+#ifdef _MOLCAS_MPP_
               DBL_MB(MW+IDX-1)=GM
+#else
+              GA_Arrays(lg_w)%A(IDX)=GM
+#endif
             END DO
           END DO
 
@@ -1421,13 +1514,13 @@ C GM(v,jac)=((av,cj)-(cv,aj))*SQRT(3/2)
 
         CALL RHS_Release_Update (lg_W,IASTA,IAEND,IISTA,IIEND)
         CALL RHS_SAVE (NAS,NIS,lg_W,iCASE,iSYM,iVEC)
-        CALL RHS_FREE (NAS,NIS,lg_W)
+        CALL RHS_FREE (lg_W)
  11     CONTINUE
       END DO
 ************************************************************************
 
-      CALL GETMEM('BRABUF','FREE','REAL',LBRABUF,NBRABUF)
-      CALL GETMEM('KETBUF','FREE','REAL',LKETBUF,NKETBUF)
+      CALL mma_deallocate(BRABUF)
+      CALL mma_deallocate(KETBUF)
 
       RETURN
       END
