@@ -20,21 +20,31 @@
 * Jeppe Olsen,  Oct 1994
 * G. Li Manni, June 2024: Scale-up capability for single SD ROHF type calculations
 *
-      IMPLICIT REAL*8(A-H,O-Z)
-*
-*
-#include "mxpdim.fh"
-#include "cgas.fh"
-#include "lucinp.fh"
-#include "orbinp.fh"
-#include "cstate.fh"
-#include "gasstr.fh"
-#include "strinp.fh"
-#include "stinf.fh"
-#include "crun.fh"
+      use lucia_data, only: NGAS,NCISPC,NMXOCCLS,IGSOCC,IGSOCCX,IPHGAS,
+     &                      IPHGAS1
+      use lucia_data, only: MS2
+      use lucia_data, only: NGRP,NSTTP,NTSPGP,NSPGPFTP,IBSPGPFTP,NELFTP,
+     &                      NGPSTR, MXGSOC,MNGSOC,IBGPSTR,IGSFGP,
+     &                      ISPGPFTP,MNELFGP,MNGSOC,MXELFGP,MXGSOC,
+     &                      NELFGP,NELFSPGP,NSTFGP
+      use lucia_data, only: NACTEL
+      use lucia_data, only: MXTSOB_P,MXTSOB_H,NOBPT
+      use lucia_data, only: NOCTYP,ISTAC
+      use lucia_data, only: NSTTYP,NELEC
+      use lucia_data, only: MXPSTT
+      IMPLICIT NONE
+      INTEGER IPRNT
+
 *. Local scratch
-      DIMENSION IOCTYP(MXPSTT),IREOSPGP(MXPSTT),ISCR(MXPSTT)
+      INTEGER IOCTYP(MXPSTT),IREOSPGP(MXPSTT),ISCR(MXPSTT)
       INTEGER IOCCLS(1),IBASSPC(1)
+      INTEGER NTESTL,NTEST,IGAS,MINI,MAXI,ICISPC,IPHGASL,NPHGAS,NOCCLS,
+     &        NAEL,NBEL,MAXSUB,IGRP,MXAL,MNAL,MXBL,MNBL,MXA1,MXB1,MNA1,
+     &        MNB1,MXA,MXB,MNA,MNB,MNAB,MXAB,IADD,JGRP,IEL,IITYPE,ITP,
+     &        IOFF,NABEL,NSPGP_TOT,ITYP,NELEC_REF,IDEL,NSPGP,IONE,NEL,
+     &        IRED,NONEW,I_AM_OKAY,IOELMX,IBTYP,ISPGP,IDIM,JGAS,ISPGP_N,
+     &        ISPGP_O
+      INTEGER, EXTERNAL:: IBION_LUCIA
 *
       NTESTL = 00
       NTEST = MAX(IPRNT,NTESTL)
@@ -614,6 +624,4 @@ C?      CALL IWRTMA(IREOSPGP,1,NSPGP,1,NSPGP)
         END DO
       END IF
 *
-*
-      RETURN
-      END
+      END SUBROUTINE STRTYP_GAS
