@@ -32,17 +32,20 @@
 * is zero if test fails
 * IGENSG .ne. 0 assumes general signs of strings given in ISGNA,ISGNB
       use stdalloc, only: mma_allocate, mma_deallocate
-      IMPLICIT REAL*8 (A-H,O-Z)
-*.Specific input
-      DIMENSION ISGNA(*),ISGNB(*)
-      DIMENSION ICONF(*),NCNFTP(*)
-      DIMENSION IOOS(*)
-*.General input
-      INTEGER IPRODT(*)
-*.Output
-      DIMENSION ICTSDT(*)
+      IMPLICIT None
+      Integer, Intent(Out):: ICTSDT(*)
+      Integer, Intent(InOut):: ICONF(*)
+      Integer :: iRefSM, nOrb
+      INTEGER, Intent(In):: IPRODT(*)
+      Integer, Intent(In):: NCNFTP(*)
+      Integer :: NEL,ICNSTR,IGENSG
+      Integer, Intent(In):: ISGNA(*),ISGNB(*)
+      Integer :: IAGRP,IBGRP
+      Integer, Intent(In):: IOOS(*)
+      Integer :: NORB1,NORB2,NORB3,NEL1MN,NEL3MX,NAEL,NBEL,MINOP,MAXOP
+      Real*8 :: PSSIGN
+      Integer :: IPRNT
 *.Scratch
-#include "dmrginfo_mclr.fh"
       Integer, Allocatable:: KL1(:), KL2(:), KL3(:)
 * NOTE : NCNFTP IS COLUMN FOR SYMMETRY GIVEN , NOT COMPLETE MATRIX.
 * Dim of IWORK : MAX(3*NORB,(MXDT+2)*NEL),
@@ -76,8 +79,7 @@
      &            NORB,NEL,
      &            IGENSG,ISGNA,ISGNB,ICNSTR,IAGRP,IBGRP,IOOS,PSSIGN,
      &            IPRNT)
-      RETURN
-      END
+      END SUBROUTINE CNFORD
 *
 *----------------------------------------------------------------------
 *
@@ -107,22 +109,26 @@
 * by calling CICNCH.ICNFOK(ICNF) is 1 of tests are passed, ICNFOK(ICNF)
 * is zero if test fails
       use stdalloc, only: mma_allocate, mma_deallocate
-      IMPLICIT REAL*8 (A-H,O-Z)
-
-      DIMENSION ICONF(*),IPRODT(*)
-      DIMENSION ICTSDT(*)
-      DIMENSION ISGNA(*),ISGNB(*)
-      DIMENSION IOOS(*)
+      use MCLR_Data, only: NTYP,NCNATS,NDPCNT,MINOP
+      IMPLICIT NONE
+      INTEGER ICONF(*),ICTSDT(*)
+      INTEGER NAEL,NBEL
+      INTEGER IPRODT(*)
+      INTEGER IREFSM,NORB,NEL,IGENSG
+      INTEGER ISGNA(*),ISGNB(*)
+      INTEGER ICNSTR,IAGRP,IBGRP
+      INTEGER IOOS(*)
+      REAL*8 PSSIGN
+      INTEGER IPRNT
 C
 C IWORK should at least be of length (MXDT+2)*NEL,
 C where MXDT is the largest number of prototype determinants occuring
 C in a single block.
 C
 *./SPINFO/
-#include "detdim.fh"
-#include "spinfo_mclr.fh"
-#include "dmrginfo_mclr.fh"
       Integer, Allocatable:: LDTBL(:), LIA(:), LIB(:), SCR23(:)
+      INTEGER NTEST,MXDT,ITYP,ICNF,JDTABS,IPSFAC,ISGNAB,ICNBS0,IPBAS,
+     &        IJKL_NUM,IDET,IOPEN,ICL,IOCC,IC,ICNBS,JDET,ISIGN,IABNUM
 *
        NEL = NAEL + NBEL
        NTEST=0000
@@ -195,22 +201,28 @@ C Separate determinants into strings and determine string number .
       CALL mma_deallocate(LDTBL)
 
 C
-      RETURN
 c Avoid unused argument warnings
       IF (.FALSE.) CALL Unused_integer(ICNSTR)
-      END
-      FUNCTION IABNUM(IASTR,IBSTR,IAGRP,IBGRP,IGENSG,
+      END SUBROUTINE CNTOST
+
+      Integer FUNCTION IABNUM(IASTR,IBSTR,IAGRP,IBGRP,IGENSG,
      &                ISGNA,ISGNB,ISGNAB,IOOS,NORB,IPSFAC,PSSIGN,
      &                IPRNT)
-      Use Str_info
+      Use Str_info, only: STR,nElec,NoCTyp
 *
 * Encapsulation routine for IABNUS
 *
-      IMPLICIT REAL*8 (A-H,O-Z)
-      DIMENSION IASTR(*),IBSTR(*)
-      DIMENSION ISGNA(*),ISGNB(*)
-#include "detdim.fh"
-      DIMENSION IOOS(NOCTYP(IAGRP),NOCTYP(IBGRP),*)
+      IMPLICIT None
+      INTEGER IASTR(*),IBSTR(*)
+      INTEGER IAGRP,IBGRP,IGENSG
+      INTEGER ISGNA(*),ISGNB(*)
+      INTEGER ISGNAB
+      INTEGER IOOS(NOCTYP(IAGRP),NOCTYP(IBGRP),*)
+      INTEGER NORB,IPSFAC
+      REAL*8 PSSIGN
+      INTEGER IPRNT
+
+      INTEGER, EXTERNAL:: IABNUS
 *
       IABNUM = IABNUS(IASTR,NELEC(IAGRP),Str(IAGRP)%STREO,
      &                Str(IAGRP)%STCL,Str(IAGRP)%STSM,
@@ -224,9 +236,9 @@ c Avoid unused argument warnings
      &                Str(IBGRP)%NSTSO,
      &                IOOS,NORB,IGENSG,ISGNA,ISGNB,ISGNAB,PSSIGN,
      &                IPSFAC,IPRNT)
-      RETURN
-      END
-      FUNCTION IABNUS(IASTR,NAEL,IAORD,ITPFSA,ISMFSA,NOCTPA,ZA,
+      END FUNCTION IABNUM
+
+      Integer FUNCTION IABNUS(IASTR,NAEL,IAORD,ITPFSA,ISMFSA,NOCTPA,ZA,
      &                ISSOA,NSSOA,
      &                IBSTR,NBEL,IBORD,ITPFSB,ISMFSB,NOCTPB,ZB,
      &                ISSOB,NSSOB,
@@ -239,16 +251,24 @@ c Avoid unused argument warnings
 * If PSSIGN .ne. 0, the determinant with higher alpha number is picked
 * and phase factor IPSFAC calculated. This corresponds to
 * configuration order
-      IMPLICIT REAL*8 (A-H,O-Z)
-      DIMENSION IASTR(NAEL),IBSTR(NBEL)
-      DIMENSION IAORD(*),IBORD(*)
-      INTEGER ZA(*),ZB(*)
-      INTEGER NSSOA(NOCTPA,*),NSSOB(NOCTPB,*)
-      INTEGER ISSOA(NOCTPA,*),ISSOB(NOCTPB,*)
+      IMPLICIT NONE
+      INTEGER NAEL
+      INTEGER IASTR(NAEL),IAORD(*),ITPFSA(*),ISMFSA(*)
+      INTEGER NOCTPA
+      INTEGER ZA(*),ISSOA(NOCTPA,*),NSSOA(NOCTPA,*)
+      INTEGER NBEL
+      INTEGER IBSTR(NBEL),IBORD(*),ITPFSB(*),ISMFSB(*)
+      INTEGER NOCTPB
+      INTEGER ZB(*),ISSOB(NOCTPB,*),NSSOB(NOCTPB,*)
       INTEGER IOOS(NOCTPA,NOCTPB,*)
+      INTEGER NORB,IGENSG
       INTEGER ISGNA(*),ISGNB(*)
-      INTEGER ITPFSA(*),ITPFSB(*)
-      INTEGER ISMFSA(*),ISMFSB(*)
+      REAL*8 PSSIGN
+      INTEGER IPSFAC,IPRNT
+
+!     Local variables
+      INTEGER NTEST,IANUM,IBNUM,ISGNAB,IASYM,IBSYM,IATP,IBTP,
+     &        IAREL,IBREL,ISTRNM
 *
 * Jeppe Olsen
 *
@@ -334,12 +354,8 @@ C?    END IF
          WRITE(6,*) ' Corresponding determinant number ', IABNUS
       END IF
 
-!      write(117,"(A,1X,I20)",advance='no')" SD_number",IABNUS ! yma
-!      write(117,*)
-
 *
-      RETURN
-      END
+      END FUNCTION IABNUS
 
 *
 *----------------------------------------------------------------------
@@ -348,26 +364,25 @@ C?    END IF
 *----------------------------------------------------------------------
 *
       Subroutine CsfInf(lSym,iSpin,MS,iSPC,iPrnt,nsym)
-      use Str_Info
+      use Str_Info, only: STR,CNSM,CFTP,DFTP,DTOC,NELEC,NOCTYP
       use stdalloc, only: mma_allocate, mma_deallocate
+      use MCLR_Data, only: i1,iAnders,lConf,llDET
+      use MCLR_Data, only: iRefSM,iDC,MS2,PSSIGN
+      use MCLR_Data, only: LuCSF2SD
+      use MCLR_Data, only: IASTFI,IBSTFI,ISMOST,MNR1IC,MXR3IC,NELCI
+      use MCLR_Data, only: NACOB,NORB1,NORB2,NORB3
+      use MCLR_Data, only: MAXOP,MINOP,NCNATS
+      use CandS, only: ICSM,ISSM,ICSPC,ISSPC
+      use csm_data, only: NSMST
 *
-      Implicit Real*8 (A-H,O-Z)
+      Implicit None
+      Integer lSym,iSpin,MS,iSPC,iPrnt,nsym
 *
-#include "cstate_mclr.fh"
-#include "detdim.fh"
-#include "orbinp_mclr.fh"
-#include "csm.fh"
-#include "cicisp_mclr.fh"
-#include "spinfo_mclr.fh"
-#include "cands.fh"
-#include "Files_mclr.fh"
       integer idum(1)
       Integer, Allocatable:: SIOIO(:), SBLTP(:), IOOS1(:),
      &                       NOOS1(:)
-*     COMMONBLOCK THE SUPPORT STORAGE OF REORDERING VECTOR
-*     ON DISK
-#include "csfsd.fh"
-
+      Integer NEL,IATP,IBTP,NOCTPA,NOCTPB,MNELR1,MXELR3,NOOS,IA,ISYM,
+     &        NCOMB,LLCSF
 *
 *
 C.... Sorry about this  but this is just to tell the program
@@ -444,10 +459,9 @@ C     MXELR3 = MNR1IC(ISPC)
       Call mma_deallocate(SBLTP)
       Call mma_deallocate(SIOIO)
 *
-      RETURN
 c Avoid unused argument warnings
       IF (.FALSE.) CALL Unused_integer(MS)
-      END
+      END Subroutine CsfInf
 *
 *----------------------------------------------------------------------
 *
@@ -480,10 +494,17 @@ c Avoid unused argument warnings
 * the determinant normalization
 *
       use stdalloc, only: mma_allocate, mma_deallocate
-      IMPLICIT REAL*8 (A-H,O-Z)
-      DIMENSION IDET(NOPEN,NDET),ICSF(NOPEN,NCSF)
-      DIMENSION CDC(NDET,NCSF)
+      IMPLICIT NONE
+      INTEGER NOPEN,NDET,NCSF
+      INTEGER IDET(NOPEN,NDET),ICSF(NOPEN,NCSF)
+      REAL*8 CDC(NDET,NCSF)
+      Real*8 PSSIGN
+      Integer IPRCSF
+
+!     Local variables
       Real*8, Allocatable:: LMDET(:), lSCSF(:)
+      INTEGER NTEST,JDET,JDADD,IOPEN,JCSF
+      REAL*8 CMBFAC,COEF,SIGN
 
       NTEST = 0000
       NTEST = MAX(IPRCSF,NTEST)
@@ -549,8 +570,7 @@ C
       END IF
 
 C
-      RETURN
-      END
+      END SUBROUTINE CSFDET
 *
 *----------------------------------------------------------------------
 *
@@ -574,10 +594,16 @@ C
 * we select as the unique determinants those with first electron
 * having alpha spin
 *
-      INTEGER ADD
-      DIMENSION IABDET(NOPEN,*),IABUPP(NOPEN,*)
-      DIMENSION IWORK(*)
+      Implicit None
+      INTEGER IWORK(*)
+      INTEGER NOPEN,MS2,NDET
+      INTEGER IABDET(NOPEN,*),IABUPP(NOPEN,*)
       REAL*8 PSSIGN
+      INTEGER IFLAG,IPRCSF
+
+!     local variables
+      INTEGER ADD
+      INTEGER NUPPER,MX,I,J,NALPHA,MS2L,lUPPER,IEL
 *
 * LENGTH OF IWORK MUST BE AT LEAST NOPEN
 *
@@ -638,10 +664,9 @@ C
   200 CONTINUE
 C
 *     XMSD2=DBLE(MS2)/2
-      RETURN
 c Avoid unused argument warnings
       IF (.FALSE.) CALL Unused_integer(IPRCSF)
-      END
+      END SUBROUTINE SPNCOM
 *
 *----------------------------------------------------------------------
 *
@@ -657,11 +682,17 @@ c Avoid unused argument warnings
 *
 *
       use stdalloc, only: mma_allocate, mma_deallocate
-      IMPLICIT REAL*8 (A-H,O-Z)
-#include "detdim.fh"
-#include "spinfo_mclr.fh"
+      use MCLR_Data, only: MULTSP,MS2P,NTYP,MINOP,NCPCNT,NDPCNT
+      IMPLICIT None
       DIMENSION IDFTP(*),ICFTP(*),DTOC(*)
+      REAL*8 PSSIGN
+      Integer IPRNT
+
+!     local variables
       Integer, Allocatable:: SCR7(:)
+      Integer MULTS,MS2,IDTBS,ICSBS,ITP,IOPEN,IFLAG,IDFTP,ICFTP,
+     &        ICDCBS,NNDET
+      REAL*8 DTOC
 *./SPINFO/
 *
 
@@ -724,8 +755,7 @@ c Avoid unused argument warnings
    30 CONTINUE
 *
 
-      RETURN
-      END
+      END SUBROUTINE CSDTMT
 *
 *----------------------------------------------------------------------
 *
@@ -757,11 +787,20 @@ c Avoid unused argument warnings
 * If PSSIGN .ne. 0, spin combinations are used !!
       Use Str_Info, only: DFTP, CFTP, DTOC, CNSM
       use stdalloc, only: mma_allocate, mma_deallocate
-      IMPLICIT REAL*8 (A-H,O-Z)
-#include "detdim.fh"
-#include "spinfo_mclr.fh"
-#include "dmrginfo_mclr.fh"
+      use MCLR_Data, only: MULTSP,MS2P,MINOP,MAXOP,NTYP,NCPCNT,NDPCNT,
+     &                       NCNASM,NCNATS,NCSASM,NDTASM
+      use DetDim, only: MXPCTP,MXPCSM,MXCNSM
+      IMPLICIT NONE
+      INTEGER NACTOB,NACTEL,MULTP,MS2,NORB1,NORB2,NORB3,NEL1MN,NEL3MX,
+     &        LLCSF,NCNSM,ICNSTR
+      REAL*8 PSSIGN
+      INTEGER IPRNT,lconf,lldet
+!     local variables
       Integer, Allocatable:: IICL(:), IIOP(:), IIOC(:)
+      Integer NTEST,IMSCMB,MULTS,NEL,IEL1,IEL2,IEL3,IOP1,IOP2,IOP3,IOP,
+     &        ITP,IOPEN,IAEL,IBEL,ITYPE,LIDT,LICS,LDTOC,MXPTBL,MXDT,
+     &        LCSFDT,LCNFOR,LDET,ILCNF,ISYM,ILLCNF,LLCONF,ITYP,ICL,
+     &        ICNSM,IBION,IWEYLF
 *
 * Last modification : Sept 20 : sign and address of dets goes together
 *                      in CNSM(:)%ICTS
@@ -925,11 +964,6 @@ C?      WRITE(6,*) ' MEMORY FOR HOLDING CONFS OF SYM... ',ISYM,LLCONF
        END IF
        call xflush(6) !yma
 
-!       if(doDMRG.and.doMCLR)then  ! yma
-!         ndets_RGLR=LDET
-!         ncsfs_RGLR=ILCNF
-!       end if
-
 *. permanent memory for csf proto type arrays
 
       Call mma_allocate(DFTP,LIDT,Label='DFTP')
@@ -953,10 +987,9 @@ C?      WRITE(6,*) ' MEMORY FOR HOLDING CONFS OF SYM... ',ISYM,LLCONF
 *
       lldet=ldet
 
-      RETURN
 c Avoid unused argument warnings
       IF (.FALSE.) CALL Unused_integer(ICNSTR)
-      END
+      END SUBROUTINE INTCSF
 *
 *----------------------------------------------------------------------
 *
@@ -976,15 +1009,24 @@ c Avoid unused argument warnings
 *  Jeppe Olsen
 *         August 1990 : Improved handling of large RAS 3 space
 *         Winter 1991 : Modified for LUCIA
-      IMPLICIT REAL*8 (A-H,O-Z)
-*.Input
-      DIMENSION NDPCNT(*),NCPCNT(*)
+      IMPLICIT NONE
+      INTEGER NORB1,NORB2,NORB3,NEL1MN,NEL3MX,NACTEL,MINOP,MAXOP,
+     &        MXPCNT,MXPCSM
 *.Output
-      DIMENSION NCNATS(MXPCNT,*),NCNASM(*),NDTASM(*),NCSASM(*)
+      INTEGER NCNATS(MXPCNT,*),NCNASM(*),NDTASM(*),NCSASM(*)
+*.Input
+      INTEGER NDPCNT(*),NCPCNT(*)
 *. Scratch
-      DIMENSION IICL(*),IIOP(*),IIOC(NORB1+NORB2+NORB3)
+      INTEGER IICL(*),IIOP(*),IIOC(NORB1+NORB2+NORB3)
+      INTEGER IPRNT
 *
+!     Local variables
       Logical Test
+      Integer NTEST,ILOOP,ILOOP2,NCNF,NORBT,IORB1F,IORB1L,IORB2F,IORB2L,
+     &        IORB3F,IORB3L,NORB,MINCL1,NOP,ITYPE,NCL,ICL,IFRSTC,IORB,
+     &        IPLACE,IPRORB,NEWORB,IEL1C,IEL3C,ICL1,IIICHK,MXMPTY,IOP,
+     &        IFRSTO,IEL1,IEL3,IR3CHK,IFSTR3,K,KEL,KORB,ISYM,I,NTYP,
+     &        ICSM,ISYMCN_MCLR
 *
       NTEST = 0000
       NTEST = MAX(NTEST,IPRNT)
@@ -1285,11 +1327,8 @@ C
          END IF
   570  CONTINUE
       END IF
-
 *
-*
-      RETURN
-      END
+      END SUBROUTINE CISIZE
 *
 *----------------------------------------------------------------------
 *
@@ -1306,11 +1345,17 @@ C Construct the corresponding determinants in contracted  form .
 C
 C JEPPE OLSEN , NOVEMBER 1988
 C
-      IMPLICIT REAL*8 (A-H,O-Z)
-      DIMENSION ICONF(*   )
-C     DIMENSION IPDET(NOP,NDET)
-      DIMENSION IPDET(*       )
-      DIMENSION IDET(NEL,*   )
+      IMPLICIT NONE
+      Integer NEL
+      Integer ICONF(*   )
+C     Integer IPDET(NOP,NDET)
+      Integer IPDET(*       )
+      Integer NORB,NOP,NCL
+      Integer IDET(NEL,*   )
+      Integer IPRNT
+
+! local variables
+      Integer NTEST,ICL,IBASE,JDET,NDET,IADD,IOP,IADR
 C
 C
 C POSITIVE NUMBER  : ALPHA ORBITAL
@@ -1367,8 +1412,7 @@ C
 C
 C..4  EXIT
 C
-      RETURN
-      END
+      END SUBROUTINE CNDET_MCLR
 *
 *----------------------------------------------------------------------
 *
@@ -1390,13 +1434,16 @@ C BETA STRING
 C
 C JEPPE OLSEN NOVEMBER 1988
 C
-      IMPLICIT REAL*8 (A-H,O-Z)
+      IMPLICIT NONE
 
-#include "dmrginfo_mclr.fh"
-      DIMENSION IDET(NEL)
-      DIMENSION IASTR(NAEL),IBSTR(NBEL)
-      DIMENSION IWORK(*)
+      Integer NEL,NAEL,NBEL
+      Integer IDET(NEL)
+      Integer IASTR(NAEL),IBSTR(NBEL)
+      Integer NORB,ISIGN
+      Integer IWORK(*)
+      Integer IPRNT
 C
+      INTEGER NTEST,IBEL,ITMP
 C
 C
       NTEST = 000
@@ -1437,10 +1484,9 @@ C
 !      end if
 
 C
-      RETURN
 c Avoid unused argument warnings
       IF (.FALSE.) CALL Unused_integer(NORB)
-      END
+      END SUBROUTINE DETSTR_MCLR
 *
 *----------------------------------------------------------------------
 *
@@ -1463,9 +1509,15 @@ C
 C IMPLEMENTED MORE TRANSPARENT BUBBLE SORTING INSTEAD
 C               JR NOV 2006
 C
-      IMPLICIT REAL*8 (A-H,O-Z)
-      DIMENSION IINST(NELMNT),IOUTST(NELMNT)
+      IMPLICIT None
+      Integer NELMNT
+      Integer IINST(NELMNT),IOUTST(NELMNT)
+      Integer ISIGN,IPRNT
+
+      Integer iTemp, iPass, I
+
       IF(NELMNT.EQ.0) RETURN
+
       ISIGN=1
       iTEMP=0
 
@@ -1520,10 +1572,9 @@ c        CALL IWRTMA(IOUTST,1,NELMNT,1,NELMNT)
 c        WRITE(6,*) ' ISIGN : ', ISIGN
 c      END IF
 C
-      RETURN
 c Avoid unused argument warnings
       IF (.FALSE.) CALL Unused_integer(IPRNT)
-      END
+      END SUBROUTINE ORDSTR_MCLR
 *
 *----------------------------------------------------------------------
 *
@@ -1549,16 +1600,20 @@ c Avoid unused argument warnings
 *     REEXPRESS THIS AS S VALUES OF ALL COUPLINGS
 *
 * THE TWO PROCEDURES ARE IDENTICAL .
-      IMPLICIT REAL*8 (A-H,O-Z)
-      DIMENSION INSTRN(NOPEN),UTSTRN(NOPEN)
+      use Constants, only: Half
+      IMPLICIT NONE
+      Integer, Intent(In):: NOPEN
+      Integer, Intent(In):: INSTRN(NOPEN)
+      REAL*8, Intent(Out):: UTSTRN(NOPEN)
+
+      Integer IOPEN
 *
-      UTSTRN(1) = DBLE(INSTRN(1)) - 0.5D0
-      DO 10 IOPEN = 2, NOPEN
-        UTSTRN(IOPEN) = UTSTRN(IOPEN-1) +DBLE(INSTRN(IOPEN))-0.5D0
-10    CONTINUE
+      UTSTRN(1) = DBLE(INSTRN(1)) - Half
+      DO IOPEN = 2, NOPEN
+        UTSTRN(IOPEN) = UTSTRN(IOPEN-1) +DBLE(INSTRN(IOPEN))-Half
+      END DO
 *
-      RETURN
-      END
+      END SUBROUTINE MSSTRN
 *
 *----------------------------------------------------------------------
 *
@@ -1584,15 +1639,23 @@ c Avoid unused argument warnings
 *  ICONF is written so closed orbitals are given first and then single
 *  occupied orbitals
 *
-      IMPLICIT REAL*8 (A-H,O-Z)
-*.Input
-      DIMENSION NCNFTP(*)
+      IMPLICIT None
+      Integer NORB1,NORB2,NORB3,NEL1MN,NEL3MX,MINOP,MAXOP,IREFSM,NEL
 *.Output
-      DIMENSION ICONF(*)
+      Integer, Intent(Out)::ICONF(*)
+*.Input
+      Integer, Intent(In):: NCNFTP(*)
 *.Scratch
-      DIMENSION IIOC(*),IICL(*),IIOP(*)
+      Integer IIOC(*),IICL(*),IIOP(*)
+      Integer IPRNT
 *
+! local variables
       Logical Test
+      Integer NTEST,IORB1F,IORB1L,IORB2F,IORB2L,IORB3F,IORB3L,NORB,
+     &        JCONF,ICFREE,MINCL1,NOP,ITYPE,NCL,ICL,IFRSTC,IORB,
+     &        IPLACE,IPRORB,NEWORB,IEL1C,IEL3C,ICL1,IIICHK,MXMPTY,
+     &        IOP,IFRSTO,IEL1,IEL3,IR3CHK,IFSTR3,K,KEL,KORB,ISYM,I,
+     &        IBAS,IOPEN,IOC,LICONF,ISYMCN_MCLR
 *
       NTEST = 0000
 
@@ -1871,8 +1934,7 @@ C
       END IF
 
 C
-      RETURN
-      END
+      END SUBROUTINE CONFG2
 *
 *----------------------------------------------------------------------
 *
@@ -1880,30 +1942,33 @@ C
 *----------------------------------------------------------------------
 *
       SUBROUTINE ICISPS(IPRNT)
-      Use Str_Info
+      Use Str_Info, only: STR, NOCTYP
       use stdalloc, only: mma_allocate, mma_deallocate
+      use MCLR_Data, only: IDC
+      use MCLR_Data, only: IASTFI,IBSTFI,ISMOST,MNR1IC,MXR3IC,IACTI,
+     &                       MNR3IC,MXR1IC,NAELCI,NBELCI,XISPSM,MXSB,
+     &                       MXSOOB,NICISP
+      use DetDim, only: MXPCSM
+      use Constants, only: Zero
+      use csm_data, only: NSMCI,NSMST
 *
 * Number of dets and combinations
 * per symmetry for each type of internal space
 *
 * Jeppe Olsen , Winter 1991
 * Last revision April 1991
-      IMPLICIT REAL*8(A-H,O-Z)
-*
-* ===================
-*.Input common blocks
-* ===================
-*
-#include "detdim.fh"
-#include "cstate_mclr.fh"
-#include "csm.fh"
+      IMPLICIT None
+      Integer IPRNT
+
+! local variables
+      Integer MXCEXP,ICI,ISYM,IATP,IBTP,IIDC,NTEST,MX,MXS,MXSOO,NCOMB
+      Real*8 XNCOMB
 *
       Integer, Allocatable:: LBLTP(:), LCVST(:)
 * ====================
-*. Output common block : XISPSM is calculated
+*. Output  XISPSM is calculated
 * ====================
 *
-#include "cicisp_mclr.fh"
 *
 *
 *.Local memory
@@ -1924,6 +1989,7 @@ C            SMOST(NSMST,NSMCI,MXPCSM,ISMOST)
       MXSB = 0
       MXSOOB = 0
       MXCEXP = 0
+      XISPSM(:,:) = Zero
       DO 100 ICI = 1, NICISP
       DO  50 ISYM = 1, NSMCI
         IATP = IASTFI(ICI)
@@ -1945,8 +2011,8 @@ CMS        write(6,*) ' NRASDT : ICI IATP IBTP ',ICI,IATP,IBTP
           MXSOOB = MAX(MXSOOB,MXSOO)
           MXSB = MAX(MXSB,MXS)
           MXCEXP = MAX(MXCEXP,NCOMB)
-        ELSE
-          XISPSM(ISYM,ICI) = 0.0D0
+*       ELSE
+*         XISPSM(ISYM,ICI) = Zero
         END IF
    50 CONTINUE
   100 CONTINUE
@@ -1977,8 +2043,7 @@ CMS        write(6,*) ' NRASDT : ICI IATP IBTP ',ICI,IATP,IBTP
       WRITE(6,*) ' Largest Symmetry-type-type block ',MXSOOB
       End If
 *
-      RETURN
-      END
+      END SUBROUTINE ICISPS
 *
 *----------------------------------------------------------------------
 *
@@ -2003,11 +2068,20 @@ CMS        write(6,*) ' NRASDT : ICI IATP IBTP ',ICI,IATP,IBTP
 *
 * Updated with IBLTP, Summer of 93
 *
-      IMPLICIT REAL*8(A-H,O-Z)
-      DIMENSION IEL1A(*),IEL3A(*)
-      DIMENSION IEL1B(*),IEL3B(*)
-      DIMENSION NSSOA(NOCTPA,*),NSSOB(NOCTPB,*)
-      DIMENSION IBLTP(*)
+      IMPLICIT None
+      Integer MNRS1,MXRS1,MNRS3,MXRS3,ITOTSM,
+     &                  NSMST,NOCTPA,NOCTPB
+      Integer IEL1A(*),IEL1B(*)
+      Integer NSSOA(NOCTPA,*),NSSOB(NOCTPB,*)
+      Integer IEL3A(*),IEL3B(*)
+      Integer NCOMB
+      Real*8 XNCOMB
+      Integer MXSB,MXSOOB
+      Integer IBLTP(*)
+
+! local variables
+      Integer IASM,LSB,IBSM,ISYM,IATP,MXBTP,IBTP,IEL1,IEL3,LTTSBL,
+     &        LTTSUP,NTEST
 *
       MXSB = 0
       MXSOOB = 0
@@ -2065,5 +2139,4 @@ CMS        write(6,*) ' NRASDT : ICI IATP IBTP ',ICI,IATP,IBTP
         WRITE(6,*) ' NCOMB and XNCOMB ', NCOMB,XNCOMB
       END IF
 *
-      RETURN
-      END
+      END SUBROUTINE NRASDT
