@@ -10,6 +10,7 @@
 *                                                                      *
 * Copyright (C) 1996, Anders Bernhardsson                              *
 ************************************************************************
+*define _DEBUGPRINT_
        SubRoutine OutPut_MCLR(iKapDisp,isigdisp,iCiDisp,
      &                        iCiSigDisp,iRHSDisp,iRHSCIDisp,
      &                        converged)
@@ -36,23 +37,26 @@
       Use Arrays, only: Hss
       use ipPage, only: W
       use stdalloc, only: mma_allocate, mma_deallocate
-      Implicit Real*8 (a-h,o-z)
-#include "detdim.fh"
-#include "Input.fh"
-#include "Pointers.fh"
-#include "Files_mclr.fh"
-#include "disp_mclr.fh"
-#include "cicisp_mclr.fh"
+      use MCLR_Data, only: nConf1, nDensC
+      use MCLR_Data, only: nHess,lDisp
+      use MCLR_Data, only: LuTEMP
+      use MCLR_Data, only: XISPSM
+      use input_mclr, only: nDisp,Debug,nSym,State_Sym,iMethod,
+     &                      McKinley,Coor,lCalc,nCSF,nTPert
+      Implicit None
+      Integer iKapDisp(nDisp),isigdisp(nDisp),
+     &        iCiDisp(nDisp),iCiSigDisp(nDisp),
+     &        iRHSDisp(nDisp),iRHSCiDisp(nDisp)
+      Logical converged(8)
+
       Character(LEN=8) Label
 #ifdef _DEBUGPRINT_
       Character(LEN=20) Label2
       Logical elec_On
+      Integer ip
 #endif
       Integer Pstate_sym,ldisp2(8),ielec(3)
-      Integer iKapDisp(nDisp),isigdisp(nDisp),
-     &        iCiDisp(nDisp),iCiSigDisp(nDisp),
-     &        iRHSDisp(nDisp),iRHSCiDisp(nDisp)
-      Logical converged(8),CI
+      Logical CI
       Real*8 Pola(6)
       Real*8, Allocatable:: RHss(:)
       Real*8, Allocatable:: Kap1(:), Kap2(:), sKap(:),
@@ -60,10 +64,14 @@
       Real*8, Allocatable:: Hess(:), Hess2(:), Temp(:), ELEC(:),
      &                      EG(:), ELOUT(:)
       Integer, Allocatable:: NrDisp(:), DegDisp(:)
-*                                                                      *
-************************************************************************
-*                                                                      *
-*define _DEBUGPRINT_
+      Integer nHss, mSym, kSym, iDum, iDisp, iSym, nConfm, ipCIP1,
+     &        ipCIP2, ipSP, ipRP1, ipRP2, jDisp, jSpin, iDisk, Len, i,
+     &        iLen, iDis, iRC, kDisp, kSpin, MaxI, MinI, Index, iOpt,
+     &        Lu_10
+      Real*8 rTempC1, rTempK1, Fact, rTempK2, rTempK3, rTempC2, rTempC3
+      Real*8, External:: DDot_
+      Integer, External:: ipGet, ipIn, ipClose
+      Integer, External:: IsFreeUnit
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -570,5 +578,4 @@ c       Open(unit=Lu_10, file='UNSYM')
       Call mma_deallocate(Hess)
       Call mma_deallocate(RHss)
 *
-      Return
-      End
+      End SubRoutine OutPut_MCLR
