@@ -24,41 +24,53 @@
       use cmslag, only: ResQaaLag2
       use stdalloc, only: mma_allocate, mma_deallocate
       use Constants, only: Zero, One
-      Implicit Real*8 (a-h,o-z)
+      use MCLR_Data, only:nConf1,nDens2,nDensC,nDens,ipCI
+      use MCLR_Data, only: ipDia
+      use MCLR_Data, only: ISNAC,OVERRIDE,IRLXROOT,ISMECIMSPD,
+     &                     NACSTATES
+      use MCLR_Data, only: LuTemp, LuQDat
+      use MCLR_Data, only: XISPSM
+      use input_mclr, only: nDisp,Fail,lSave,State_Sym,iMethod,
+     &                      iBreak,Eps,nIter,
+     &                      Debug,kPrint,nCSF,
+     &                      nRoots,TwoStep,StepType,iAddressQDat,nAsh,
+     &                      nRS2
+      use dmrginfo, only: DoDMRG,RGRAS2
+      Implicit None
+      Integer iKapDisp(nDisp),isigDisp(nDisp)
+      Integer iCIDisp(nDisp),iCIsigDisp(nDisp)
+      Integer iRHSDisp(nDisp)
+      Logical converged(8)
+      Integer iPL
 *
-#include "Input.fh"
-#include "disp_mclr.fh"
-#include "Pointers.fh"
-#include "Files_mclr.fh"
-#include "detdim.fh"
-#include "cicisp_mclr.fh"
-#include "incdia.fh"
-#include "spinfo_mclr.fh"
-#include "sa.fh"
-#include "dmrginfo_mclr.fh"
+#include "rasdim.fh"
 
       Logical CI
-#include "crun_mclr.fh"
-      Character*8   Fmt2
-      Integer iKapDisp(nDisp),isigDisp(nDisp)
-      Integer iRHSDisp(nDisp)
-      Integer iCIDisp(nDisp),iCIsigDisp(nDisp)
+      Character(LEN=8) Fmt2
       Integer opOut
-      Logical lPrint,converged(8)
+      Logical lPrint
       Real*8 rchc(mxroot)
-      Real*8 rdum(1)
       Real*8, Allocatable:: Kappa(:), dKappa(:), Sigma(:),
      &                      Temp3(:), Temp4(:),
      &                      Sc1(:), Sc2(:), Fancy(:)
       Integer LURot,IsFreeUnit,JRoot
       External IsFreeUnit
       CHARACTER(len=16)::VecName
+      Real*8 R1,R2,DeltaC,DeltaK,Delta,Delta0,ReCo,
+     &       rAlphaC,rAlphaK,rAlpha,rEsk,rEsci,rBeta,Res
+      Real*8, External:: DDot_
+      Integer lPaper,lLine,Left,iDis,Lu_50,iDisp,iSym,
+     &        nConf3,iRC,ipS1,ipS2,ipST,ipCIT,ipCID,nPre2,
+     &        iLen,Iter,ipPre2,jSpin,i
+      Integer, External:: ipClose,ipGet,ipIn,ipOut,ipNOut
+      Integer, External:: nPre
+
 *
 *----------------------------------------------------------------------*
 *     Start                                                            *
 *----------------------------------------------------------------------*
-      Call StatusLine(' MCLR:',
-     &                ' Computing Lagrangian multipliers for MS-PDFT')
+      Call StatusLine('MCLR: ',
+     &                'Computing Lagrangian multipliers for MS-PDFT')
 *
 
       lPaper=132
@@ -77,8 +89,8 @@
       lprint=.true.
       reco=-One
       Lu_50=50
-      If (SAVE) CALL DANAME(Lu_50,'RESIDUALS')
-      If (SAVE) Then
+      If (lSAVE) CALL DANAME(Lu_50,'RESIDUALS')
+      If (lSAVE) Then
          Write (6,*) 'WfCtl_MSPD: SAVE option not implemented'
          Call Abend()
       End If
@@ -206,7 +218,7 @@
        CLOSE(LURot)
        if(VecName.eq.'CMS-PDFT') THEN
          Call RHS_CMS_NAC(Temp4,W(ipST)%Vec)
-         CALL DMinvCI_SA(ipST,W(ipS2)%Vec,rdum(1),isym,Fancy)
+         CALL DMinvCI_SA(ipST,W(ipS2)%Vec,Fancy)
        else
         write(6,'(6X,A)')'Error: Lagrangian Not Implemented for MS-PDFT'
         write(6,'(6X,A)')'       Other Than CMS-PDFT'
@@ -223,7 +235,7 @@
        CLOSE(LURot)
        if(VecName.eq.'CMS-PDFT') THEN
         Call RHS_CMS(Temp4,W(ipST)%Vec)
-        CALL DMinvCI_SA(ipST,W(ipS2)%Vec,rdum(1),isym,Fancy)
+        CALL DMinvCI_SA(ipST,W(ipS2)%Vec,Fancy)
        else
         write(6,'(6X,A)')'Error: Lagrangian Not Implemented for MS-PDFT'
         write(6,'(6X,A)')'       Other Than CMS-PDFT'
@@ -272,7 +284,7 @@
 *      In MS-PDFT deltaC is no longer zero initially
 *      deltaC=Zero
 *      Use following two lines instead
-      CALL DMinvCI_SA(ipST,W(ipS2)%Vec,rdum(1),isym,Fancy)
+      CALL DMinvCI_SA(ipST,W(ipS2)%Vec,Fancy)
       call dcopy_(nConf1*nroots,W(ipS2)%Vec,1,W(ipCID)%Vec,1)
       deltaC=ddot_(nConf1*nroots,W(ipST)%Vec,1,W(ipS2)%Vec,1)
       irc=ipOut(ipcid)
@@ -332,7 +344,7 @@
          irc=opOut(ipcid)
 
          irc=ipIn(ipS2)
-         Call DMinvCI_SA(ipST,W(ipS2)%Vec,rdum(1),isym,Fancy)
+         Call DMinvCI_SA(ipST,W(ipS2)%Vec,Fancy)
          irc=opOut(ipci)
          irc=opOut(ipdia)
 
@@ -384,14 +396,14 @@
 *
          res=Zero ! dummy initialize
          If (iBreak.eq.1) Then
-            If (abs(delta).lt.abs(Epsilon**2*delta0)) Goto 300
+            If (abs(delta).lt.abs(Eps**2*delta0)) Goto 300
          Else If (iBreak.eq.2) Then
             res=sqrt(resk**2+resci**2+ResQaaLag2)
             if (doDMRG) res=sqrt(resk**2)
-            If (res.lt.abs(epsilon)) Goto 300
+            If (res.lt.abs(Eps)) Goto 300
          Else
-            If (abs(delta).lt.abs(Epsilon**2*delta0).and.
-     &          res.lt.abs(epsilon))  Goto 300
+            If (abs(delta).lt.abs(Eps**2*delta0).and.
+     &          res.lt.abs(Eps))  Goto 300
          End If
          If (iter.ge.niter) goto 210
          If (lprint)
@@ -473,28 +485,33 @@
 *     Exit                                                             *
 *----------------------------------------------------------------------*
 *
-      Return
 #ifdef _WARNING_WORKAROUND_
       If (.False.) Call Unused_integer(irc)
 #endif
-      End
+      End SubRoutine WfCtl_MSPD
 
       Subroutine TimesE2MSPDFT(Kap,ipCId,isym,reco,jspin,ipS2,KapOut,
      & ipCiOut)
       use ipPage, only: w
       use stdalloc, only: mma_allocate, mma_deallocate
       use Constants, only: One
-      Implicit Real*8(a-h,o-z)
-#include "Pointers.fh"
-#include "dmrginfo_mclr.fh"
-#include "Input.fh"
+      use MCLR_Data, only: nConf1,n2Dens,nDens,nDens2
+      use input_mclr, only: nRoots,nAsh,nRS2,Weight
+      use dmrginfo, only: DoDMRG,LRRAS2,RGRAS2
+      Implicit None
+      Real*8 Kap(*)
+      Integer ipCId,isym,jspin,ipS2,ipCiOut
+      Real*8 ReCo
+      Real*8 KapOut(*)
+
       Integer opOut
-      Real*8 Kap(*),KapOut(*)
       Real*8 rdum(1)
       Real*8, Allocatable:: Temp3(:), Temp4(:),
      &                      Sc1(:), Sc2(:), Sc3(:), RMOAA(:),MSHam(:)
       INTEGER kRoot,lRoot
       Real*8 ECOff
+      Integer iRC
+      Integer, External:: ipIN
 *
       Call mma_allocate(RMOAA,n2Dens,Label='RMOAA')
       Call mma_allocate(Sc1,nDens2,Label='Sc1')
@@ -560,8 +577,7 @@
         call dmrg_spc_change_mclr(LRras2(1:8),nash)
       end if
 *
-      Return
 #ifdef _WARNING_WORKAROUND_
       If (.False.) Call Unused_integer(irc)
 #endif
-      End
+      End Subroutine TimesE2MSPDFT
