@@ -28,28 +28,30 @@
       use PDFT_Util, only: Do_Hybrid, WF_Ratio,PDFT_Ratio
       use stdalloc, only: mma_allocate, mma_deallocate
       use Constants, only: Zero, One, Two
-      Implicit Real*8 (a-h,o-z)
+      use MCLR_Data, only:nConf1,nDens2,nDensC,nDens,ipCI,nAcPar,nNA,
+     &                    nAcPr2,ipMat
+      use MCLR_Data, only: ipDia
+      use MCLR_Data, only: ISNAC,IRLXROOT,NACSTATES
+      use MCLR_Data, only: LuTemp
+      use MCLR_Data, only: XISPSM
+      use input_mclr, only: nDisp,Fail,lSave,nSym,State_Sym,iMethod,
+     &                      iBreak,Eps,nIter,Weight,
+     &                      Debug,ERASSCF,kPrint,nCSF,nRoots,
+     &                      ntAsh,nAsh,nBas,nRs2
+      use dmrginfo, only: DoDMRG,RGRAS2
+      Implicit None
+      Integer iKapDisp(nDisp),isigDisp(nDisp)
+      Integer iCIDisp(nDisp),iCIsigDisp(nDisp)
+      Integer iRHSDisp(nDisp)
+      Logical converged(8)
+      Integer iPL
 *
-#include "Input.fh"
-#include "disp_mclr.fh"
-#include "Pointers.fh"
-#include "Files_mclr.fh"
-#include "detdim.fh"
-#include "cicisp_mclr.fh"
-#include "incdia.fh"
-#include "spinfo_mclr.fh"
-#include "sa.fh"
-#include "dmrginfo_mclr.fh"
+#include "rasdim.fh"
 
       Logical CI
-#include "crun_mclr.fh"
-      Character*8   Fmt2
-      Integer iKapDisp(nDisp),isigDisp(nDisp)
-      Integer iRHSDisp(nDisp)
-      Integer iCIDisp(nDisp),iCIsigDisp(nDisp)
+      Character(LEN=8) Fmt2
       Integer opOut
-*      Integer nacpar,nacpr2
-      Logical lPrint,converged(8)
+      Logical lPrint
       Real*8 rchc(mxroot)
       Real*8 rDum(1)
 
@@ -62,6 +64,16 @@
       Real*8, Allocatable:: lmroots(:), lmroots_new(:), Kap_New(:),
      &                      Kap_New_Temp(:)
       Real*8, Allocatable:: WFOrb(:),P2WF(:),P2PDFT(:)
+      Real*8 R1,R2,DeltaC,DeltaK,Delta,Delta0,ReCo,
+     &       rAlphaC,rAlphaK,rAlpha,rEsk,rEsci,rBeta,Res,
+     &       TRoot,rE,Diff,WScale
+      Real*8, External:: DDot_
+      Integer lPaper,lLine,Left,iDis,Lu_50,iDisp,iSym,
+     &        nConf3,iRC,ipS1,ipS2,ipST,ipCIT,ipCID,nPre2,
+     &        iLen,Iter,ipPre2,jSpin,i,nTri,nOrbAct,kSym,iOff,iS,jS,
+     &        j,ji,ij,nG1,nG2
+      Integer, External:: ipClose,ipGet,ipIn,ipOut,ipNOut
+      Integer, External:: nPre
 *                                                                      *
 ************************************************************************
 *                                                                      *
@@ -86,8 +98,8 @@
 *----------------------------------------------------------------------*
 *     Start                                                            *
 *----------------------------------------------------------------------*
-      Call StatusLine(' MCLR:',
-     &                ' Computing Lagrangian multipliers for MC-PDFT')
+      Call StatusLine('MCLR: ',
+     &                'Computing Lagrangian multipliers for MC-PDFT')
 *
 
       lPaper=132
@@ -105,8 +117,8 @@
       debug=.false.
       reco=-One
       Lu_50=50
-      If (SAVE) CALL DANAME(Lu_50,'RESIDUALS')
-      If (SAVE) Then
+      If (lSAVE) CALL DANAME(Lu_50,'RESIDUALS')
+      If (lSAVE) Then
          Write (6,*) 'WfCtl_SA: SAVE option not implemented'
          Call Abend()
       End If
@@ -228,8 +240,6 @@
 !AMS _____________________________________________________
 !Read in the Fock operator for the calculation of the CI part of the RHS
 !ipF1 and ipF2.
-      LUTMP=87
-      Call Molcas_Open(LUTMP,'TmpFock')
       nTri = 0
       nOrbAct = 0
       do ksym=1,nsym
@@ -242,9 +252,8 @@
       nacpar=(nnA+1)*nnA/2
       nacpr2=(nacpar+1)*nacpar/2
       Call mma_allocate(FMO2t,nacpr2,Label='FMO2t')
-      do i=1,nTri
-        read(LUTMP,*) FMO1t(i)
-      end do
+
+      call get_darray('F1_PDFT         ',FMO1t,nTri)
 
       ioff = 0
       do iS=1,nSym
@@ -275,11 +284,8 @@
       end do
 
 
+      call get_darray('F2_PDFT         ',FMO2t,nacpr2)
 
-      do i=1,nacpr2
-        read(LUTMP,*) FMO2t(i)
-      end do
-      Close(LUTMP)
 
       Call CISigma_sa(0,State_sym,State_sym,FMO1,nDens2,FMO2t,
      &                SIZE(FMO2t),rdum,1,ipci,ipST,.True.)
@@ -449,7 +455,7 @@
 !I need to read in the CI portion of the RHS here.
       If (CI) Then
          irc=ipIn(ipS2)
-         Call DMinvCI_sa(ipST,W(ipS2)%Vec,rdum(1),isym,Fancy)
+         Call DMinvCI_sa(ipST,W(ipS2)%Vec,Fancy)
       End If
       irc=ipin(ipST)
       irc=ipin(ipCId)
@@ -638,7 +644,7 @@
          irc=opOut(ipcid)
 
          irc=ipIn(ipS2)
-         Call DMinvCI_SA(ipST,W(ipS2)%Vec,rdum(1),isym,Fancy)
+         Call DMinvCI_SA(ipST,W(ipS2)%Vec,Fancy)
 
          irc=opOut(ipci)
          irc=opOut(ipdia)
@@ -698,14 +704,14 @@
 *
          res=Zero ! dummy initialize
          If (iBreak.eq.1) Then
-            If (abs(delta).lt.abs(Epsilon**2*delta0)) Goto 300
+            If (abs(delta).lt.abs(Eps**2*delta0)) Goto 300
          Else If (iBreak.eq.2) Then
             res=sqrt(resk**2+resci**2)
             if (doDMRG) res=sqrt(resk**2)
-            If (res.lt.abs(epsilon)) Goto 300
+            If (res.lt.abs(Eps)) Goto 300
          Else
-            If (abs(delta).lt.abs(Epsilon**2*delta0).and.
-     &          res.lt.abs(epsilon))  Goto 300
+            If (abs(delta).lt.abs(Eps**2*delta0).and.
+     &          res.lt.abs(Eps))  Goto 300
          End If
          If (iter.ge.niter) goto 210
          If (lprint)
@@ -800,26 +806,31 @@
 *     Exit                                                             *
 *----------------------------------------------------------------------*
 *
-      Return
 #ifdef _WARNING_WORKAROUND_
       If (.False.) Call Unused_integer(irc)
 #endif
-      End
+      End SubRoutine WfCtl_pdft
 
       Subroutine TimesE2_(Kap,ipCId,isym,reco,jspin,ipS2,KapOut,ipCiOut)
 *
       use ipPage, only: W
       use stdalloc, only: mma_allocate, mma_deallocate
       use Constants, only: One
-      Implicit Real*8(a-h,o-z)
-#include "Pointers.fh"
-#include "dmrginfo_mclr.fh"
-#include "Input.fh"
+      use MCLR_Data
+      use input_mclr, only: nRoots,nAsh,nRs2
+      use dmrginfo, only: DoDMRG,LRRAS2,RGRAS2
+      Implicit None
+      Real*8 Kap(*)
+      Integer ipCId,isym,jspin,ipS2,ipCiOut
+      Real*8 ReCo
+      Real*8 KapOut(*)
+
       Integer opOut
-      Real*8 Kap(*),KapOut(*)
       Real*8 rdum(1)
       Real*8, Allocatable:: RMOAA(:), Sc1(:), Sc2(:), Sc3(:),
      &                      Temp4(:), Temp3(:)
+      Integer iRC
+      Integer, External:: ipIN
 *
       Call mma_allocate(RMOAA,n2dens,Label='RMOAA')
       Call mma_allocate(Sc1,ndens2,Label='Sc1')
@@ -863,9 +874,8 @@
         call dmrg_spc_change_mclr(LRras2(1:8),nash)
       end if
 *
-      Return
 #ifdef _WARNING_WORKAROUND_
       If (.False.) Call Unused_integer(irc)
 #endif
-      End
+      End Subroutine TimesE2_
 
