@@ -17,12 +17,12 @@
 * ****************************************************************
       use stdalloc, only : mma_allocate, mma_deallocate
       use CMS, only: CMSNotConverged
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: NACPR2, CMSStartMat, lRoots, NAC
+      use printlevel, only: USUAL
+      use output_ras, only: LF,IPRLOC
+      Implicit None
+
 #include "SysDef.fh"
-#include "input_ras.fh"
-#include "output_ras.fh"
 #include "warnings.h"
 
       Real*8,DIMENSION(NACPR2)::TUVX
@@ -31,6 +31,8 @@
       Real*8,DIMENSION(:,:,:,:),Allocatable::DDG
       Real*8,DIMENSION(:,:,:),Allocatable::GDMat
       Real*8,DIMENSION(:,:),Allocatable::RotMat
+      Integer iPrLev
+
 C     Allocating Memory
       CALL mma_allocate(GDMat,LRoots*(LRoots+1)/2,NAC,NAC)
       CALL mma_allocate(RotMat,lRoots,lRoots)
@@ -41,9 +43,9 @@ C     Allocating Memory
 
 *     printing header
       IF(IPRLEV.ge.USUAL) THEN
-      write(6,*)
-      write(6,*)
-      write(6,*) '    CMS INTERMEDIATE-STATE OPTIMIZATION'
+      write(LF,*)
+      write(LF,*)
+      write(LF,*) '    CMS INTERMEDIATE-STATE OPTIMIZATION'
       END IF
       IF(trim(CMSStartMat).eq.'XMS') THEN
        CALL ReadMat('ROT_VEC',VecName,RotMat,lroots,lroots,7,16,'N')
@@ -79,8 +81,7 @@ C     Deallocating Memory
        Call WarningMessage(2,'CMS Intermediate States Not Converged')
        Call Quit(_RC_NOT_CONVERGED_)
       END IF
-      RETURN
-      End Subroutine
+      End Subroutine CMSRot
 
 ************************************************************************
 
@@ -88,12 +89,14 @@ C     Deallocating Memory
       Subroutine NStateOpt(RotMat,DDg)
       use stdalloc, only : mma_allocate, mma_deallocate
       use CMS, only: CMSNotConverged
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots, CMSThreshold, iCMSIterMax,
+     &                         iCMSIterMin
+      use printlevel, only: USUAL
+      use output_ras, only: LF,IPRLOC
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
-#include "output_ras.fh"
 #include "warnings.h"
       Real*8,DIMENSION(lRoots,lRoots,lRoots,lRoots)::DDG
       Real*8,DIMENSION(lroots,lroots)::RotMat
@@ -106,6 +109,7 @@ C     Deallocating Memory
       Logical Converged
       Real*8 CalcNSumVee
       External CalcNSumVee
+      Integer iPrLev
 
       IPRLEV=IPRLOC(6)
 
@@ -134,10 +138,10 @@ C     Deallocating Memory
        CALL ThetaOpt(FRot,theta,VeeSumNew,StatePair,NPairs,DDg)
        IF(IPRLEV.ge.USUAL) THEN
        IF(lRoots.gt.2) THEN
-       write(6,'(6X,I4,8X,F16.8,8X,ES16.4E3)')
+       write(LF,'(6X,I4,8X,F16.8,8X,ES16.4E3)')
      & ICMSIter,VeeSumNew,VeeSumNew-VeeSumOld
        ELSE
-       write(6,'(6X,I4,8X,F6.1,9X,F16.8,5X,ES16.4E3)')
+       write(LF,'(6X,I4,8X,F6.1,9X,F16.8,5X,ES16.4E3)')
      & ICMSIter,asin(FRot(2,1))/atan(1.0d0)*45.0d0,VeeSumNew
      & ,VeeSumNew-VeeSumOld
        END IF
@@ -151,8 +155,8 @@ C     Deallocating Memory
         if(ICMSIter.ge.ICMSIterMax) then
          Converged=.true.
          CMSNotConverged=.true.
-         write(6,'(4X,A)')'NOT CONVERGED AFTER MAX NUMBER OF CYCLES'
-         write(6,'(4X,A)')'TEMPORARY ROTATION MATRIX SAVED'
+         write(LF,'(4X,A)')'NOT CONVERGED AFTER MAX NUMBER OF CYCLES'
+         write(LF,'(4X,A)')'TEMPORARY ROTATION MATRIX SAVED'
         end if
        END IF
        VeeSumOld=VeeSumNew
@@ -162,17 +166,15 @@ C     Deallocating Memory
       CALL mma_deallocate(StatePair)
       CALL mma_deallocate(theta)
       CALL mma_deallocate(FRot)
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE NStateOpt
 ************************************************************************
 
 ************************************************************************
       Subroutine ThetaOpt(FRot,theta,SumVee,StatePair,NPairs,DDg)
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots
+      Implicit None
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
       INTEGER NPairs
       Real*8 SumVee
@@ -196,12 +198,12 @@ C      Real*8,DIMENSION(NPairs)::thetanew
        CALL
      & OptOneAngle(theta(iPair),SumVee,FRot,DDg,IState,JState,lRoots)
       END DO
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE ThetaOpt
 ************************************************************************
 ************************************************************************
       SUBROUTINE OptOneAngle(Angle,SumVee,RotMat,DDg,I1,I2,lRoots)
       use stdalloc, only : mma_allocate, mma_deallocate
+      Implicit None
       real*8 Angle,SumVee
       INTEGER I1,I2,lRoots
       Real*8,DIMENSION(lRoots,lRoots)::RotMat
@@ -214,10 +216,8 @@ C      Real*8,DIMENSION(NPairs)::thetanew
       Real*8,DIMENSION(:),Allocatable::ScanA,ScanS
       Real*8,DIMENSION(:,:),Allocatable::RTmp
 
-      Real*8 CalcNSumVee
-      External CalcNSumVee
-      INTEGER RMax
-      External RMax
+      Real*8, External ::CalcNSumVee
+      INTEGER, External ::RMax
 
       CALL mma_allocate(Angles,4)
       CALL mma_allocate(Sums,4)
@@ -283,11 +283,11 @@ C     &'Convergence reached after ',Iter,' micro cycles'
       CALL mma_deallocate(ScanS)
       CALL mma_deallocate(RTmp)
 
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE OptOneAngle
 ************************************************************************
 ************************************************************************
       Function RMax(A,N)
+      Implicit None
        INTEGER N,RMax
        Real*8,DIMENSION(N)::A
        INTEGER I
@@ -295,17 +295,15 @@ C     &'Convergence reached after ',Iter,' micro cycles'
        DO I=2,N
         IF (A(I).gt.A(RMax)) RMax=I
        END DO
-       RETURN
-      End Function
+      End Function RMax
 
 ************************************************************************
       Function CalcNSumVee(RotMat,DDg)
       use stdalloc, only : mma_allocate, mma_deallocate
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots
+      Implicit None
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
       Real*8,DIMENSION(lRoots,lRoots,lRoots,lRoots)::DDG
       Real*8,DIMENSION(lroots,lroots)::RotMat
@@ -320,11 +318,11 @@ C     &'Convergence reached after ',Iter,' micro cycles'
        CalcNSumVee=CalcNSumVee+Vee(IState)
       END DO
       CALL mma_deallocate(Vee)
-      RETURN
-      END Function
+      END Function CalcNSumVee
 ************************************************************************
 ************************************************************************
       Subroutine Copy2DMat(A,B,NRow,NCol)
+      Implicit None
       INTEGER NRow,NCol,IRow,ICol
       Real*8,DIMENSION(NRow,NCol)::A,B
       DO ICol=1,NCol
@@ -332,14 +330,15 @@ C     &'Convergence reached after ',Iter,' micro cycles'
         A(IRow,ICol)=B(IRow,ICol)
        End Do
       END DO
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE Copy2DMat
 ************************************************************************
 ************************************************************************
       Subroutine CMSMatRot(Mat,A,I,J,N)
+      Implicit None
       INTEGER I,J,N
       Real*8 A
       Real*8,DIMENSION(N,N)::Mat,TM
+      INTEGER K
       DO K=1,N
        TM(I,K)=Mat(I,K)
        TM(J,K)=Mat(J,K)
@@ -348,11 +347,11 @@ C     &'Convergence reached after ',Iter,' micro cycles'
        Mat(J,K)= cos(A)*TM(J,K)+sin(A)*TM(I,K)
        Mat(I,K)=-sin(A)*TM(J,K)+cos(A)*TM(I,K)
       END DO
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE CMSMatRot
 ************************************************************************
 ************************************************************************
       Subroutine CMSFitTrigonometric(x,y)
+      Implicit None
       real*8,DIMENSION(4)::x,y
       real*8 s12,s23,c12,c23,d12,d23,k,a,b,c,phi,psi1,psi2,val1,val2
       real*8 atan1
@@ -385,17 +384,16 @@ C       y(4)=val2
       end if
       y(4)=a+sqrt(b**2+c**2)
 C      write(6,*)a,b,c,x(4),y(4)
-      return
-      END Subroutine
+      END Subroutine CMSFitTrigonometric
 ************************************************************************
 
 ************************************************************************
       Subroutine CalcVee(Vee,RMat,DDg)
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
       Real*8,DIMENSION(lRoots,lRoots,lRoots,lRoots)::DDG
       Real*8,DIMENSION(lroots,lroots)::RMat
@@ -417,16 +415,15 @@ C      write(6,*)a,b,c,x(4),y(4)
 C       write(6,'(A,I2,A,F10.6)')'The classic coulomb energy for state ',
 C     & IState,' is ',Vee(IState)
       END DO
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE CalcVee
 ************************************************************************
 ************************************************************************
       Subroutine GetDDgMat(DDg,GDMat,Gtuvx)
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots, NAC
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
       Real*8,DIMENSION(lRoots,lRoots,lRoots,lRoots)::DDG
       Real*8,DIMENSION(NAC,NAC,NAC,NAC)::Gtuvx
@@ -468,7 +465,7 @@ C     & IState,' is ',Vee(IState)
        END DO
       END DO
       RETURN
-      End Subroutine
+      End Subroutine GetDDgMat
 ************************************************************************
 
       Subroutine LoadGtuvx(TUVX,Gtuvx)
@@ -477,11 +474,11 @@ C     & IState,' is ',Vee(IState)
 * Loading TUVX array to a 4-D tensor.                            *
 * Copyied from src/molcas_ci_util/david5.f                       *
 * ****************************************************************
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: NACPR2, NAC
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
 
       Real*8,DIMENSION(NACPR2)::TUVX
@@ -508,17 +505,19 @@ C     & IState,' is ',Vee(IState)
        End Do
       END DO
       RETURN
-      End Subroutine
+      End Subroutine LoadGtuvx
 ************************************************************************
       Subroutine NStateOpt2(RotMat,GDMat,Gtuvx)
       use stdalloc, only : mma_allocate, mma_deallocate
       use CMS, only: CMSNotConverged
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots, NAC, CMSThreshold, iCMSIterMax,
+     &                         iCMSIterMin
+      use printlevel, only: USUAL
+      use output_ras, only: IPRLOC
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
-#include "output_ras.fh"
 #include "warnings.h"
 
       Real*8,DIMENSION(LRoots*(LRoots+1)/2,NAC,NAC)::GDMat
@@ -532,8 +531,8 @@ C     & IState,' is ',Vee(IState)
       Real*8,DIMENSION(:),Allocatable::Vee
       Real*8,DIMENSION(:,:),Allocatable::FRot
       Logical Converged
-      Real*8 SumArray
-      External SumArray
+      Real*8, External :: SumArray
+      Integer iPrLev
 
       IPRLEV=IPRLOC(6)
 
@@ -604,18 +603,17 @@ C     & IState,' is ',Vee(IState)
       CALL mma_deallocate(theta)
       CALL mma_deallocate(Vee)
       CALL mma_deallocate(FRot)
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE NStateOpt2
 
 ************************************************************************
 
       SubRoutine OptOneAngle2(ang,change,R,GD,I1,I2,Vee,G)
       use stdalloc, only : mma_allocate, mma_deallocate
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots, NAC
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
       Real*8 ang,change
       Integer I1,I2
@@ -630,8 +628,7 @@ C     & IState,' is ',Vee(IState)
       Real*8,DIMENSION(:),Allocatable::Angles,Sums
       Real*8,DIMENSION(:),Allocatable::ScanA,ScanS
 
-      INTEGER RMax
-      External RMax
+      INTEGER, External :: RMax
 
       CALL mma_allocate(Angles,4)
       CALL mma_allocate(Sums,4)
@@ -690,17 +687,15 @@ C       IF(I2.eq.1) write(6,*) Iter,ScanA(Iter),ScanS(Iter)
       CALL mma_deallocate(Sums)
       CALL mma_deallocate(ScanA)
       CALL mma_deallocate(ScanS)
-      RETURN
-      End Subroutine
+      End Subroutine OptOneAngle2
 
 ************************************************************************
       Subroutine SumVeeNew(SV,A,GD,I1,I2,G,V1,V2,Update)
       use stdalloc, only : mma_allocate, mma_deallocate
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots, NAC
+      Implicit None
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
 
       Real*8 SV,A,V1,V2
@@ -853,19 +848,18 @@ C       IF(I2.eq.1) write(6,*) Iter,ScanA(Iter),ScanS(Iter)
        Call mma_deallocate(D11)
        Call mma_deallocate(D22)
       END IF
-      RETURN
-      End Subroutine
+      End Subroutine SumVeeNew
 ************************************************************************
 
 ************************************************************************
 
 
       Subroutine ThetaOpt2(R,theta,deltaQ,SPair,NP,GD,Vee,G)
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots, NAC
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
       INTEGER NP
       Real*8,DIMENSION(NP)::theta
@@ -892,11 +886,11 @@ C       IF(I2.eq.1) write(6,*) Iter,ScanA(Iter),ScanS(Iter)
        deltaQ=deltaQ+change
       END DO
 
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE ThetaOpt2
 
 ************************************************************************
       Function SumArray(A,N)
+      Implicit None
       INTEGER N,I
       Real*8,DIMENSION(N)::A
       Real*8 SumArray
@@ -904,17 +898,16 @@ C       IF(I2.eq.1) write(6,*) Iter,ScanA(Iter),ScanS(Iter)
       DO I=1, N
        SumArray=SumArray+A(I)
       END DO
-      RETURN
-      End Function
+      End Function SumArray
 
 
 ************************************************************************
       Subroutine CalcVee2(Vee,GD,Gtuvx)
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots, NAC
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
       Real*8,DIMENSION(LRoots*(LRoots+1)/2,NAC,NAC)::GD
       Real*8,DIMENSION(lRoots)::Vee
@@ -935,16 +928,15 @@ C       IF(I2.eq.1) write(6,*) Iter,ScanA(Iter),ScanS(Iter)
        End Do
        Vee(I)=Vee(I)/2.0d0
       END DO
-      RETURN
-      END SUBROUTINE
+      END SUBROUTINE CalcVee2
 
 ************************************************************************
       Subroutine RotGDMat(R,GD)
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
+      use rasscf_global, only: lRoots, NAC
+      Implicit None
+
+
 #include "SysDef.fh"
-#include "input_ras.fh"
 #include "warnings.h"
 
       Real*8,DIMENSION(LRoots*(LRoots+1)/2,NAC,NAC)::GD,GD2
@@ -987,6 +979,4 @@ C       IF(I2.eq.1) write(6,*) Iter,ScanA(Iter),ScanS(Iter)
        End Do
       END DO
       END DO
-      RETURN
-      END SUBROUTINE
-
+      END SUBROUTINE RotGDMat
