@@ -55,6 +55,9 @@
      &  qcmaquis_interface_deinit, qcmaquis_param,
      &  TEMPLATE_4RDM, TEMPLATE_TRANSITION_3RDM, dmrg_energy
       use qcmaquis_interface_mpssi, only: qcmaquis_mpssi_transform
+      use rasscf_lucia, only: RF1, RF2
+      use rasscf_global, only: DoNEVPT2Prep, DoDelChk
+      use rasscf_global, only: Twordm_qcm, DoMCPDFTDMRG
 #endif
       use OneDat, only: sNoNuc, sNoOri
       use Fock_util_global, only: ALGO, DoActive, DoCholesky
@@ -80,60 +83,82 @@
       use mh5, only: mh5_put_attr, mh5_put_dset
       use csfbas, only: CONF
       use glbbas, only: CFTP
+      use rasscf_lucia, only: DStmp, Dtmp
+      use raswfn, only: wfn_iter, wfn_energy, wfn_transdens,
+     &                  wfn_transsdens
+      use rasscf_global, only: lRoots
+      use general_data, only: NACTEL,STSYM
 #endif
       use OFembed, only: Do_OFemb, FMaux
       use UnixInfo, only: ProgName
       use stdalloc, only: mma_allocate, mma_deallocate
       use rctfld_module, only: lRF
       use Lucia_Interface, only: Lucia_Util
-#ifdef _HDF5_
-      use rasscf_lucia, only: DStmp, Dtmp
-#endif
-#ifdef _DMRG_
-      use rasscf_lucia, only: RF1, RF2
-#endif
       use wadr, only: DMAT, PMAT, PA, FockOcc, TUVX, FI, FA, DSPN,
      &                D1I, D1A, OccN, CMO, DIAF
       use sxci
       use gugx, only: SGS, CIS, EXS
       use general_data, only: CRVec, CleanMask, CRPROJ
+      use gas_data, only: iDOGAS
+      use input_ras, only: KeyORBO, KeyORTH, KeyCION, KeyWRMA, KeyTDM,
+     &                     KeySSCR, LuInput
+      use raswfn, only: cre_raswfn, Wfn_FileID
+      use rasscf_global, only: KSDFT, CBLBM, CMAX, DE, DOBLOCKDMRG,
+     &                         DoFaro, DoFCIDump,               ECAS,
+     &                         ESX, ExFac, FDIAG, HalfQ, iBLBM,
+     &                         ICICH, iCIOnly, iExpand, IfCrPr,
+     &                         InOCalc, iPr, iPT2, iRLXRoot, iSave_Exp,
+     &                         iSymBB, ITER, ITERCI, ITERSX, JBLBM,
+     &                         l_casdft,         lSquare, MaxIt, NAC,
+     &                         NACPAR, NACPR2, NewFock, nFint, no2m,
+     &                         nROOTS, PotNuc, QNSTEP, QNUPDT, ROTMax,
+     &                         Start_Vectors, SXShft, Thre, ThrSX,
+     &                         THRTE, TMin, Tot_Charge, EMY,
+     &                         VIA_DFT, iRoot, Weight, iAdr15, Ener,
+     &                         Conv, DoDMRG, iCIRST, KSDFT_Temp
+      use SplitCas_Data, only: DoSPlitCas,IterSplit,lRootSplit
+      use printlevel, only: DEBUG,USUAL,TERSE
+      use output_ras, only: LF,IPRLOC,RC_CI,RC_SX
+      use general_data, only: NALTER,ITERFILE,NSYM,INVEC,ISPIN,NCONF,
+     &                        NCRVEC,JOBIPH,NASH,NBAS,NDEL,NFRO,
+     &                        NISH,NRS1,NRS2,NRS3,NTOT,NTOT1,NTOT2
+      use spinfo, only: DOBKAP
 
-      Implicit Real*8 (A-H,O-Z)
+      Implicit None
 
 #include "rasdim.fh"
 #include "warnings.h"
-#include "input_ras.fh"
-#include "rasscf.fh"
-#include "rasrc.fh"
-#include "general.fh"
-#include "gas.fh"
-#include "splitcas.fh"
-#include "bk_approx.fh"
-#include "output_ras.fh"
 #include "timers.fh"
-#include "lucia_ini.fh"
-#include "pamint.fh"
-#include "qnctl.fh"
-#include "orthonormalize.fh"
-#include "ciinfo.fh"
-#include "raswfn.fh"
 
+      Integer IReturn, RC_RAS
       Logical DSCF
       Logical lTemp, lOPTO
-      Character*80 Line
-      Character*8 Label
-      Character*1 CTHRE, CTHRSX, CTHRTE
+      Character(LEN=80) Line
+      Character(LEN=8) Label
+      Character(LEN=1) CTHRE, CTHRSX, CTHRTE
       Logical IfOpened
+      Real*8 ECAS1, EVAC
 #ifdef _DMRG_
       Logical Do_ESPF
       ! function defined in misc_util/pcm_on.f
       Logical, External :: PCM_On
 #endif
+      Real*8 CASDFT_E, CASDFT_FUNCT, Certina_1, Certina_2, Certina_3,
+     &       DiffE, DiffETol, dum1, dum2, dum3, EAv, ThMax, TMXTOT
+      Real*8, External:: Get_ExFac
+      Integer i, i_ROOT, iAd, iAd15, iBas,      iComp, iFinal, ihh,
+     &        imm, Ind, IndT, iOff, iOpt, iPrLev, iRC, iRot, iShift,
+     &        iss, iSyLbl, iSym, iTerm, j,               kau,
+     &        kRoot, LuOne, LuvvVec, mRoots, nTav, iFlags, NoScr1
+      Integer, External:: IsFreeUnit
+#ifdef _HDF5_
+      Integer iDX, jDisk, jRoot, kDisk
+#endif
+#ifdef _FDE_
+      Integer iDummyEmb, iEmb, iUnit, nNuc
+      Real*8, External:: EmbPotEneMODensities
+#endif
 
-* --------- Cholesky stuff:
-#include "qmat.fh"
-* --------- End Cholesky stuff
-      Character*8 EMILOOP
 * --------- FCIDUMP stuff:
       real*8, allocatable :: orbital_E(:), folded_Fock(:)
 * --------- End FCIDUMP stuff:
@@ -144,14 +169,13 @@
       integer :: actual_iter
 
 
-      Character*15 STLNE2
+      Character(LEN=15) STLNE2
       External RasScf_Init
       External Scan_Inp
       External Proc_Inp
 #ifdef _DMRG_
       integer :: maxtrR
       real*8  :: maxtrW
-#include "nevptp.fh"
 #endif
       Integer IndType(56)
       Character(len=80) ::  VecTyp
@@ -164,9 +188,10 @@
      &                      OCCX(:), Scr1(:), Scr2(:), SMat(:),
      &                      QMat(:), EDUM(:), Tmp1(:), Fock(:),
      &                      TmpDS(:), TmpD1S(:)
+      Integer, External :: isStructure
 
 * Set status line for monitor:
-      Call StatusLine('RASSCF:',' Just started.')
+      Call StatusLine('RASSCF: ','Just started.')
 
 * Set the return code(s)
       ITERM  = 0
@@ -177,7 +202,6 @@
 
 * Set some Cholesky stuff
       DoActive=.true.
-      DoQmat=.false.
       lOPTO=.False.
 * Initialise doDMRG if compiled without QCMaquis
 #ifndef _DMRG_
@@ -202,7 +226,7 @@
         Write (6,*) 'integral file.'
         Call Quit(_RC_INTERNAL_ERROR_)
        End If
-       Call StatusLine('RASSCF:',' Read-in ONEINT')
+       Call StatusLine('RASSCF: ','Read-in ONEINT')
       If (IfVB.eq.2) go to 10
 
 *
@@ -211,7 +235,7 @@
 * with '*' or '!' or ' '  when left-adjusted, and replacing any rightmost
 * substring beginning with '!' with blanks.
 * That copy will be in file 'CleanInput', and its unit number is returned
-* as LUInput in common (included file input_ras.fh) by the following call:
+* as LUInput in common (module file input_ras.F90) by the following call:
       Call cpinp(LUInput,iRc)
 * If something wrong with input file:
       If (iRc.ne._RC_ALL_IS_WELL_) Then
@@ -243,13 +267,13 @@
       Call OpnFls_RASSCF(DSCF,DoCholesky)
 
 * Some preliminary input data:
-      Call Rd1Int
-      If ( .not.DSCF ) Call Rd2Int_RASSCF
+      Call Rd1Int()
+      If ( .not.DSCF ) Call Rd2Int_RASSCF()
 
 * Printed program header:
 
 * Process the input:
-      Call StatusLine('RASSCF:',' Processing input')
+      Call StatusLine('RASSCF: ','Processing input')
       Call Proc_Inp(DSCF,lOPTO,iRc)
 * If something goes wrong in proc_inp:
       If (iRc.ne._RC_ALL_IS_WELL_) Then
@@ -330,6 +354,8 @@
       FI(:)=0.0D0
       FA(:)=0.0D0
       DIAF(:)=0.0D0
+      ECAS1=0.0D0
+      EVAC=0.0D0
 *
       If (iCIRST.eq.1.and.DumpOnly) then
         write(6,*) 'ICIRST and DumpOnly flags are not compatible!'
@@ -444,7 +470,7 @@ c At this point all is ready to potentially dump MO integrals... just do it if r
 *
 ************************************************************************
 
-      Call StatusLine('RASSCF:',' Compute wave function.')
+      Call StatusLine('RASSCF: ','Compute wave function.')
       If ( IPRLEV.GE.2 .AND..NOT.lOPTO) then
        Write(LF,*)
        Write(LF,'(6X,A)') repeat('*',120)
@@ -599,8 +625,8 @@ c At this point all is ready to potentially dump MO integrals... just do it if r
       end if
 
       ITER=ITER+1
-      Write(STLNE2,'(A12,I3)')' Iteration ',ITER
-      Call StatusLine('RASSCF:',STLNE2)
+      Write(STLNE2,'(A12,I3)')'Iteration ',ITER
+      Call StatusLine('RASSCF: ',STLNE2)
       Call Timing(dum1,dum2,Certina_1,dum3)
 #ifdef _DMRG_
       ! Leon 27/11/2017: Skip the first CI iteration if we're using
@@ -675,8 +701,6 @@ c At this point all is ready to potentially dump MO integrals... just do it if r
 
         End If
 
-        DoQmat=.false.
-
         IPR=0
         IF(IPRLOC(2).EQ.4) IPR=5
         IF(IPRLOC(2).EQ.5) IPR=10
@@ -997,7 +1021,6 @@ c.. upt to here, jobiph are all zeros at iadr15(2)
       DoActive = .true.
 
       If (DoCholesky.and.ALGO.eq.2) Then
-         DoQmat=.true. ! to be used in the subsequent SX-section
          NTav=0
          do iSym=1,nSym
             NTav = NTav + nBas(iSym)*nAsh(iSym)
@@ -1577,7 +1600,7 @@ cGLM some additional printout for MC-PDFT
 
       IF (IFINAL.EQ.1) GOTO 2000
       IF (DE.GT.1.0D0) THEN
-        Call StatusLine('RASSCF:','No convergence.')
+        Call StatusLine('RASSCF: ','No convergence.')
         Write(LF,*)
         Write(LF,'(6X,A)') repeat('=',120)
         Call WarningMessage(2,'Rasscf energy diverges.')
@@ -1594,8 +1617,8 @@ cGLM some additional printout for MC-PDFT
         GOTO 2000
       ENDIF
       IF(ITER.LT.MAXIT) THEN
-        Write(STLNE2,'(A12,I3)')' Iteration ',ITER
-        Call StatusLine('RASSCF converged:',STLNE2)
+        Write(STLNE2,'(A12,I3)')'Iteration ',ITER
+        Call StatusLine('RASSCF converged: ',STLNE2)
         IF(ABS(DE).GT.THRE) GO TO 1000
         IF(ABS(CBLBM).GT.THRSX) GO TO 1000
         IF(ABS(ROTMAX).GT.THRTE) GO TO 1000
@@ -1626,8 +1649,8 @@ cGLM some additional printout for MC-PDFT
       ELSE
         IF(IPRLEV.ge.TERSE) Write(LF,'(6X,A,I3,A)')
      &        'No convergence after',ITER,' iterations'
-        Write(STLNE2,'(A12,I3)')' Iteration ',ITER
-        Call StatusLine('RASSCF max iter:',STLNE2)
+        Write(STLNE2,'(A12,I3)')'Iteration ',ITER
+        Call StatusLine('RASSCF max iter: ',STLNE2)
         IFINAL=1
         ITERM=16
         GOTO 1000
@@ -1683,9 +1706,9 @@ c Clean-close as much as you can the CASDFT stuff...
          End Do
         End If
       IF (NROOTS.GT.1) THEN
-       Call StatusLine('RASSCF:','Compute final CI vectors')
+       Call StatusLine('RASSCF: ','Compute final CI vectors')
       ELSE
-       Call StatusLine('RASSCF:','Compute final CI vector')
+       Call StatusLine('RASSCF: ','Compute final CI vector')
       END IF
 *
 * Transform two-electron integrals
@@ -1698,8 +1721,6 @@ c Clean-close as much as you can the CASDFT stuff...
 
       Call Get_D1I_RASSCF(CMO,D1I)
 
-       DoQmat=.false.
-
        IPR=0
        IF(IPRLOC(2).EQ.4) IPR=5
        IF(IPRLOC(2).EQ.5) IPR=10
@@ -1752,7 +1773,7 @@ c Clean-close as much as you can the CASDFT stuff...
 ! and CIOnly. It's enabled only for DMRGCI with QCMaquis now
 ! (to exclude potential side effects)
 ! but consider extending it to other cases!
-      else if (doDMRG .and. (ICIONLY.NE.0)) then
+      else if (doDMRG .and. ICIONLY/=0) then
         continue
 #endif
       else
@@ -1790,7 +1811,7 @@ c Clean-close as much as you can the CASDFT stuff...
 * NATORB args: Arg1 is current CMO coeffs, used in CI;
 *  all the rest should be regarded as scratch.
 *
-      Call StatusLine('RASSCF:','Compute natural orbitals')
+      Call StatusLine('RASSCF: ','Compute natural orbitals')
       IPR=0
       IF(IPRLOC(6).EQ.4) IPR=5
       IF(IPRLOC(6).EQ.5) IPR=10
@@ -1890,7 +1911,7 @@ c      write(6,*) 'I am in RASSCF before call to PutRlx!'
 ************************************************************************
 *                                                                      *
 
-      Call StatusLine('RASSCF:','Printing results')
+      Call StatusLine('RASSCF: ','Printing results')
       IF (IPRLEV.GE.USUAL .AND..NOT.lOPTO) THEN
         Write(LF,*)
         Write(LF,'(6X,A)') repeat('*',120)
@@ -2007,7 +2028,7 @@ c deallocating TUVX memory...
       end if
 
 
-      Call StatusLine('RASSCF:','Finished.')
+      Call StatusLine('RASSCF: ','Finished.')
       If (IPRLEV.GE.2) Write(LF,*)
       if(ifvb.eq.1) call make_close_rvb
 cvv call to grid is moved up, in order to call clssew safely..
@@ -2023,6 +2044,10 @@ c      End If
       Call ClsFls_RASSCF()
 
 *
+c Rc_RAS  =  0 : The RASSCF wave function is converged
+c         = 16 : The RASSCF wave function is not(!) converged
+c         = 99 : The RASSCF energy is divergent or
+c                the CI and SX energies differ
       Rc_RAS = ITERM
       Rc_RAS = Max(RC_RAS,Rc_CI)
       Rc_RAS = Max(RC_RAS,Rc_SX)
@@ -2036,9 +2061,7 @@ c      End If
       End If
 *
       If (Do_OFemb) Then
-         Call GetEnvF('EMIL_InLoop',EMILOOP)
-         If (EMILOOP.eq.' ') EMILOOP='0'
-         If (EMILOOP(1:1).ne.'0') Then
+         If (isStructure().eq.1) Then
             If (iReturn.ne._RC_ALL_IS_WELL_) Then
                Call WarningMessage(1,'RASSCF: non-zero return code.')
             EndIf
