@@ -61,28 +61,37 @@
       use fciqmc, only : DoNECI
 #ifdef _HDF5_
       use mh5, only: mh5_put_dset
+      use raswfn, only: wfn_mocoef, wfn_occnum
 #endif
       use stdalloc, only: mma_allocate, mma_deallocate
       use Fock_util_global, only: ALGO, DoCholesky
       use Lucia_Interface, only: Lucia_Util
       use wadr, only: DIA, SXN, BM, F1, F2, SXG, SXH, NLX
+      use input_ras, only: KeyHEUR
+      use rasscf_global, only: ExFac, KSDFT, DoBlockDMRG, DoDMRG, ECAS,
+     &                         ESX, iCIOnly, iPT2, ITER, ITERSX, ITMAX,
+     &                         l_casdft, NAC, nDimSX, nFint, NO2M,
+     &                         nQune, NROOT, NSXS, NTOT4, QNSTEP,
+     &                         QNUPDT, SXSEL, TMIN, VIA, ISTORP,
+     &                         IADR15, EMY
+      use printlevel, only: DEBUG
+      use output_ras, only: LF,IPRLOC
+      use general_data, only: NSYM,NACTEL,JOBIPH,LUINTM,LUQUNE,NASH,
+     &                        NBAS,NDEL,NFRO,NISH,NORB,NRS1,NRS2,NRS3,
+     &                        NSSH,NTOT,NTOT1,NTOT2
 
-      Implicit Real*8 (A-H,O-Z)
 
-      Dimension CMO(*),OCC(*),D(*),P(*),PA(*),FI(*),FA(*),D1A(*)
+      Implicit None
 
-#include "rasdim.fh"
-#include "rasscf.fh"
-#include "general.fh"
-#include "input_ras.fh"
-#include "output_ras.fh"
-      Character*16 ROUTINE
-      Parameter (ROUTINE='SXCTL   ')
-#include "raswfn.fh"
+      Real*8 CMO(*),OCC(*),D(*),P(*),PA(*),FI(*),FA(*),D1A(*)
+      Real*8 THMAX
+      INTEGER IFINAL
+
+      Character(LEN=16), Parameter :: ROUTINE='SXCTL   '
 * PAM 2008 IndType, VecTyp added, see below at call to WrVec
       Integer IndType(56)
-      Character*80 VecTyp
-      Save nCall
+      Character(LEN=80) VecTyp
+      Integer, Save ::nCall
       Logical TraOnly
       Real*8 P2act(1),CIDUMMY(1)
       Real*8, Allocatable:: SXHD(:)
@@ -94,7 +103,15 @@
      &                      ENER_X(:), SC(:), QQ(:), OVL(:), VT(:),
      &                      VL(:), XQN(:), SCR(:), V1(:), V2(:),
      &                      XMAT(:), X2(:)
-      Real*8 :: Dummy(1)
+      Real*8 :: Dummy(1), CASDFT_En, CPES, CPTS, P2reo_size, TIOES,
+     &          TIOS, XSXMAX
+      Real*8, External :: DDot_
+      Integer :: i, iBas, IC, iDisk, IndT, iOff, iOrb, iPrLev, iRC,
+     &           iRef, iShift, iSym, iWay, j, kMax, LCSXI, LuvvVec,
+     &           MIAAE, MNO, NA, NAEAE, NAOAE, NB, NCR, NCR1, NE, NI,
+     &           NIA, NIAIA, NLCC, NLHH, NLOVL, NLQ, NLX1, NLX2, NO,
+     &           nP2Act, NQ, NAE
+      Integer, External:: IsFreeUnit
 
 C PAM01 The SXCI part has been slightly modified by P-AA M Jan 15, 2001:
 C Changes affect several of the subroutines of this part.
