@@ -31,12 +31,10 @@
       SUBROUTINE DO_AOTDMNTO(TDMZZ,TSDMZZ,ANTSIN,ISTATE,JSTATE,nb,nb2)
       use OneDat, only: sNoNuc, sNoOri, sOpSiz
       use stdalloc, only: mma_allocate, mma_deallocate
+      use Cntrl, only: IfArgu
+      use rassi_data, only: NBTRI
+
       IMPLICIT None
-#include "Molcas.fh"
-#include "cntrl.fh"
-#include "rassi.fh"
-#include "symmul.fh"
-#include "Files.fh"
       Integer ISTATE,JSTATE,nb,nb2
       REAL*8 TDMZZ(6,nb2)
       REAL*8 TSDMZZ(6,nb2)
