@@ -8,7 +8,7 @@
 * For more details see the full text of the license in the file        *
 * LICENSE or in <http://www.gnu.org/licenses/>.                        *
 ************************************************************************
-      SUBROUTINE INPPRC
+      SUBROUTINE INPPRC()
       use rasdef, only: NRS1, NRS1T, NRS2, NRS2T, NRS3, NRS3T
       use rassi_global_arrays, only: HAM, ESHFT, HDIAG, JBNUM, LROOT
       use rassi_aux, Only : jDisk_TDM, AO_Mode, JOB_INDEX, CMO1, CMO2,
@@ -16,24 +16,39 @@
       use kVectors
       use Lebedev_quadrature, only: order_table
       use OneDat, only: sOpSiz, sRdFst, sRdNxt
-      use cntrl_data, only: SONTOSTATES, SONATNSTATE, HEff, RefEne
+      use cntrl, only: SONTOSTATES, SONATNSTATE, HEff, RefEne
       use stdalloc, only: mma_allocate
-      IMPLICIT REAL*8 (A-H,O-Z)
-#include "rasdim.fh"
-#include "symmul.fh"
-#include "rassi.fh"
-#include "cntrl.fh"
-#include "Files.fh"
-#include "SysDef.fh"
-#include "centra.fh"
-      CHARACTER*8 LABEL
-      CHARACTER*8 LABEL2
-      !CHARACTER*8 LABEL3
-      CHARACTER*8 PRPLST(MXPROP)
-      Character*3 lIrrep(8)
+      use Cntrl, only: IPUSED, ISOCMP, ICOMP, PTYPE, SOPRTP, SOPRNM,
+     &                 PNAME, MXPROP, nState, SOThr_PRT,
+     &                 nSOThr_PRT, SAVEDENS, IFTRD1, IFTDM, NATO,
+     &                 DO_TMOM, FORCE_NON_AO_TDM, NPROP, NSOPR, IFSO,
+     &                 DQVD, IFJ2, IFJZ, IFGCAL, IFXCAL, IFDCPL, IFHAM,
+     &                 IFSHFT, IFHDIA, IFMCAL, NJOB, IFHEFF, HAVE_HEFF,
+     &                 IFEJOB, HAVE_DIAG, IFHEXT, IFHCOM, NOHAM, TRACK,
+     &                 ONLY_OVERLAPS, PRSXY, PRORB, PRTRA, PRCI,
+     &                 RFPert, ToFile, PRXVR, PRXVE, PRXVS, PRMER,
+     &                 PRMEE, PRMES, NrNATO, BINA, NBINA, Do_SK, NQUAD,
+     &                 L_Eff, IBINA, IRREP, MLTPLT
+      use cntrl, only: nAtoms, Coor
+      use cntrl, only: LuTDM, FnTDM
+      use Symmetry_Info, only: nSym=>nIrrep
+      use rassi_data, only: NBSQ,NBMX,NBTRI,NBST,NCMO,NTRA,NTDMZZ,
+     &                      NTDMAB,NASHT,NISHT,NSSHT,NASH,NBASF,
+     &                      NBSQPR,NISH,NOSH,NSSH
+
+      IMPLICIT None
+      CHARACTER(LEN=8) LABEL
+      CHARACTER(LEN=8) LABEL2
+      CHARACTER(LEN=8) PRPLST(MXPROP)
+      Character(LEN=3) lIrrep(8)
       INTEGER ICMPLST(MXPROP)
       LOGICAL JOBMATCH,IsAvail(MXPROP),IsAvailSO(MXPROP)
-      DIMENSION IDUM(1)
+      Integer IDUM(1), IPRP, I, NBI, NLEV, IS, IBYTE, IPROP, ISOPR, IRC,
+     &        IOPT, ICMP, NPRPLST, IATOM, MISSAMX, MISSAMY, MISSAMZ,
+     &        IMISS, IERR, NATOM, IADD, MPROP, N, JPROP, MSOPR, JSOPR,
+     &        ISYM, JOB1, JOB2, J, I1, I2, II, III, ISYLAB
+      Integer, External:: IsFreeUnit
+      REAL*8 XAXIS, ZAXIS
 * Analysing and post-processing the input that was read in readin_rassi.
 
 
@@ -86,8 +101,6 @@ C HOWEVER, MAX POSSIBLE SIZE IS WHEN LSYM1=LSYM2.
         NTRA=NTRA+NOSH(IS)**2
         NTDMZZ=NTDMZZ+NBASF(IS)**2
       END DO
-      NTDMS=(NTDMZZ+NBST)/2
-      NTDMA=NTDMS
       NTDMAB=NTRA
       SaveDens=(IFTRD1.OR.IFTDM).OR.
      &         (SONATNSTATE.GT.0).OR.(SONTOSTATES.GT.0)
@@ -1062,4 +1075,4 @@ C Addition of NSTATE, JBNUM, and LROOT to RunFile.
 *
       CALL XFLUSH(6)
 
-      END
+      END SUBROUTINE INPPRC
