@@ -12,11 +12,12 @@
      &                   ISSTAB,NFSB0,NRDETS0,NFSB,NRDETS)
       use stdalloc, only: mma_allocate, mma_deallocate
       use rassi_global_arrays, only: FSBARR
+      use cntrl, only: MORSBITS
+      use Symmetry_Info, only: nSym=>nIrrep, MUL
       IMPLICIT NONE
       INTEGER ISSTAB(*)
       INTEGER NASPRT,NACTEL,M2SPIN,LSYM
       INTEGER NPART
-#include "symmul.fh"
       INTEGER NGASORB(0:NSYM,0:NPART)
       INTEGER NGASLIM(2,NPART)
       INTEGER NFSB,NFSB0,NRDETS,NRDETS0
@@ -36,7 +37,6 @@
       INTEGER IARC,IA,ISUM,KEEP
       INTEGER NSBS
       INTEGER NSDBLK
-#include "Morsel.fh"
       INTEGER LIMARR(2,0:50)
       INTEGER ITRY(50)
       INTEGER, Allocatable::  SSTPTR(:), SSTARR(:), VIDX(:)
